#!/bin/bash
SCRIPTDIR=`dirname $0`
CURDIR=`pwd`
USRID=`id -u`
GID=`id -g`
cd $SCRIPTDIR
SCRIPTDIR=`pwd`
cd ..

cd $CURDIR
#echo "CURR_DIR=${CURR_DIR}"


export PATH=${PATH}:.

cd ${0%/*}


if [ ! $6 ]
then
echo Usage: 
echo		agentImportKS.sh "Path to WAS_HOME" "KS_TYPE" "KS_PATH" "KS_PASSWORD" "SKLMADMIN_USERNAME" "SKLMADMIN_PASSWORD" "ALIAS_NAME"
echo		ALIAS_NAME is optional and required if there are multiple alias entries in Keystore
echo Example: 
echo		agentImportKS.sh /opt/IBM/WebSphere/AppServer JCEKS /home/user/testks.jks password 
echo Note:	Please ensure the WAS HOME path is correct.
exit 1
fi

export WAS_HOME=$1
export KS_TYPE=$2
export KS_PATH=$3
export KS_PASSWORD=$4
export SKLMADMIN_USERNAME=$5
export SKLMADMIN_PASSWORD=$6
export ALIAS_NAME=$7


if [ ! -d ${WAS_HOME} ]
then
echo "WAS_HOME Path Invalid"
exit 1
fi

if [ !  ${JAVA_HOME} ]
then
export JAVA_HOME=${WAS_HOME}/java/8.0
fi

if [ ! -d ${JAVA_HOME} ]
then
echo "JAVA_HOME ${JAVA_HOME} is not directory."
exit 1
fi

if [ -z ${KS_TYPE} ]
then 
echo "KS_TYPE Property is empty"
exit 1
fi

if [ -z ${KS_PATH} ]
then 
echo "KS_PATH Property is empty"
exit 1
fi

if [ -z ${KS_PASSWORD} ]
then 
echo "KS_PASSWORD Property is empty"
exit 1
fi

if [ -z ${SKLMADMIN_USERNAME} ]
then
echo "SKLMADMIN_USERNAME Property is empty"
exit 1
fi

if [ -z ${SKLMADMIN_PASSWORD} ]
then
echo "SKLMADMIN_PASSWORD Property is empty"
exit 1
fi


AGENT_CP=${SCRIPTDIR}/com.ibm.sklm.agent.jar:${WAS_HOME}/runtimes/com.ibm.ws.admin.client_9.0.jar:${WAS_HOME}/lib/ext/com.ibm.tklm.obfuscation.jar:${WAS_HOME}/universalDriver/lib/db2jcc4.jar:${WAS_HOME}/universalDriver/lib/db2jcc_license_cu.jar:${WAS_HOME}/lib/j2ee.jar:${WAS_HOME}/plugins/com.ibm.icu.jar:${WAS_HOME}/plugins/com.ibm.tklm.commands.jar:${WAS_HOME}/java/jre/lib/ext/ibmkeycert.jar:${WAS_HOME}/java/jre/lib/ext/ibmpkcs11impl.jar:${WAS_HOME}/java/jre/lib/ext/ibmjcefips.jar:${WAS_HOME}/lib/ext/com.ibm.tklm.passwordpolicy.jar:${WAS_HOME}/runtimes/com.ibm.jaxws.thinclient_9.0.jar

#echo "****** AGENT_CP ${AGENT_CP}*******"

#echo WAS_HOME=$1
#echo KS_TYPE=$2
#echo KS_PATH=$3
#echo KS_PASSWORD= @@@@@
#echo SKLMADMIN_USERNAME= $5
#echo SKLMADMIN_PASSWORD= @@@@@
#echo ALIAS_NAME= $7
#echo ${ALIAS_NAME}

shopt -s nullglob
for f in ${WAS_HOME}/plugins/*.jar
do
	AGENT_CP=${AGENT_CP}:$f
done
for f in ${WAS_HOME}/lib/*.jar
do
	AGENT_CP=${AGENT_CP}:$f
done
for f in ${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/*.jar
do
	AGENT_CP=${AGENT_CP}:$f
done
for f in ${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/lib/*.jar
do
    AGENT_CP=${AGENT_CP}:$f
done
echo ${JAVA_HOME}/bin/java -cp ${AGENT_CP} com.ibm.sklm.agent.utilities.SKLMImportKS ${KS_TYPE} ${KS_PATH} @@@@@@ ${SKLMADMIN_USERNAME} @@@@@@@ ${ALIAS_NAME} > agentImportKS.log 2>&1
${JAVA_HOME}/bin/java -cp ${AGENT_CP} com.ibm.sklm.agent.utilities.SKLMImportKS ${KS_TYPE} ${KS_PATH} ${KS_PASSWORD} ${SKLMADMIN_USERNAME} ${SKLMADMIN_PASSWORD} ${ALIAS_NAME} > agentImportKS.log 2>&1
rc=$?
if [ $rc -eq 0 ]; then
   	echo "Agent Import keystore successful"
else
	echo "Agent Import keystore failed."
	echo "Please check agentImportKS.log for more details."
fi

exit $rc
