#!/usr/bin/env bash
#set -x
############################################################################################### 
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2016  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###############################################################################################
# Verify input
#TODO:need detailed usage statement

printusage() {
echo "usage: DB2ROSSetup.sh DB2_ADMIN DB2_PASS DB2INSTALLDIR DBNAME HADR_ROLE DB2_Service_Name ROS_VALUE
  where
  DB2_ADMIN is the Database Instance Owner specified during the install
  DB2_PASS is the password of the database instance owner
  DB2INSTALLDIR is the DB2 install directory Example /opt/IBM/DB2SKLMV41 - In case of non root install, its instance home directory including sqllib Example /home/testuser/sqllib   
  DBNAME is the database name, default is SKLMDB
  HADR_ROLE is either PRIMARY or STANDBY.
  DB2_Service_Name DB2 service name - optional"
  ROS_VALUE ROS value either ON or OFF
  Warning : This action may restart database server
exit 1
}

loadHADRROS(){
	HADR_ROS_STATUS=""
	if [ "$username" != "$DB2ADMIN" ]; then
		HADR_ROS_STATUS=$(su - $DB2ADMIN -c "db2set DB2_HADR_ROS")
		RC=0
	else
		HADR_ROS_STATUS=$(${INSTALLDIR}/bin/db2set DB2_HADR_ROS)
		RC=0
	fi
	echo HADR_ROS_STATUS=$HADR_ROS_STATUS >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
}



updateHADRROS() {
	if [ "$username" != "$DB2ADMIN" ]; then
		su - $DB2ADMIN -c "db2set DB2_HADR_ROS=$ROS_VALUE" >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		su - $DB2ADMIN -c "db2set DB2_STANDBY_ISO=UR" >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		RC=$?
	else
		db2set DB2_HADR_ROS=$ROS_VALUE >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		db2set DB2_STANDBY_ISO=UR >>  $HOME/sklm41properties/scripts/DB2ROSSetup.output
		RC=$?
	fi

}

deactivateDBForStandby() {
	if [ "$multimasterRole" = "STANDBY" ]; then
		if [ "$username" != "$DB2ADMIN" ]; then
			su - $DB2ADMIN -c "${INSTALLDIR}/bin/db2 deactivate db $DBNAME " >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
			RC=$?
		else
			db2 deactivate db $DBNAME >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
			RC=$?
		fi
	fi
}

restartDB2HADR() {
	servicedirpath=/etc/systemd/system
	if [ "$username" != "$DB2ADMIN" ]; then
		if [ -d ${servicedirpath} ]; then
			systemctl stop ${DB2_SRV_NAME} >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		fi
		su - $DB2ADMIN -c "db2stop force" >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		su - $DB2ADMIN -c "db2start" >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		#su - $DB2ADMIN -c "db2 start HADR on database $DBNAME as $multimasterRole"  >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		RC=0
	else
		db2stop force >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		db2start >>  $HOME/sklm41properties/scripts/DB2ROSSetup.output
		#${INSTALLDIR}/bin/db2 start HADR on database $DBNAME as $multimasterRole  >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		RC=$?
	fi
}

startDB2HADR() {
	if [ "$username" != "$DB2ADMIN" ]; then
		su - $DB2ADMIN -c "db2 start HADR on database $DBNAME as $multimasterRole"  >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		RC=$?
	else
		db2 start HADR on database $DBNAME as $multimasterRole  >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
		RC=$?
	fi
}

   export DB2ADMIN="$1"
   export DB2PASS="$2"
   export INSTALLDIR="$3"
   export DBNAME="$4"
   export HADR_ROLE=$5
   export multimasterRole=$HADR_ROLE
   export DB2_SRV_NAME=$6
   export ROS_VALUE=$7
   export MASTERTYPE=

if [ "$DB2ADMIN" =  "" ]; then
   printusage
fi

if [ "$DB2PASS" =  "" ]; then
   printusage
fi
if
[ "$INSTALLDIR" = "" ]; then
   printusage
fi
if
[ "$DBNAME" = "" ]; then
   printusage
fi

if [ "${HADR_ROLE}" = "" ]; then
	printusage
fi

if [ "${ROS_VALUE}" = "" ]; then
	printusage
fi

if [ "${ROS_VALUE}" != "ON" ]; then
	if [ "${ROS_VALUE}" != "OFF" ]; then
		printusage
	fi
fi

username=$(whoami)
#echo user : $username

if [ ! -d "${INSTALLDIR}" ]; then
 	echo "Error:" $INSTALLDIR " does not exist"
  	RC=-10
fi

loadHADRROS

echo HADR_ROS_STATUS=$HADR_ROS_STATUS >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
if [ "$HADR_ROS_STATUS" = "${ROS_VALUE}" ]; then
	echo Reads on standby already ${ROS_VALUE}. >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
else
	echo enable Reads ON Standby, update HADR_ROS_STATUS value. >> $HOME/sklm41properties/scripts/DB2ROSSetup.output
	updateHADRROS
	deactivateDBForStandby
	restartDB2HADR
fi

if [ "$multimasterRole" = "PRIMARY" ]; then
	startDB2HADR
fi

if [ "$multimasterRole" = "STANDBY" ]; then
	startDB2HADR
fi	

if [ $RC -eq 0 ]; then
  echo "Update of DB2 instance is complete."
fi
exit $RC
