#!/usr/bin/env bash
#set -x
############################################################################################### 
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2016  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###############################################################################################
# Verify input
#TODO:need detailed usage statement

printusage() {
echo "usage: FP1DB2Update.sh DB2_ADMIN DB2_PASS DB2INSTALLDIR DBNAME WAS_HOME DB2_Service_Name
  where
  DB2_ADMIN is the Database Instance Owner specified during the install
  DB2_PASS is the password of the database instance owner
  DB2INSTALLDIR is the DB2 install directory Example /opt/IBM/DB2SKLMV41 - In case of non root install, its instance home directory including sqllib Example /home/testuser/sqllib   
  DBNAME is the database name, default is SKLMDB
  WAS_HOME is path to WAS_HOME folder.
  DB2_Service_Name DB2 service name - optional"
exit 1
}

loadHADRROS(){
	HADR_ROS_STATUS=""
	if [ "$username" != "$DB2ADMIN" ]; then
		HADR_ROS_STATUS=$(su - $DB2ADMIN -c "db2set DB2_HADR_ROS")
		RC=0
	else
		HADR_ROS_STATUS=$(db2set DB2_HADR_ROS)
		RC=0
	fi
	echo HADR_ROS_STATUS=$HADR_ROS_STATUS >> $HOME/sklm41properties/scripts/DB2update.output
}

performDBChanges() {
	if [ "$username" != "$DB2ADMIN" ]; then
		cp $HOME/sklm41properties/scripts/gklmsql-fp.db2 /tmp >> $HOME/sklm41properties/scripts/DB2update.output
		su - $DB2ADMIN -c "${INSTALLDIR}/bin/db2 connect to $DBNAME user $DB2ADMIN using '$DB2PASS'" >> $HOME/sklm41properties/scripts/DB2update.output
		su - $DB2ADMIN -c "${INSTALLDIR}/bin/db2 connect to $DBNAME user $DB2ADMIN using '$DB2PASS' && ${INSTALLDIR}/bin/db2 -td# -s -f  /tmp/gklmsql-fp.db2" >> $HOME/sklm41properties/scripts/DB2update.output
		RC=$?
		rm -f /tmp/gklmsql-fp.db2
	else
		#chmod -R 775 $HOME/sklm41properties
		#. ${HOME}/.profile
		db2 "connect to $DBNAME user $DB2ADMIN using '$DB2PASS'" >> $HOME/sklm41properties/scripts/DB2update.output
		db2 -td# -s -f  "$HOME/sklm41properties/scripts/gklmsql-fp.db2" >>  $HOME/sklm41properties/scripts/DB2update.output
		RC=$?
	fi
}

updateHADRROS() {
	if [ "$username" != "$DB2ADMIN" ]; then
		su - $DB2ADMIN -c "db2set DB2_HADR_ROS=ON" >> $HOME/sklm41properties/scripts/DB2update.output
		su - $DB2ADMIN -c "db2set DB2_STANDBY_ISO=UR" >> $HOME/sklm41properties/scripts/DB2update.output
		su - $DB2ADMIN -c "db2 UPDATE ALTERNATE SERVER FOR DATABASE $DBNAME USING HOSTNAME NULL PORT NULL" >> $HOME/sklm41properties/scripts/DB2update.output
		RC=$?
	else
		db2set DB2_HADR_ROS=ON >> $HOME/sklm41properties/scripts/DB2update.output
		db2set DB2_STANDBY_ISO=UR >>  $HOME/sklm41properties/scripts/DB2update.output
		db2 UPDATE ALTERNATE SERVER FOR DATABASE $DBNAME USING HOSTNAME NULL PORT NULL >>  $HOME/sklm41properties/scripts/DB2update.output
		RC=$?
	fi

}

deactivateDBForStandby() {
	if [ "$multimasterRole" = "STANDBY" ]; then
		if [ "$username" != "$DB2ADMIN" ]; then
			su - $DB2ADMIN -c "db2 deactivate db $DBNAME " >> $HOME/sklm41properties/scripts/DB2update.output
			RC=$?
		else
			db2 deactivate db $DBNAME >> $HOME/sklm41properties/scripts/DB2update.output
			RC=$?
		fi
	fi
}

restartDB2HADR() {
	servicedirpath=/etc/systemd/system
	if [ "$username" != "$DB2ADMIN" ]; then
		if [ -d ${servicedirpath} ]; then
			systemctl stop ${DB2_SRV_NAME} >> $HOME/sklm41properties/scripts/DB2update.output
		fi
		su - $DB2ADMIN -c "db2stop force" >> $HOME/sklm41properties/scripts/DB2update.output
		su - $DB2ADMIN -c "db2start" >> $HOME/sklm41properties/scripts/DB2update.output
		#su - $DB2ADMIN -c "db2 start HADR on database $DBNAME as $multimasterRole"  >> $HOME/sklm41properties/scripts/DB2update.output
		RC=0
	else
		db2stop force >> $HOME/sklm41properties/scripts/DB2update.output
		db2start >>  $HOME/sklm41properties/scripts/DB2update.output
		#${INSTALLDIR}/bin/db2 start HADR on database $DBNAME as $multimasterRole  >> $HOME/sklm41properties/scripts/DB2update.output
		RC=$?
	fi
}

startDB2HADR() {
	if [ "$username" != "$DB2ADMIN" ]; then
		su - $DB2ADMIN -c "db2 start HADR on database $DBNAME as $multimasterRole"  >> $HOME/sklm41properties/scripts/DB2update.output
		RC=$?
	else
		db2 start HADR on database $DBNAME as $multimasterRole  >> $HOME/sklm41properties/scripts/DB2update.output
		RC=$?
	fi
}

   export DB2ADMIN="$1"
   export DB2PASS="$2"
   export INSTALLDIR="$3"
   export DBNAME="$4"
   export WAS_HOME=$5
   export DB2_SRV_NAME=$6
   export MASTERTYPE=

if [ "$DB2ADMIN" =  "" ]; then
   printusage
fi

if [ "$DB2PASS" =  "" ]; then
   printusage
fi
if
[ "$INSTALLDIR" = "" ]; then
   printusage
fi
if
[ "$DBNAME" = "" ]; then
   printusage
fi

if [ "${WAS_HOME}" = "" ]; then
	echo WAS_HOME path ${WAS_HOME} does not exist.
	exit 1 
fi




#. $WAS_HOME/products/sklm/config/MMConfig.properties
file="$WAS_HOME/products/sklm/config/MMConfig.properties"
  while IFS="=" read -r key value; do
    if [ "$key" = "multimasterRole" ]; then
      multimasterRole="$value"
    fi
  done < "$file"

username=$(whoami)
#echo user : $username

if [ ! -d "${INSTALLDIR}" ]; then
 	echo "Error:" $INSTALLDIR " does not exist"
  	RC=-10
fi

loadHADRROS

if [ "$multimasterRole" = "STANDBY" ]; then
	echo Skipping database changes as role is STANDBY.
else
	#Perform db2 changes for PRIMARY and STANDALONE (non STANDBY)
	echo Executing database changes as role is not STANDBY.
	performDBChanges
fi

echo HADR_ROS_STATUS=$HADR_ROS_STATUS >> $HOME/sklm41properties/scripts/DB2update.output
if [ "$HADR_ROS_STATUS" = "ON" ]; then
	echo Reads on standby already enabled. >> $HOME/sklm41properties/scripts/DB2update.output
else
	echo enable Reads ON Standby, update HADR_ROS_STATUS value. >> $HOME/sklm41properties/scripts/DB2update.output
	updateHADRROS
	deactivateDBForStandby
	restartDB2HADR
fi

if [ "$multimasterRole" = "PRIMARY" ]; then
	startDB2HADR
fi

if [ "$multimasterRole" = "STANDBY" ]; then
	startDB2HADR
fi	

if [ $RC -eq 0 ]; then
  echo "Update of DB2 instance is complete."
fi
exit $RC
