#!/usr/bin/env bash
############################################################################################### 
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2008, 2009  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###############################################################################################

printusage() {
echo "*************************************************************************************
Usage: 
     ./installDb2Fixpack.sh db2installdir db2username fixpackLocation 
      where
      db2installdir is installation directory of DB2.
      db2username is the name of DB2 user for SKLM.
      fixpackLocation is the directory where universal fix pack in extrtacted.
Example :  ./installDb2Fixpack.sh 	/opt/IBM/DB2SKLMV40 sklmdb40 /root/universal
							
Note: -On Linux systems, ./installDb2Fixpack.sh must have executable permission.							
		
******************************************************************************************"
echo STATUS=1
exit 1
}

db2installdir=$1
db2username=$2
fixpackLocation=$3

if [ $# -ne 3 ]; then
	printusage
else
   export db2installdir="$1"
   export db2username="$2"   
   export fixpackLocation="$3"
fi

if [ "$db2installdir" = "" ]; then
   printusage
fi
if [ "$db2username" = "" ]; then
   printusage
fi
if [ "$fixpackLocation" =  "" ]; then
   printusage
fi


#=======MAIN============

db2installdir=$1
db2username=$2
fixpackLocation=$3

logfile=installUniversalFixpack.output.txt

UNAME=`uname`
echo executed by user ${UNAME}  > ${logfile}

GID=`id -g`
if [ $GID -eq 0  ]; then

	echo stopping DB2 database manager
	sudo -i -u $db2username $db2installdir/adm/db2stop force  >> ${logfile}
	
	echo changing ownership of DB2 install directory to owner of installation copy aka root  >> ${logfile}
	chown -R root $db2installdir  >> ${logfile}
	
	echo installing db2 universal fix pack at db2 installation directory $db2installdir for root user
	yes no | $fixpackLocation/installFixPack  -f install -b $db2installdir
	
	chmod -R 755 $db2installdir  >> ${logfile}
	$db2installdir/instance/db2iupdt $db2username  >> ${logfile}
	
	echo changing ownership of DB2 install directory back to $db2username >> ${logfile}
	chown -R $db2username $db2installdir  >> ${logfile}
	
	echo Starting DB2 database manager
	sudo -i -u $db2username $db2installdir/adm/db2start  >> ${logfile}
	
else
    . /$db2installdir/db2profile
    echo stopping DB2 database manager
	$db2installdir/adm/db2stop force  >> ${logfile}
	
	echo installing db2 universal fix pack at db2 installation directory for non root user
	$fixpackLocation/installFixPack -f install -b $db2installdir
	chmod -f -R 755 $db2installdir  >> ${logfile}
	
	echo Starting DB2 database manager
	$db2installdir/adm/db2start  >> ${logfile}
	
fi