CREATE SCHEMA IF NOT EXISTS sklm AUTHORIZATION current_user;
ALTER ROLE current_user SET search_path TO sklm;
SET search_path TO sklm;
-------------------------------------- BEGIN CREATE TABLES ---------------------------------------

CREATE TABLE KMT_METADATA (
    PROPERTY_NAME VARCHAR(254) NOT NULL,
    PROPERTY_VALUE VARCHAR(1024) NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  ;
  
CREATE TABLE KMT_KEY (
	UUID VARCHAR(64) NOT NULL,
	TYPE VARCHAR (64) NOT NULL,
	DESCRIPTION VARCHAR(256),
	ALGORITHM VARCHAR(512),
	LENGTH INT,
	CREATIONDATE TIMESTAMP,
	EXPIRATIONDATE TIMESTAMP,
--Obsolete column:
	RETIREDATE TIMESTAMP,
	DESTROYDATE TIMESTAMP,
--Obsolete column:	
	AUTOSTATECHANGE SMALLINT NOT NULL,
	CONSTRAINT CCAUTOSTATECHANGE1 CHECK (AUTOSTATECHANGE in(0,1)),
	ACTIVATIONDATE TIMESTAMP,
	COMPROMISEDATE TIMESTAMP,
	ARCHIVETIME TIMESTAMP,
--Obsolete column:	
	STATE INTEGER,
	PREVSTATE INTEGER,
	OWNER VARCHAR(128),
	HASHVALUE BYTEA NOT NULL,
	VERSION INT NOT NULL,
	PENDING SMALLINT DEFAULT 0,
	FORMAT SMALLINT,
	--KMIP:
	LEASE_TIME INTEGER,
	CONTACT_INFO VARCHAR(1024),
	LAST_CHANGED_DATE TIMESTAMP,
	OPERATIONAL_POLICY VARCHAR(64),
	COMPROMISE_OCCURRENCE_DATE TIMESTAMP,
	PROCESS_START_DATE TIMESTAMP,
	PROTECT_STOP_DATE TIMESTAMP,
	REVOKE_REASON_CODE INTEGER,
	REVOKE_REASON_MESSAGE VARCHAR(2048),
	USAGE_VALUE DECIMAL(18,0),
	USAGE_TOTAL DECIMAL(18,0),
	USAGE_LIMIT_TYPE SMALLINT,
	CRYPTO_USAGE VARCHAR(32),
	KEY_DATA BYTEA,
	 -- SKI SUPPORT
	X509EXT_SKI VARCHAR(256),
	SHA1PUBKEY_SKI VARCHAR(256),
	ORIGINAL_CREATION_DATE TIMESTAMP,
        CREATED_BY VARCHAR(128),
	CONSTRAINT PK_KEY PRIMARY KEY (UUID)
  )
  ;
  

CREATE INDEX IDX_KEY_01 ON KMT_KEY (CREATIONDATE);
CREATE INDEX IDX_KEY_02 ON KMT_KEY (EXPIRATIONDATE) ;
CREATE INDEX IDX_KEY_03 ON KMT_KEY (ACTIVATIONDATE) ;
CREATE INDEX IDX_KEY_04 ON KMT_KEY (COMPROMISEDATE) ;
CREATE INDEX IDX_KEY_05 ON KMT_KEY (DESTROYDATE) ;
CREATE INDEX IDX_KEY_06 ON KMT_KEY (HASHVALUE) ;
CREATE INDEX IDX_KEY_07 ON KMT_KEY (PENDING) ;
CREATE INDEX IDX_KEY_08 ON KMT_KEY (ALGORITHM) ;
CREATE INDEX IDX_KEY_09 ON KMT_KEY (LENGTH) ;
CREATE INDEX IDX_KEY_10 ON KMT_KEY (LEASE_TIME) ;
CREATE INDEX IDX_KEY_11 ON KMT_KEY (OWNER) ;
CREATE INDEX IDX_KEY_12 ON KMT_KEY (REVOKE_REASON_CODE) ;
CREATE INDEX IDX_KEY_13 ON KMT_KEY (PROCESS_START_DATE) ;
CREATE INDEX IDX_KEY_14 ON KMT_KEY (PROTECT_STOP_DATE) ;
CREATE INDEX IDX_KEY_15 ON KMT_KEY (USAGE_VALUE) ;
CREATE INDEX IDX_KEY_16 ON KMT_KEY (USAGE_TOTAL) ;
CREATE INDEX IDX_KEY_17 ON KMT_KEY (USAGE_LIMIT_TYPE) ;
CREATE INDEX IDX_KEY_18 ON KMT_KEY (CRYPTO_USAGE) ;
CREATE INDEX IDX_KEY_19 ON KMT_KEY (PREVSTATE) ;
CREATE INDEX IDX_KEY_20 ON KMT_KEY (TYPE) ;
CREATE INDEX IDX_KEY_21 ON KMT_KEY (X509EXT_SKI) ;
CREATE INDEX IDX_KEY_22 ON KMT_KEY (SHA1PUBKEY_SKI) ;
CREATE INDEX IDX_KEY_23 ON KMT_KEY (ORIGINAL_CREATION_DATE) ;


CREATE TABLE KMT_CERT (
	UUID VARCHAR(64) NOT NULL,
	DESCRIPTION VARCHAR(256),
	ISSUERNAME VARCHAR(512),
	SERIALNUMBER VARCHAR(64),
	SUBJECTNAME VARCHAR(512),
--Obsolete column:	
	TARGETUUID VARCHAR(64),
	CREATIONDATE TIMESTAMP,
	ACTIVATIONDATE TIMESTAMP,
	EXPIRATIONDATE TIMESTAMP,        
	DESTROYDATE TIMESTAMP,
	COMPROMISEDATE TIMESTAMP,
--Obsolete column:	
	RETIREDATE TIMESTAMP,
--Obsolete column:	
	AUTOSTATECHANGE SMALLINT NOT NULL,
--Obsolete column:	
	STATE INTEGER,
	PREVSTATE INTEGER,
	OWNER VARCHAR(128),
	ARCHIVETIME TIMESTAMP,
	HASHVALUE BYTEA NOT NULL,
	VERSION INT NOT NULL,
	NOTIFY SMALLINT NOT NULL DEFAULT 1,
	TRUSTED SMALLINT NOT NULL DEFAULT 1,
	--KMIP:
	LEASE_TIME INTEGER,
	CONTACT_INFO VARCHAR(1024),
	LAST_CHANGED_DATE TIMESTAMP,
	COMPROMISE_OCCURRENCE_DATE TIMESTAMP,
	OPERATIONAL_POLICY VARCHAR(64),
	CERTIFICATE_TYPE INTEGER,
	PROCESS_START_DATE TIMESTAMP,
	PROTECT_STOP_DATE TIMESTAMP,
	REVOKE_REASON_CODE INTEGER,
	REVOKE_REASON_MESSAGE VARCHAR(2048),
	CONSTRAINT NOTIFY1 CHECK (NOTIFY in(0,1)),
	USAGE_VALUE DECIMAL(18,0),
	USAGE_TOTAL DECIMAL(18,0),
	USAGE_LIMIT_TYPE SMALLINT,
	KEY_DATA BYTEA,
	PENDING_TRUST SMALLINT DEFAULT 0,
	PENDING_TRUST_DATE TIMESTAMP,
--New for V3 Cert support:
    DIGITAL_SIGNATURE_ALGORITHM SMALLINT NOT NULL,
    CERTIFICATE_LENGTH INTEGER NOT NULL,
    -- SKI SUPPORT
    X509EXT_SKI VARCHAR(256),
    SHA1PUBKEY_SKI VARCHAR(256),
	CRYPTO_USAGE VARCHAR(32),
	ALGORITHM VARCHAR(512),
	LENGTH INT,
    ORIGINAL_CREATION_DATE TIMESTAMP,
    CREATED_BY VARCHAR(128),
    CONSTRAINT PK_CERT PRIMARY KEY (UUID)
  )
  ;

CREATE INDEX IDX_CERT_01 ON KMT_CERT (CREATIONDATE) ;
CREATE INDEX IDX_CERT_02 ON KMT_CERT (EXPIRATIONDATE) ;
CREATE INDEX IDX_CERT_03 ON KMT_CERT (ACTIVATIONDATE) ;
CREATE INDEX IDX_CERT_04 ON KMT_CERT (COMPROMISEDATE) ;
CREATE INDEX IDX_CERT_05 ON KMT_CERT (DESTROYDATE) ;
CREATE INDEX IDX_CERT_06 ON KMT_CERT (HASHVALUE) ;
CREATE INDEX IDX_CERT_07 ON KMT_CERT (NOTIFY) ;
CREATE INDEX IDX_CERT_08 ON KMT_CERT (TRUSTED) ;
CREATE INDEX IDX_CERT_09 ON KMT_CERT (LEASE_TIME) ;
CREATE INDEX IDX_CERT_10 ON KMT_CERT (SERIALNUMBER) ;
CREATE INDEX IDX_CERT_11 ON KMT_CERT (ISSUERNAME) ;
CREATE INDEX IDX_CERT_12 ON KMT_CERT (SUBJECTNAME) ;
CREATE INDEX IDX_CERT_13 ON KMT_CERT (OWNER) ;
CREATE INDEX IDX_CERT_14 ON KMT_CERT (REVOKE_REASON_CODE) ;
CREATE INDEX IDX_CERT_15 ON KMT_CERT (PROCESS_START_DATE) ;
CREATE INDEX IDX_CERT_16 ON KMT_CERT (PROTECT_STOP_DATE) ;
CREATE INDEX IDX_CERT_17 ON KMT_CERT (USAGE_VALUE) ;
CREATE INDEX IDX_CERT_18 ON KMT_CERT (USAGE_TOTAL) ;
CREATE INDEX IDX_CERT_19 ON KMT_CERT (USAGE_LIMIT_TYPE) ;
CREATE INDEX IDX_CERT_20 ON KMT_CERT (PREVSTATE) ;
CREATE INDEX IDX_CERT_21 ON KMT_CERT (DIGITAL_SIGNATURE_ALGORITHM) ;
CREATE INDEX IDX_CERT_22 ON KMT_CERT (X509EXT_SKI) ;
CREATE INDEX IDX_CERT_23 ON KMT_CERT (SHA1PUBKEY_SKI) ;
CREATE INDEX IDX_CERT_24 ON KMT_CERT (ORIGINAL_CREATION_DATE) ;
CREATE INDEX IDX_CERT_25 ON KMT_CERT (CRYPTO_USAGE) ;
CREATE INDEX IDX_CERT_26 ON KMT_CERT (ALGORITHM) ;
CREATE INDEX IDX_CERT_27 ON KMT_CERT (LENGTH) ;

CREATE TABLE KMT_POLICY (
    UUID VARCHAR(64) NOT NULL,
    MANADATORY SMALLINT NOT NULL,
    POLICYTYPE SMALLINT NOT NULL,
    POLICY  VARCHAR (3072) NOT NULL,
    VERSION INT NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_POLICY PRIMARY KEY(UUID)
  ) 
  ;
  

CREATE TABLE KMT_KEYPOLICY_RN (
    UUID VARCHAR(64) NOT NULL,
    POLICYID VARCHAR(64) NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_KEYPOLICYRN PRIMARY KEY(POLICYID, UUID)
  )
   ;



CREATE TABLE KMT_CERPOLICY_RN (
    UUID VARCHAR(64) NOT NULL,
    POLICYID VARCHAR(64) NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP, 
    CONSTRAINT PK_CERPOLICYRN  PRIMARY KEY (POLICYID, UUID)
  )
  ;

CREATE TABLE KMT_DEVICE_TYPE (
		BASE_FAMILY_ID SMALLINT NOT NULL,
		NAME VARCHAR(256) NOT NULL,
		ROLE_NAME VARCHAR(256),
		VERSION INTEGER NOT NULL,
		UUID SMALLINT NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 10000 INCREMENT BY 1 MINVALUE 1 MAXVALUE 32767 CYCLE CACHE 20),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		DEVICE_GROUP_TYPE VARCHAR(64),
                CONSTRAINT DEVICE_TYPE_PK PRIMARY KEY (UUID),
                CONSTRAINT DEVTYPE_NAME_UN UNIQUE (NAME)
	);


CREATE INDEX DEVTYPE_BASE_FAMILY_IDX ON KMT_DEVICE_TYPE (BASE_FAMILY_ID ASC, UUID ASC);

CREATE INDEX DEVTYPE_ROLE_IDX ON KMT_DEVICE_TYPE (ROLE_NAME ASC, UUID ASC);


CREATE TABLE KMT_KEYSTR (
    UUID VARCHAR(64) NOT NULL,
    KEYSTORELOCATION VARCHAR(2048) NOT NULL,
    KEYSTOREPWD VARCHAR(256),
    KEYSTORETYPE VARCHAR(64),
    KEYSTORENAME VARCHAR(64) NOT NULL,
    USERID    VARCHAR (256),
    VERSION INT NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_KEYSTR PRIMARY KEY (UUID)
  )
 ;


CREATE UNIQUE INDEX IDX_KEYSTR_01 ON KMT_KEYSTR(KEYSTORENAME);

CREATE TABLE KMT_KEYSTR_RN (
    UUID VARCHAR(64) NOT NULL,
    KEYSTOREID VARCHAR(64) NOT NULL,
    ALIAS VARCHAR(256) NOT NULL,
    KEYPASSWORD VARCHAR(256),
    DEVICE_TYPE_ID SMALLINT NOT NULL DEFAULT 0,
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_KEYSTR_RN PRIMARY KEY (UUID, KEYSTOREID, ALIAS),
    CONSTRAINT KEYSTRRN_FK1 FOREIGN KEY (KEYSTOREID)
				REFERENCES KMT_KEYSTR (UUID) ON DELETE RESTRICT,
    CONSTRAINT KEYSTRRN_FK2 FOREIGN KEY (UUID)
				REFERENCES KMT_KEY (UUID) ON DELETE CASCADE,
    CONSTRAINT KEY_DEVTYPE_FK FOREIGN KEY (DEVICE_TYPE_ID)
				REFERENCES KMT_DEVICE_TYPE (UUID) ON DELETE CASCADE
  )
;

CREATE INDEX IDX_KEYSTRRN_01 ON KMT_KEYSTR_RN(ALIAS) ;
CREATE INDEX IDX_KEYSTRRN_02 ON KMT_KEYSTR_RN(UUID) ;

CREATE INDEX KMT_KEYSTR_RN_DEVTYPE_IDX ON KMT_KEYSTR_RN (UUID ASC, DEVICE_TYPE_ID ASC);


CREATE TABLE KMT_CERTSTR_RN (
    UUID VARCHAR(64) NOT NULL,
    KEYSTOREID VARCHAR(64) NOT NULL,
    ALIAS VARCHAR(256) NOT NULL,
    DEVICE_TYPE_ID SMALLINT NOT NULL DEFAULT 0,
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_CERTSTR_RN PRIMARY KEY (UUID, KEYSTOREID, ALIAS),
    CONSTRAINT CERTSTRRN_FK1 FOREIGN KEY (KEYSTOREID)
				  REFERENCES KMT_KEYSTR (UUID) ON DELETE RESTRICT,
    CONSTRAINT CERTSTRRN_FK2 FOREIGN KEY (UUID)
				  REFERENCES KMT_CERT (UUID) ON DELETE CASCADE,
    CONSTRAINT CERT_DEVTYPE_FK FOREIGN KEY (DEVICE_TYPE_ID)
				  REFERENCES KMT_DEVICE_TYPE (UUID) ON DELETE CASCADE
  )
 ;



CREATE UNIQUE INDEX IDX_CERTSTRRN_01 ON KMT_CERTSTR_RN(KEYSTOREID, ALIAS);
CREATE INDEX IDX_CERTSTRRN_02 ON KMT_CERTSTR_RN(UUID);

CREATE INDEX KMT_CERTSTR_RN_DEVTYPE_IDX ON KMT_CERTSTR_RN (UUID ASC, DEVICE_TYPE_ID ASC);


-- table store data about groupings of TKLM entities.
--GROUPTYPE: 1=key, 2=device
CREATE TABLE KMT_GROUP (
    UUID VARCHAR(64) NOT NULL,
    GROUPTYPE SMALLINT NOT NULL,
    GROUPNAME VARCHAR(256) NOT NULL,
    INITIALIZATIONDATE TIMESTAMP,
    ACTIVESTATEDURATION INT,
    ACTIVATIONDATE TIMESTAMP,
    LASTACTIVEMEMBER VARCHAR(256), 
    KEYCOUNT INT DEFAULT 0, 
    KEYUNUSED INT DEFAULT 0, 
    VERSION INT NOT NULL,
    DEVICE_TYPE_ID SMALLINT NOT NULL DEFAULT 0,
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_GROUP PRIMARY KEY (UUID),
    CONSTRAINT GROUP_DEVTYPE_FK FOREIGN KEY (DEVICE_TYPE_ID)
		REFERENCES KMT_DEVICE_TYPE (UUID) ON DELETE CASCADE
  )
;

CREATE UNIQUE INDEX IDX_GROUP_01 ON KMT_GROUP(GROUPNAME, GROUPTYPE);
CREATE INDEX IDX_GROUP_02 ON KMT_GROUP(KEYCOUNT);
CREATE INDEX IDX_GROUP_03 ON KMT_GROUP(KEYUNUSED);
CREATE INDEX IDX_GROUP_04 ON KMT_GROUP(GROUPTYPE);
CREATE INDEX IDX_GROUP_05 ON KMT_GROUP(LASTACTIVEMEMBER);
CREATE INDEX GRP_NAME_IDX ON KMT_GROUP(GROUPNAME);

CREATE INDEX KMT_GROUP_DEVTYPE_IDX ON KMT_GROUP (UUID ASC, DEVICE_TYPE_ID ASC);


-- table stores data about group memebers
--MEMBERTYPE: 0=subgroup, 1=key, 2=certificate, 3=device
CREATE TABLE KMT_GROUP_MEMBERS (
    GROUPID VARCHAR(64) NOT NULL,
    MEMBERID  VARCHAR(64) NOT NULL,
    MEMBERTYPE  SMALLINT NOT NULL,
    MEMSEQNO INT GENERATED ALWAYS AS IDENTITY (MINVALUE -2147483648 INCREMENT BY 1),
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_GR_MEMB_ID PRIMARY KEY (GROUPID, MEMBERID),
    CONSTRAINT GROUP_MEMBERS_FK1 FOREIGN KEY (GROUPID)
		REFERENCES KMT_GROUP (UUID) ON DELETE CASCADE
  )
 ;

CREATE INDEX IDX_KMT_GROUP_MEMBERS_01 ON KMT_GROUP_MEMBERS(GROUPID) ;
CREATE INDEX IDX_KMT_GROUP_MEMBERS_02 ON KMT_GROUP_MEMBERS(MEMBERID) ;
CREATE INDEX IDX_KMT_GROUP_MEMBERS_03 ON KMT_GROUP_MEMBERS(MEMSEQNO) ;
CREATE INDEX IDX_KMT_GROUP_MEMBERS_04 ON KMT_GROUP_MEMBERS(MEMBERTYPE) ;


CREATE TABLE KMT_TEMPL (
    UUID VARCHAR(64) NOT NULL,
    TEMPLNAME VARCHAR(256),
    TYPE VARCHAR(64),
    APPNAME VARCHAR(256),
    TEMPL VARCHAR(7072),
    VERSION INT NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_TEMPL PRIMARY KEY(UUID)
  )
;


CREATE INDEX IDX_TEMPL_01 on KMT_TEMPL(TEMPLNAME) ;
CREATE INDEX IDX_TEMPL_02 on KMT_TEMPL(TYPE) ;
CREATE INDEX IDX_TEMPL_03 On KMT_TEMPL(APPNAME) ;

-- table store metadata about devices.
-- 0 for UNKNOWN, 1 - JAG 2 - LTO-4
-- no known attribute is unique
CREATE TABLE KMT_DEVICE (
    UUID VARCHAR(64) NOT NULL,
    DEVICETYPE SMALLINT,
    SERIALNO VARCHAR(256) NOT NULL,
    WWN VARCHAR(128) NOT NULL,
    SYMALIAS VARCHAR(256),
    DEVICECERT BYTEA,
    KEYALIAS1 VARCHAR(256),
    KEYALIAS2 VARCHAR(256),
    DESCRIPTION VARCHAR(256),
    VERSION INT NOT NULL,
	DEVICETEXT VARCHAR(256),
	DEVICEPENDING SMALLINT,
	DEVICEPENDINGDATE TIMESTAMP,
	ORIGDEVICETYPE SMALLINT,
	LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT PK_DEV PRIMARY KEY (UUID)
  )
;

CREATE UNIQUE INDEX IDX_DEVICE_01 On KMT_DEVICE(SERIALNO) ;


CREATE TABLE KMT_DEVAUDIT (
    UUID VARCHAR(64) NOT NULL, 
    SERIALNO VARCHAR(64),
    VOLSERIALNO VARCHAR(128),
    WWN VARCHAR(128),
    KEYALIAS1 VARCHAR(256),
    KEYALIAS2 VARCHAR(256),
    TIME_STAMP TIMESTAMP,
    DKI VARCHAR(128),
    EXTATTR VARCHAR(2800),
    DEVICE_TYPE_NAME VARCHAR(64) DEFAULT 'UNSET',
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    KMIP_CLIENT_CERT_UUID VARCHAR (64),
    CONSTRAINT PK_DEVAUDIT PRIMARY KEY (UUID)
  )
;
CREATE INDEX KMT_DEVAUDIT_DEVTYPENAME_IDX ON KMT_DEVAUDIT (DEVICE_TYPE_NAME);
CREATE INDEX IDX_DEVAUDIT_01 ON KMT_DEVAUDIT(SERIALNO);
CREATE INDEX IDX_DEVAUDIT_02 ON KMT_DEVAUDIT(VOLSERIALNO);
CREATE INDEX IDX_DEVAUDIT_03 ON KMT_DEVAUDIT(KMIP_CLIENT_CERT_UUID);


----------------------------BEGIN SCHEDULER------------------------------------------------

CREATE TABLE KMT_SCH_TASK (TASKID DECIMAL(19) PRIMARY KEY NOT NULL ,
              VERSION VARCHAR(5) NOT NULL ,
              ROW_VERSION INTEGER NOT NULL ,
              TASKTYPE INTEGER NOT NULL ,
              TASKSUSPENDED SMALLINT NOT NULL ,
              CANCELLED SMALLINT NOT NULL ,
              NEXTFIRETIME DECIMAL(19) NOT NULL ,
              STARTBYINTERVAL VARCHAR(254) ,
              STARTBYTIME DECIMAL(19) ,
              VALIDFROMTIME DECIMAL(19) ,
              VALIDTOTIME DECIMAL(19) ,
              REPEATINTERVAL VARCHAR(254) ,
              MAXREPEATS INTEGER NOT NULL ,
              REPEATSLEFT INTEGER NOT NULL ,
              TASKINFO BYTEA ,
              NAME VARCHAR(1024) NOT NULL ,
              AUTOPURGE INTEGER NOT NULL ,
              FAILUREACTION INTEGER ,
              MAXATTEMPTS INTEGER ,
              QOS INTEGER ,
              PARTITIONID INTEGER ,
              OWNERTOKEN VARCHAR(200) NOT NULL ,
              CREATETIME DECIMAL(19) NOT NULL,
			  LAST_UPDATE_TIMESTAMP TIMESTAMP) ;


CREATE INDEX KMT_SCH_TASK_IDX1 ON KMT_SCH_TASK (TASKID,
              OWNERTOKEN) ;

CREATE INDEX KMT_SCH_TASK_IDX2 ON KMT_SCH_TASK (NEXTFIRETIME ASC,
               REPEATSLEFT,
               PARTITIONID) ;

CREATE INDEX KMT_SCH_TASK_IDX3 ON KMT_SCH_TASK(NAME) ;

CREATE TABLE KMT_SCH_TREG (REGKEY VARCHAR(254) NOT NULL ,
              REGVALUE VARCHAR(254),
	      PRIMARY KEY (REGKEY)
	      );


CREATE TABLE KMT_SCH_LMGR (LEASENAME VARCHAR(254) PRIMARY KEY NOT NULL,
               LEASEOWNER VARCHAR(254) NOT NULL,
               LEASE_EXPIRE_TIME  DECIMAL(19),
              DISABLED VARCHAR(5));

CREATE TABLE KMT_SCH_LMPR (LEASENAME VARCHAR(254) NOT NULL,
              NAME VARCHAR(254) NOT NULL,
              VALUE VARCHAR(254) NOT NULL);

CREATE INDEX KMT_SCH_LMPR_IDX1 ON KMT_SCH_LMPR (LEASENAME,
               NAME);

------------------------------ END SCHEDULER -----------------------------------------------

------------------------------- START V2 UPDATES -------------------------------------------------

------------------------------- START DEVICE TYPE RELATED UPDATES --------------------------------

CREATE TABLE KMT_DEVICE_TYPE_ATTRIBUTES (
		ATTR_NAME VARCHAR(256) NOT NULL,
		ATTR_VALUE VARCHAR(2048) NOT NULL,
		DEVICE_TYPE_ID SMALLINT NOT NULL,
		UUID VARCHAR(64) NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT DEVTYPE_ATTRS_PK PRIMARY KEY (UUID),
                CONSTRAINT DEVTYPE_FK FOREIGN KEY (DEVICE_TYPE_ID)
				REFERENCES KMT_DEVICE_TYPE (UUID) ON DELETE CASCADE
	);

CREATE INDEX DEVTYPE_ATTRNAME_IDX ON KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME ASC, DEVICE_TYPE_ID ASC);




------------------------------- END DEVICE TYPE RELATED UPDATES --------------------------------

------------------------------- START MACHINE AFFINITY UPDATES --------------------------------

CREATE TABLE KMT_MACHINE (
    UUID VARCHAR(64) NOT NULL,
    MACHINEID VARCHAR(64) NOT NULL,
    DESCRIPTION VARCHAR(256),
    MACHINETEXT VARCHAR (256),
	FAMILYTYPE SMALLINT,
	VERSION INTEGER NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT PK_MACHINE_ID PRIMARY KEY (UUID)
  )
  ;
 

CREATE UNIQUE INDEX IDX_MACHINE_01 On KMT_MACHINE(MACHINEID, MACHINETEXT) ;

CREATE TABLE KMT_MACHINE_DEVICE (
    DEVICEID VARCHAR(64) NOT NULL,
    MACHINEID  VARCHAR(64) NOT NULL,
    PENDING_DATE TIMESTAMP,
	PENDINGAUTO SMALLINT,
	VERSION INTEGER NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT PK_MACHE_DEV_ID PRIMARY KEY (DEVICEID, MACHINEID),
	CONSTRAINT MACHINE_DEVICE_FK1 FOREIGN KEY (DEVICEID)
				   REFERENCES KMT_DEVICE (UUID),
	CONSTRAINT MACHINE_DEVICE_FK2 FOREIGN KEY (MACHINEID)
				   REFERENCES KMT_MACHINE (UUID)
  )	
  ;
 

------------------------------- END MACHINE AFFINITY UPDATES --------------------------------

------------------------------- START KMIP RELATED UPDATES --------------------------------
CREATE TABLE KMT_KMIP_ATTR_APPINFO (
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		APP_NAMESPACE VARCHAR(1024) NOT NULL,
		APP_INFO VARCHAR(2048) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT KMT_APPINFO_PK PRIMARY KEY (MANAGED_OBJECT_UUID, INDEX_ID)
	)
	 ;
CREATE INDEX KMT_KMIP_ATTR_APPINFO_IDX ON KMT_KMIP_ATTR_APPINFO (MANAGED_OBJECT_UUID);

CREATE TABLE KMT_KMIP_ATTR_CERTSUBJECT (
		CERT_UUID VARCHAR(64) NOT NULL,
		ALTERNATIVE_NAME VARCHAR(1024),
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT FK_CERT FOREIGN KEY (CERT_UUID)
			REFERENCES KMT_CERT (UUID) ON DELETE CASCADE,
		CONSTRAINT KMT_CERTSUB_PK PRIMARY KEY (CERT_UUID, INDEX_ID)
	)
	;

CREATE TABLE KMT_KMIP_ATTR_CERTISSUER (
		CERT_UUID VARCHAR(64) NOT NULL,
		ALTERNATIVE_NAME VARCHAR(1024),
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT FK_CERT FOREIGN KEY (CERT_UUID)
			REFERENCES KMT_CERT (UUID) ON DELETE CASCADE,
		CONSTRAINT KMT_CERTISS_PK PRIMARY KEY (CERT_UUID, INDEX_ID)
	)
	 ;

CREATE TABLE KMT_KMIP_ATTR_CRYPTOPARAMS (
		BLOCK_CIPHER_MODE INTEGER,
		PADDING_METHOD INTEGER,
		HASHING_ALGORITHM INTEGER,
		ROLE_TYPE INTEGER,
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CRYPTOGRAPHIC_ALGORITHM INTEGER,
                SALT_LENGTH INTEGER,
                P_SOURCE VARCHAR(256),
                MASK_GENERATOR_HASHING_ALGO INTEGER,
                MASK_GENERATOR INTEGER,
                TAG_LENGTH INTEGER,
		RANDOM_IV SMALLINT,
		CONSTRAINT PK_CRYPTOPARAMS PRIMARY KEY (MANAGED_OBJECT_UUID, INDEX_ID)
	)
	 ;

CREATE INDEX KMT_KMIP_ATTR_CRYPTOPARAMS_IDX ON KMT_KMIP_ATTR_CRYPTOPARAMS (MANAGED_OBJECT_UUID);

CREATE TABLE KMT_KMIP_ATTR_CUSTOM (
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		TYPE INTEGER,
		ATTR_NAME VARCHAR(1024) NOT NULL,
		ATTR_VALUE VARCHAR(2048) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT PK_CUSTOMATTR PRIMARY KEY (MANAGED_OBJECT_UUID, ATTR_NAME, INDEX_ID)
	)
 ;

CREATE INDEX KMT_KMIP_ATTR_CUSTOM_IDX ON KMT_KMIP_ATTR_CUSTOM (MANAGED_OBJECT_UUID);

CREATE TABLE KMT_KMIP_ATTR_DIGEST (
		HASHING_ALGORITHM INTEGER NOT NULL,
		DIGEST_VALUE VARCHAR(1024) NOT NULL,
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		KEY_FORMAT SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT PK_DIGEST PRIMARY KEY (MANAGED_OBJECT_UUID, INDEX_ID)
	)
	;
CREATE INDEX KMT_KMIP_ATTR_DIGEST_IDX ON KMT_KMIP_ATTR_DIGEST (MANAGED_OBJECT_UUID);

CREATE TABLE KMT_KMIP_ATTR_LINK (
		LINK_TARGET_OBJECT_UUID VARCHAR(64) NOT NULL,
		LINK_TYPE INTEGER NOT NULL,
		LINK_SOURCE_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT PK_LINK PRIMARY KEY (LINK_SOURCE_OBJECT_UUID, INDEX_ID)
	);

CREATE INDEX KMT_KMIP_ATTR_LINK_IDX1 ON KMT_KMIP_ATTR_LINK (LINK_TARGET_OBJECT_UUID);
CREATE INDEX KMT_KMIP_ATTR_LINK_IDX2 ON KMT_KMIP_ATTR_LINK (LINK_SOURCE_OBJECT_UUID);

CREATE TABLE KMT_KMIP_GLOBAL_NAMES (                
		NAME_TYPE INTEGER NOT NULL,
		NAME_VALUE VARCHAR(512) NOT NULL,
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
        NAME_UUID VARCHAR(64) NOT NULL,
        LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT KMT_KMIP_GN_PK PRIMARY KEY (NAME_UUID),
	CONSTRAINT UNQ_NAME UNIQUE (NAME_VALUE, NAME_TYPE)
  )
 ;
CREATE INDEX KMT_KMIP_GLOBAL_NAMES_IDX ON KMT_KMIP_GLOBAL_NAMES (MANAGED_OBJECT_UUID);

CREATE TABLE KMT_KMIP_ATTR_NAME (                
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
        NAME_UUID VARCHAR(64) NOT NULL,
        LAST_UPDATE_TIMESTAMP TIMESTAMP,
        CONSTRAINT UNQ_INSTANCE UNIQUE (MANAGED_OBJECT_UUID, INDEX_ID),
	CONSTRAINT FK FOREIGN KEY (NAME_UUID) 
			REFERENCES KMT_KMIP_GLOBAL_NAMES (NAME_UUID) ON DELETE CASCADE
  )
 ;
CREATE INDEX KMT_KMIP_ATTR_NAME_IDX ON KMT_KMIP_ATTR_NAME (MANAGED_OBJECT_UUID);
CREATE INDEX KMT_KMIP_ATTR_NAME_IDX2 ON KMT_KMIP_ATTR_NAME (NAME_UUID);

CREATE TABLE KMT_KMIP_ATTR_OBJECTGROUP (
		GROUP_NAME VARCHAR(512) NOT NULL,
		MEMBER_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT PK_OBJGROUP PRIMARY KEY (MEMBER_OBJECT_UUID, INDEX_ID)
	)
	;
CREATE INDEX KMT_KMIP_ATTR_OBJECTGROUP_IDX ON KMT_KMIP_ATTR_OBJECTGROUP (MEMBER_OBJECT_UUID);

-- KMIP 1.2 addition
CREATE TABLE KMT_KMIP_ATTR_ALTERNATIVE_NAME (
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		ALTERNATIVE_NAME VARCHAR(512) NOT NULL,
		TYPE SMALLINT NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT PK_ALTNAME PRIMARY KEY (MANAGED_OBJECT_UUID, INDEX_ID)
	)
 ;

CREATE INDEX KMT_KMIP_ATTR_ALTERNATIVE_NAME_IDX ON KMT_KMIP_ATTR_ALTERNATIVE_NAME (MANAGED_OBJECT_UUID);
CREATE INDEX KMT_KMIP_ATTR_ALTERNATIVE_NAME_IDX2 ON KMT_KMIP_ATTR_ALTERNATIVE_NAME (ALTERNATIVE_NAME);
CREATE INDEX KMT_KMIP_ATTR_ALTERNATIVE_NAME_IDX3 ON KMT_KMIP_ATTR_ALTERNATIVE_NAME (TYPE);
-- end of KMIP 1.2 addition

-- outplan ?
CREATE TABLE KMT_KMIP_OBJECT_OPAQUE (
		UUID VARCHAR(64) NOT NULL,
		ARCHIVE_DATE TIMESTAMP,
		LAST_CHANGED_DATE TIMESTAMP,
		INITIAL_DATE TIMESTAMP NOT NULL,
		DESTROYDATE TIMESTAMP,
		ACTIVATIONDATE TIMESTAMP,
		DATA BYTEA,
		LARGE_DATA BYTEA,
		CONTACT_INFO VARCHAR(1024),
		VERSION INT NOT NULL,	
		OPERATIONAL_POLICY VARCHAR(64),
		USAGE_VALUE DECIMAL(18,0),
		USAGE_TOTAL DECIMAL(18,0),
		USAGE_LIMIT_TYPE SMALLINT,
		OWNER VARCHAR(128),
		ORIGINAL_CREATION_DATE TIMESTAMP,	
		OPAQUE_DATA_TYPE INTEGER NOT NULL DEFAULT 0,
		LEASE_TIME INTEGER,
		DEACTIVATION_DATE TIMESTAMP,
		COMPROMISE_OCCURRENCE_DATE TIMESTAMP,
		COMPROMISE_DATE TIMESTAMP,
		REVOKE_REASON_CODE INTEGER,
		REVOKE_REASON_MESSAGE VARCHAR(2048),
		DEVICE_TYPE_ID SMALLINT,
		CREATED_BY VARCHAR(128),
		CONSTRAINT PK_OBJ_OPAQUE PRIMARY KEY (UUID)
	)
	 ;
CREATE INDEX IDX_OPQOBJ_01 ON KMT_KMIP_OBJECT_OPAQUE(INITIAL_DATE) ;
CREATE INDEX IDX_OPQOBJ_02 ON KMT_KMIP_OBJECT_OPAQUE (ACTIVATIONDATE) ;
CREATE INDEX IDX_OPQOBJ_03 ON KMT_KMIP_OBJECT_OPAQUE (DESTROYDATE) ;
CREATE INDEX IDX_OPQOBJ_04 ON KMT_KMIP_OBJECT_OPAQUE (OWNER) ;
CREATE INDEX IDX_OPQOBJ_05 ON KMT_KMIP_OBJECT_OPAQUE (ORIGINAL_CREATION_DATE) ;

CREATE TABLE KMT_KMIP_OBJECT_SECRET_DATA (
		UUID VARCHAR(64) NOT NULL,
		TYPE INT NOT NULL,
		CRYPTO_LENGTH INTEGER,			
		ACTIVATIONDATE TIMESTAMP,
		DEACTIVATION_DATE TIMESTAMP,		
		ARCHIVE_DATE TIMESTAMP,
		INITIAL_DATE TIMESTAMP NOT NULL,
		LAST_CHANGED_DATE TIMESTAMP NOT NULL,
		DESTROYDATE TIMESTAMP,
		COMPROMISE_OCCURRENCE_DATE TIMESTAMP,
		COMPROMISEDATE TIMESTAMP,
		REVOKE_REASON_CODE INTEGER,
		REVOKE_REASON_MESSAGE VARCHAR(2048),
		CONTACT_INFO VARCHAR(1024),
		ALIAS VARCHAR(256) NOT NULL, 
		KEYPASSWORD VARCHAR(32600),
		KEYSTORE_UUID VARCHAR(64) NOT NULL,
		VERSION INT NOT NULL,	
		OPERATIONAL_POLICY VARCHAR(64),
		OWNER VARCHAR(128),
		LEASE_TIME INTEGER,
		PREVSTATE INTEGER,
		FORMAT SMALLINT,
		CRYPTO_USAGE VARCHAR(32),
		ORIGINAL_CREATION_DATE TIMESTAMP,
		DEVICE_TYPE_ID SMALLINT,
		CREATED_BY VARCHAR(128),
		CONSTRAINT PK_SECDATA PRIMARY KEY (UUID),
		CONSTRAINT FK_KS_UUID FOREIGN KEY (KEYSTORE_UUID)
				REFERENCES KMT_KEYSTR (UUID) ON DELETE RESTRICT,
		CONSTRAINT UN_SECDATA_1 UNIQUE (KEYSTORE_UUID,ALIAS)
	)
;
CREATE INDEX IDX_SECDATA_01 ON KMT_KMIP_OBJECT_SECRET_DATA (INITIAL_DATE) ;
CREATE INDEX IDX_SECDATA_02 ON KMT_KMIP_OBJECT_SECRET_DATA (DEACTIVATION_DATE) ;
CREATE INDEX IDX_SECDATA_03 ON KMT_KMIP_OBJECT_SECRET_DATA (ACTIVATIONDATE) ;
CREATE INDEX IDX_SECDATA_04 ON KMT_KMIP_OBJECT_SECRET_DATA (COMPROMISEDATE) ;
CREATE INDEX IDX_SECDATA_05 ON KMT_KMIP_OBJECT_SECRET_DATA (DESTROYDATE) ;
CREATE INDEX IDX_SECDATA_06 ON KMT_KMIP_OBJECT_SECRET_DATA (LEASE_TIME) ;
CREATE INDEX IDX_SECDATA_07 ON KMT_KMIP_OBJECT_SECRET_DATA (OWNER) ;
CREATE INDEX IDX_SECDATA_08 ON KMT_KMIP_OBJECT_SECRET_DATA (REVOKE_REASON_CODE) ;
CREATE INDEX IDX_SECDATA_09 ON KMT_KMIP_OBJECT_SECRET_DATA (ALIAS) ;
CREATE INDEX IDX_SECDATA_10 ON KMT_KMIP_OBJECT_SECRET_DATA (PREVSTATE) ;
CREATE INDEX IDX_SECDATA_11 ON KMT_KMIP_OBJECT_SECRET_DATA (CRYPTO_USAGE) ;
CREATE INDEX IDX_SECDATA_12 ON KMT_KMIP_OBJECT_SECRET_DATA (ORIGINAL_CREATION_DATE) ;

CREATE TABLE KMT_KMIP_OBJECT_TEMPLATE (
		UUID VARCHAR(64) NOT NULL,
		ALGORITHM VARCHAR(512),
		CRYPTO_LENGTH INTEGER,
		CONTACT_INFO VARCHAR(1024),
		INITIAL_DATE TIMESTAMP NOT NULL,
		ACTIVATIONDATE TIMESTAMP,
		DESTROYDATE TIMESTAMP,
		ARCHIVE_DATE TIMESTAMP,
		LAST_CHANGED_DATE TIMESTAMP NOT NULL,
		CRYPTO_USAGE VARCHAR(32),
		PROCESS_START_DATE TIMESTAMP,
		PROTECT_STOP_DATE TIMESTAMP,
		DEACTIVATION_DATE TIMESTAMP,
		VERSION INT NOT NULL,
		USAGE_VALUE DECIMAL(18,0),
		USAGE_TOTAL DECIMAL(18,0),
		USAGE_LIMIT_TYPE SMALLINT,		
		OWNER VARCHAR(128),
		OPERATIONAL_POLICY VARCHAR(64),
-- new field                
		BODY_UUID VARCHAR(64),
		ORIGINAL_CREATION_DATE TIMESTAMP,
		CONSTRAINT PK_TEMPLATE PRIMARY KEY (UUID)
	)
 ;
CREATE INDEX IDX_TMPL_01 ON KMT_KMIP_OBJECT_TEMPLATE (INITIAL_DATE) ;
CREATE INDEX IDX_TMPL_02 ON KMT_KMIP_OBJECT_TEMPLATE (DEACTIVATION_DATE) ;
CREATE INDEX IDX_TMPL_03 ON KMT_KMIP_OBJECT_TEMPLATE (ACTIVATIONDATE) ;
CREATE INDEX IDX_TMPL_04 ON KMT_KMIP_OBJECT_TEMPLATE (DESTROYDATE) ;
CREATE INDEX IDX_TMPL_05 ON KMT_KMIP_OBJECT_TEMPLATE (ALGORITHM) ;
CREATE INDEX IDX_TMPL_06 ON KMT_KMIP_OBJECT_TEMPLATE (CRYPTO_LENGTH) ;
CREATE INDEX IDX_TMPL_07 ON KMT_KMIP_OBJECT_TEMPLATE (OWNER) ;
CREATE INDEX IDX_TMPL_08 ON KMT_KMIP_OBJECT_TEMPLATE (PROCESS_START_DATE) ;
CREATE INDEX IDX_TMPL_09 ON KMT_KMIP_OBJECT_TEMPLATE (PROTECT_STOP_DATE) ;
CREATE INDEX IDX_TMPL_10 ON KMT_KMIP_OBJECT_TEMPLATE (USAGE_VALUE) ;
CREATE INDEX IDX_TMPL_11 ON KMT_KMIP_OBJECT_TEMPLATE (USAGE_TOTAL) ;
CREATE INDEX IDX_TMPL_12 ON KMT_KMIP_OBJECT_TEMPLATE (USAGE_LIMIT_TYPE) ;
CREATE INDEX IDX_TMPL_13 ON KMT_KMIP_OBJECT_TEMPLATE (CRYPTO_USAGE) ;
CREATE INDEX IDX_TMPL_14 ON KMT_KMIP_OBJECT_TEMPLATE (BODY_UUID) ;
CREATE INDEX IDX_TMPL_15 ON KMT_KMIP_OBJECT_TEMPLATE (ORIGINAL_CREATION_DATE) ;

CREATE TABLE KMT_KMIP_OBJECT_TEMPLATE_BODY (
		UUID VARCHAR(64) NOT NULL,
		PARENT_UUID VARCHAR(64) NOT NULL,
		ALGORITHM VARCHAR(512),
		CRYPTO_LENGTH INTEGER,
		CONTACT_INFO VARCHAR(1024),
		INITIAL_DATE TIMESTAMP NOT NULL,
		ACTIVATIONDATE TIMESTAMP,
		DESTROYDATE TIMESTAMP,
		ARCHIVE_DATE TIMESTAMP,
		LAST_CHANGED_DATE TIMESTAMP NOT NULL,
		CRYPTO_USAGE VARCHAR(32),
		PROCESS_START_DATE TIMESTAMP,
		PROTECT_STOP_DATE TIMESTAMP,
		DEACTIVATION_DATE TIMESTAMP,
		VERSION INT NOT NULL,
		USAGE_VALUE DECIMAL(18,0),
		USAGE_TOTAL DECIMAL(18,0),
		USAGE_LIMIT_TYPE SMALLINT,		
		OWNER VARCHAR(128),
		OPERATIONAL_POLICY VARCHAR(64),
		CONSTRAINT PK_TEMPLATE_BODY PRIMARY KEY (UUID),
		CONSTRAINT FK FOREIGN KEY (PARENT_UUID) 
			REFERENCES KMT_KMIP_OBJECT_TEMPLATE (UUID) ON DELETE CASCADE
	)
 ;
CREATE INDEX IDX_TMPL_B_01 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (INITIAL_DATE) ;
CREATE INDEX IDX_TMPL_B_02 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (DEACTIVATION_DATE) ;
CREATE INDEX IDX_TMPL_B_03 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (ACTIVATIONDATE) ;
CREATE INDEX IDX_TMPL_B_04 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (DESTROYDATE) ;
CREATE INDEX IDX_TMPL_B_05 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (ALGORITHM) ;
CREATE INDEX IDX_TMPL_B_06 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (CRYPTO_LENGTH) ;
CREATE INDEX IDX_TMPL_B_07 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (OWNER) ;
CREATE INDEX IDX_TMPL_B_08 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (PROCESS_START_DATE) ;
CREATE INDEX IDX_TMPL_B_09 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (PROTECT_STOP_DATE) ;
CREATE INDEX IDX_TMPL_B_10 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (USAGE_VALUE) ;
CREATE INDEX IDX_TMPL_B_11 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (USAGE_TOTAL) ;
CREATE INDEX IDX_TMPL_B_12 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (USAGE_LIMIT_TYPE) ;
CREATE INDEX IDX_TMPL_B_13 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (CRYPTO_USAGE) ;
CREATE INDEX IDX_TMPL_B_14 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (PARENT_UUID) ;


CREATE TABLE KMT_CLIENT (
		IP_HOSTNAME VARCHAR(255),
		PORT INTEGER,
		PRI_EMAIL VARCHAR(256),
		PRI_PHONE VARCHAR(15),
		BKUP_EMAIL VARCHAR(256),
		BKUP_PHONE VARCHAR(15),
		CAPABILITIES VARCHAR(512),
		MECHANISMS VARCHAR(256),
		INFO VARCHAR(256),
		CRYPTO_USAGE VARCHAR(32),
		UUID VARCHAR(128) PRIMARY KEY NOT NULL,
		NAME VARCHAR(256),
		TYPE INTEGER NOT NULL,
		DEV_TYPE_UUID SMALLINT,
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		ADD_COL_3 VARCHAR(256),
		ADD_COL_4 VARCHAR(256),
		ADD_COL_5 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP ,
		PUUID VARCHAR(128),
		CONSTRAINT CL_FK1 FOREIGN KEY (DEV_TYPE_UUID) REFERENCES KMT_DEVICE_TYPE (UUID) ON DELETE CASCADE,
		CONSTRAINT CLIENT_PARENT_FK FOREIGN KEY (PUUID) 
					REFERENCES KMT_CLIENT (UUID) ON DELETE CASCADE
	);


CREATE TABLE KMT_CLIENT_KEY_CERT_LIST (
		CLIENT_UUID VARCHAR(128) NOT NULL,
		KEYCERT_UUID VARCHAR(128) NOT NULL,
		KEYCERT_HASH BYTEA,
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT CKL_FK1 FOREIGN KEY (CLIENT_UUID)
			  	  REFERENCES KMT_CLIENT (UUID) ON DELETE CASCADE,		  
		CONSTRAINT CKL_FK2 FOREIGN KEY (KEYCERT_UUID)
		  		  REFERENCES KMT_CERT (UUID) ON DELETE CASCADE
	);

  
CREATE INDEX IDX_CLT_KL_01 ON KMT_CLIENT_KEY_CERT_LIST (CLIENT_UUID, KEYCERT_UUID) ;
CREATE INDEX IDX_CLT_KL_02 ON KMT_CLIENT_KEY_CERT_LIST (CLIENT_UUID) ;
CREATE INDEX IDX_CLT_KL_03 ON KMT_CLIENT_KEY_CERT_LIST (KEYCERT_UUID) ;


CREATE TABLE KMT_NOTIFICATIONS (
		UUID VARCHAR(128) NOT NULL,
		CLIENT_UUID VARCHAR(128) NOT NULL,
		KEYCERT_UUID VARCHAR(128) NOT NULL,
		STATE INTEGER,
		NOTIFY_POLICY_UUID VARCHAR(128) NOT NULL,
		NUM_NOTIFY_ATTEMPTS INTEGER NOT NULL,
		NUM_NOTIFY_REMAINING INTEGER NOT NULL,
		TIMESTAMP_LAST_NOTIFY TIMESTAMP,
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		ADD_COL_3 VARCHAR(256),
		ADD_COL_4 VARCHAR(256),
		ADD_COL_5 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT NTFN_FK1 FOREIGN KEY (CLIENT_UUID)
			  REFERENCES KMT_CLIENT (UUID) ON DELETE CASCADE,
		CONSTRAINT NTFN_FK2 FOREIGN KEY (KEYCERT_UUID)
			  REFERENCES KMT_KEY (UUID) ON DELETE CASCADE,
		CONSTRAINT NTFN_FK3 FOREIGN KEY (KEYCERT_UUID)
			  REFERENCES KMT_CERT (UUID) ON DELETE CASCADE
	);


CREATE INDEX IDX_NOTIFN_01 ON KMT_NOTIFICATIONS (UUID) ;

CREATE TABLE KMT_NOTIFICATION_POLICY (
		UUID VARCHAR(128) NOT NULL,
		LONG_NOTIFY_PERIOD INTEGER,
		SHORT_NOTIFY_PERIOD INTEGER,
		PRI_NOTIFY_TYPE INTEGER,
		BKUP_NOTIFY_TYPE INTEGER,
		NUM_NOTIFY_FAILURES INTEGER,
		NUM_NOTIFY INTEGER,
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		ADD_COL_3 VARCHAR(256),
		ADD_COL_4 VARCHAR(256),
		ADD_COL_5 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	);

CREATE INDEX IDX_NOTIFN_PLCY_01 ON KMT_NOTIFICATION_POLICY (UUID) ;
		


------------------------------- END KMIP RELATED UPDATES ----------------------------------

-------------------------------- START DELL LICENSE UPDATES --------------------------------

CREATE TABLE KMT_LICENSE (
    DEVICETYPE SMALLINT NOT NULL,
    COUNT INTEGER NOT NULL, 
    CREATIONTIME TIMESTAMP NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP,
    CONSTRAINT PK_LICENSE PRIMARY KEY (DEVICETYPE)
    )
  ;


------------------------------- END DELL LICENSE UPDATES ----------------------------------
-------------------------------- START DELL BACKUP BEFORE SERVING UPDATES --------------------------------

CREATE TABLE KMT_BACKUP (
	LASTBACKUPDATE TIMESTAMP,
	LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
;

	
------------------------------- END DELL BACKUP BEFORE SERVING UPDATES ----------------------------------
------------------------------- END V2 UPDATES -------------------------------------------------


------------------------------------------------------ V2.6 update  ---------------------------------------



CREATE TABLE KMT_OBJECT (
		UUID VARCHAR(128) PRIMARY KEY NOT NULL,
		PUUID VARCHAR(128),
		NAME VARCHAR(512),
		TYPE INTEGER NOT NULL,
		TYPE_TABLE VARCHAR(128),		
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		ADD_COL_3 VARCHAR(256),
		ADD_COL_4 VARCHAR(256),
		ADD_COL_5 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT COBJ_PARENT_FK FOREIGN KEY (PUUID)
			  REFERENCES KMT_OBJECT (UUID) ON DELETE CASCADE
	);


CREATE TABLE KMT_OBJECT_CLIENT_RN (
		CLIENT_UUID VARCHAR(128) NOT NULL,
		OBJECT_UUID VARCHAR(128) NOT NULL,
		USED INTEGER,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT COBJ_CLI_RN_CLI_FK1 FOREIGN KEY (CLIENT_UUID)
				  REFERENCES KMT_CLIENT (UUID) ON DELETE CASCADE,
		CONSTRAINT COBJ_CLI_RN_OBJ_FK1 FOREIGN KEY (OBJECT_UUID)
				  REFERENCES KMT_OBJECT (UUID) ON DELETE CASCADE,
		CONSTRAINT PK_OBJCLIRN  PRIMARY KEY (CLIENT_UUID, OBJECT_UUID)
		);



------------------------------------------------------ V2.7 update  ---------------------------------------



CREATE TABLE KMT_KMIP_CLIENT_ENCRYPT_DECRYPT (
		CLIENT_UUID VARCHAR(128),
		KEY_UUID VARCHAR(64) NOT NULL,
		IV_FLAG INTEGER NOT NULL,
		OPERATION INTEGER,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT KEY_PARENT_FK FOREIGN KEY (KEY_UUID)
			  REFERENCES KMT_KEY (UUID) ON DELETE CASCADE,
		CONSTRAINT CLIENT_PARENT_FK FOREIGN KEY (CLIENT_UUID)
			  REFERENCES KMT_CLIENT (UUID) ON DELETE CASCADE
		);
		

CREATE TABLE KMT_KEY_GROUPS (                
		UUID VARCHAR(64) PRIMARY KEY NOT NULL,
        NAME VARCHAR(256) NOT NULL,
		KEY_GROUP_TYPE SMALLINT NOT NULL,
		REF_IDENTIFIER VARCHAR(256),
		DESCRIPTION VARCHAR(512),
        LAST_UPDATE_TIMESTAMP TIMESTAMP 
  );
  
 CREATE TABLE KMT_KEY_GROUP_MEMBERS (                
		GROUP_ID VARCHAR(64) NOT NULL,
        MEMBER_TYPE SMALLINT NOT NULL,
		MEMBER_ID VARCHAR(256) NOT NULL,
        LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT GROUP_ID_FK FOREIGN KEY (GROUP_ID) 
				REFERENCES KMT_KEY_GROUPS (UUID) ON DELETE CASCADE,	    
	CONSTRAINT MEMBER_ID_FK FOREIGN KEY (MEMBER_ID) 
				REFERENCES KMT_KEY_GROUPS (UUID) ON DELETE CASCADE,	    
	CONSTRAINT PK_KEYGRPMEM  PRIMARY KEY (GROUP_ID,MEMBER_ID)
  );
  


CREATE TABLE KMT_CFGT_INSTDETAILS(
	INPUTSEED BIGINT NOT NULL,
	INSTANCEID VARCHAR(64) NOT NULL,
	GENERATEDTIME TIMESTAMP NOT NULL);
	
CREATE TABLE KMT_ALIAS_HANDLE(
	HANDLE_ID VARCHAR(64) NOT NULL,
	PREFIX VARCHAR(8) NOT NULL,
	INSTANCE_ID VARCHAR(64) NOT NULL,
	COUNTER_OFFSET BIGINT NOT NULL,
        LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT UQ_PREFIX UNIQUE (PREFIX,INSTANCE_ID)
	);

CREATE TABLE KMT_CONFLICT_CHANGES (
	UUID VARCHAR(64)  PRIMARY KEY NOT NULL,
	OBJECT_TYPE SMALLINT NOT NULL,
	CHANGE_TYPE SMALLINT NOT NULL,
	OLD_VALUE VARCHAR(512) NOT NULL,
	NEW_VALUE VARCHAR(512) NOT NULL,
	CHANGED_TIME TIMESTAMP NOT NULL );
	
CREATE TABLE KMT_EXPORT_KEYGROUP_SUMMARY (
		EXPORT_UUID VARCHAR(64) NOT NULL,
		START_TIME TIMESTAMP NOT NULL,
        END_TIME TIMESTAMP,
		OPERATION SMALLINT NOT NULL,
		STATUS SMALLINT NOT NULL,
		TARGET_EXPECTED INTEGER,
		TARGET_COMPLETED INTEGER,
		SUMMARY TEXT,
		FILE_NAME VARCHAR(512),
		DEVICE_TYPE VARCHAR(128),
		DESCRIPTION VARCHAR(512),
        LAST_UPDATE_TIMESTAMP TIMESTAMP 
  );
  CREATE TABLE KMT_MM_INSTANCE (
		INSTANCE_ID VARCHAR(64) NOT NULL,
		NAME VARCHAR(255) NOT NULL,
		CLUSTER_NAME VARCHAR(255),
		IP_HOSTNAME VARCHAR(255) NOT NULL,
		TCP_PORT INTEGER NOT NULL,
		HTTP_PORT INTEGER NOT NULL,
		ADMIN_PORT INTEGER NOT NULL,
		SSL_PORT INTEGER NOT NULL,
		KMIP_PORT INTEGER NOT NULL,
		DB_PORT INTEGER NOT NULL,
		HADR_PORT INTEGER,
		AGENT_PORT INTEGER NOT NULL,
		HADR_TYPE SMALLINT NOT NULL DEFAULT 0,
		INSTANCE_TYPE SMALLINT NOT NULL DEFAULT 0,
		STATUS SMALLINT NOT NULL DEFAULT 0,
		DB_NAME VARCHAR(255) NOT NULL,
		DB_USERNAME VARCHAR(255) NOT NULL,
		DB_PASSWORD VARCHAR(255) NOT NULL,
		SKLM_USERNAME VARCHAR(255) NOT NULL,
		SKLM_PASSWORD VARCHAR(255) NOT NULL,
		WAS_USERNAME VARCHAR(255) NOT NULL,
		WAS_PASSWORD VARCHAR(255) NOT NULL,
		AGENT_KEYSTORE_PASSWORD VARCHAR(255) NOT NULL,
		STANDBY_PRIORITY_INDEX SMALLINT,
		ACTING_PRIMARY SMALLINT NOT NULL DEFAULT 0,
		IS_FAULTY SMALLINT NOT NULL DEFAULT 0,
		IS_SERVER_RESTART_REQUIRED SMALLINT NOT NULL DEFAULT 0,
		OWNER_EMAIL_ADDR1 VARCHAR(255),
		OWNER_EMAIL_ADDR2 VARCHAR(255),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT UNIQUE_INSTANCE_ID UNIQUE (INSTANCE_ID),
		CONSTRAINT UNIQUE_IP_HOSTNAME UNIQUE (IP_HOSTNAME)
	)
	;
	

	CREATE TABLE KMT_MM_INSTANCE_STATUS (
		INSTANCE_ID VARCHAR(64) NOT NULL,
		TIME TIMESTAMP NOT NULL,
		SERVICE VARCHAR(64) NOT NULL,
		TCP_PORT_STATUS SMALLINT,
		HTTP_PORT_STATUS SMALLINT,
		ADMIN_PORT_STATUS SMALLINT,
		SSL_PORT_STATUS SMALLINT,
		KMIP_PORT_STATUS SMALLINT,
		DB_PORT_STATUS SMALLINT,
		HADR_PORT_STATUS SMALLINT,
		AGENT_PORT_STATUS SMALLINT,
		NOTIFICATION_SENT_TIME VARCHAR(255),
		NOTIFICATION_SENT_T0 VARCHAR(255),
		AGENTS_REACHABLE VARCHAR(2048),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		HADR_STATUS VARCHAR(512),
		CONSTRAINT INSTANCE_ID_FK FOREIGN KEY (INSTANCE_ID) 
			REFERENCES KMT_MM_INSTANCE (INSTANCE_ID) ON DELETE CASCADE
	)
;
	
		
CREATE TABLE KMT_MM_AGENT_TRUSTSTORE  (
		INSTANCE_ID VARCHAR(64) NOT NULL,
		ALIAS_NAME VARCHAR(255) NOT NULL,
		KEY_DATA  BYTEA NOT NULL,
		TRUSTED SMALLINT NOT NULL DEFAULT 1,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT UNIQUE_INSTANCE_TT_ID UNIQUE (INSTANCE_ID, ALIAS_NAME)
	)
;


CREATE TABLE KMT_KMIP_WRAPDATA (
	MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
	MACSIGN_KEY_UUID VARCHAR(64),
	WRAP_KEY_UUID VARCHAR(64),
	BLOCK_CIPHER_MODE INTEGER,
	PADDING_METHOD INTEGER,
	HASHING_ALGORITHM INTEGER,
	WRAPPING_METHOD INTEGER,
	ENCODING_OPTIONS INTEGER,
	MAC_SIGNATURE BYTEA,
	RANDOM_IV BYTEA,
	LAST_UPDATE_TIMESTAMP TIMESTAMP,
	foreign key(MANAGED_OBJECT_UUID) references KMT_KEY(UUID),
	foreign key(MACSIGN_KEY_UUID) references KMT_KEY(UUID),
	foreign key(WRAP_KEY_UUID) references KMT_KEY(UUID),
	CONSTRAINT PK_WRAPDATA  PRIMARY KEY (MANAGED_OBJECT_UUID)
)
;

CREATE TABLE KMT_CHANGESET_TRACK (
	OBJECT_TYPE VARCHAR(64),
	NAME VARCHAR(64),
	UUID VARCHAR(64),
	REF_TABLE_NAME  VARCHAR(64) NOT NULL,    
	REF_UUID  VARCHAR(64),
	REF_NAME_ALIAS  VARCHAR(512),
	OPERATION_TYPE  SMALLINT NOT NULL,
	CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
	LAST_UPDATE_TIMESTAMP  TIMESTAMP NOT NULL,
	REF_OBJECT_MAP BYTEA
)
;

CREATE TABLE KMT_KMIP_ATTR_HSMATTRIBUTES (
	MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
	OBJECT_TYPE VARCHAR(64),
	SENSITIVE SMALLINT,
	ALWAYS_SENSITIVE SMALLINT,
	EXTRACTABLE SMALLINT,
	NEVER_EXTRACTABLE SMALLINT,
	PKCS12_FRIENDLY_NAME VARCHAR(64),
	SHORT_UNIQUE_IDENTIFIER VARCHAR(64),
	LAST_UPDATE_TIMESTAMP TIMESTAMP NOT NULL
)
;

CREATE TABLE KMT_DEVICE_TYPE_MASTER_KEY (
	UUID VARCHAR(64) PRIMARY KEY NOT NULL,
	ALIAS VARCHAR(256) UNIQUE NOT NULL,
	KEY_ALGO VARCHAR(64) NOT NULL,
	KEY_SIZE INT NOT NULL,
	KEY_DATA BYTEA NOT NULL,
	ROTATION_PERIOD_DAYS INT NOT NULL,
	CREATION_DATE TIMESTAMP NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP NOT NULL
  )
;


CREATE TABLE KMT_MASTER_KEY_MGMT (
	SRNO INT GENERATED ALWAYS AS IDENTITY (START WITH 1 INCREMENT BY 1) PRIMARY KEY NOT NULL,
	OPERATION INT NOT NULL,
	FROM_STORE INT NOT NULL,
	TO_STORE INT NOT NULL,
	STATUS  INT NOT NULL,
	STARTED_ON_HOST VARCHAR(256) NOT NULL,
	STARTED_BY_USER VARCHAR(256) NOT NULL,
	MASTER_KEY_SIZE INT NOT NULL,
	TABLES_PROCESSED VARCHAR(1024),
	DESCRIPTION VARCHAR(256),
	CREATION_DATE TIMESTAMP NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP NOT NULL
  )
;


CREATE TABLE KMT_CLIENT_POLICY (
		UUID VARCHAR(64) NOT NULL,
		OPERATION VARCHAR(64),
		TYPE_OF_OBJECT VARCHAR(64),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT PK_CLIENT_POLICY PRIMARY KEY (UUID)
	)
;

CREATE TABLE KMT_CLIENT_POLICY_ACCESS (
		CLIENT_UUID VARCHAR(64),
		CLIENT_POLICY_UUID VARCHAR(64) NOT NULL,
		TYPE_OF_ENTITY VARCHAR(64) NOT NULL,
		ENTITY_REF VARCHAR(64),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT FK1_CLIENT_POLICY_ACCESS FOREIGN KEY (CLIENT_UUID)
					REFERENCES KMT_CLIENT (UUID) ON DELETE CASCADE,
		CONSTRAINT FK2_CLIENT_POLICY_ACCESS FOREIGN KEY (CLIENT_POLICY_UUID) 
					REFERENCES KMT_CLIENT_POLICY (UUID)
	)
;

CREATE TABLE KMT_CLIENT_USERS (
		UUID VARCHAR(64) NOT NULL,
		CLIENT_UUID VARCHAR(64),
		USER_ID VARCHAR(64),
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		CONSTRAINT PK_CLIENT_USERS PRIMARY KEY (UUID),
		CONSTRAINT FK1_CLIENT_USERS FOREIGN KEY (CLIENT_UUID) 
					REFERENCES KMT_CLIENT (UUID) ON DELETE CASCADE
	)
;


CREATE TABLE KMT_APP_ROLE (
    	UUID VARCHAR(64) NOT NULL,
		NAME VARCHAR(256) NOT NULL,
		CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
		LAST_UPDATE_TIMESTAMP  TIMESTAMP NOT NULL,
		CONSTRAINT APP_ROLE_PK PRIMARY KEY (UUID),
		CONSTRAINT APP_ROLE_NAME_UN UNIQUE (NAME)
	);

CREATE INDEX APPROLE_NAME_IDX ON KMT_APP_ROLE(NAME);


CREATE TABLE KMT_APP_USER_GROUP (
    	UUID VARCHAR(64) NOT NULL,
		NAME VARCHAR(256) NOT NULL,
		DESCRIPTION VARCHAR(512),
		CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
		LAST_UPDATE_TIMESTAMP  TIMESTAMP NOT NULL,
		CONSTRAINT APP_USER_GROUP_PK PRIMARY KEY (UUID),
		CONSTRAINT APP_USER_GROUP_NAME_UN UNIQUE (NAME)
	);

CREATE INDEX APPUSERGROUP_NAME_IDX ON KMT_APP_ROLE(NAME);


 CREATE TABLE KMT_APP_USERGROUP_MEMBERS  (
 	UUID VARCHAR(64) NOT NULL,
    USER_ID  VARCHAR(256) NOT NULL,
    GROUP_UUID   VARCHAR(64) NOT NULL,
	CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT PK_APP_USERGROUP_MEMBERS_ID PRIMARY KEY (UUID),
	CONSTRAINT APP_ROLE_MEMBERS_FK1 FOREIGN KEY (GROUP_UUID)
				REFERENCES KMT_APP_USER_GROUP  (UUID) ON DELETE CASCADE
  );

CREATE INDEX IDX_KMT_APP_USERGROUP_MEMBERS_01 ON KMT_APP_USERGROUP_MEMBERS(USER_ID);
CREATE INDEX IDX_KMT_APP_USERGROUP_MEMBERS_02 ON KMT_APP_USERGROUP_MEMBERS(GROUP_UUID);


 CREATE TABLE KMT_APP_ROLE_MEMBERS (
 	UUID VARCHAR(64) NOT NULL,
    ROLEID VARCHAR(64) NOT NULL,
    MEMBERID  VARCHAR(256) NOT NULL,
    MEMBERTYPE  SMALLINT NOT NULL,
	CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT PK_APP_ROLE_MEMBERS_ID PRIMARY KEY (UUID),
	CONSTRAINT APP_ROLE_MEMBERS_FK1 FOREIGN KEY (ROLEID)
		  REFERENCES KMT_APP_ROLE (UUID) ON DELETE CASCADE
  );

CREATE INDEX IDX_KMT_APP_ROLE_MEMBERS_01 ON KMT_APP_ROLE_MEMBERS(ROLEID);
CREATE INDEX IDX_KMT_APP_ROLE_MEMBERS_02 ON KMT_APP_ROLE_MEMBERS(MEMBERID);


CREATE TABLE KMT_VERSIONINFO (
	UUID SMALLINT NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 32767 CYCLE CACHE 20),
    APP_VERSION VARCHAR(64) NOT NULL, 
    WAS_VERSION VARCHAR(64) NOT NULL,
    JAVA_VERSION VARCHAR(64) NOT NULL,
    BUILD_LEVEL VARCHAR(64) NOT NULL,
    IMAGE_LEVEL VARCHAR(64),
    EXT1 VARCHAR(64),
    EXT2 VARCHAR(64),
	LAST_UPDATE_TIMESTAMP TIMESTAMP,
	CONSTRAINT KMT_VERSIONINFO_PK PRIMARY KEY (UUID)
  );

------ Following changes are KMIP DB Restructure related changes ----------

 CREATE TABLE KMT_KMIP_SUPPORTED_ATTRS (
	ATTR_NAME	VARCHAR (64) NOT NULL,
	ATTR_TYPE	VARCHAR (16),
	STRUCT_ATTR_NAME	VARCHAR (64) NOT NULL,
	ATTR_ENUM	VARCHAR (64),
	STRUCT_ATTR_ENUM	VARCHAR (64),
	CREATION_DATE	TIMESTAMP,
	CREATED_BY	VARCHAR (64),
	LAST_UPDATE_BY	VARCHAR (64),
	LAST_UPDATE_TIMESTAMP	TIMESTAMP,
	CONSTRAINT PK_SUPP_ATTRS PRIMARY KEY (ATTR_NAME, STRUCT_ATTR_NAME)
  );
 

CREATE TABLE KMT_KMIP_ATTRS_DATA (
	OBJ_UUID	VARCHAR (64) NOT NULL,
	ATTR_NAME	VARCHAR (64) NOT NULL,
	ATTR_INDEX	INTEGER  NOT NULL,
	STRUCT_ATTR_NAME	VARCHAR (64)  NOT NULL,
	ATTR_ENUM	VARCHAR (64),
	STRUCT_ATTR_ENUM	VARCHAR (64),
	ATTR_VALUE	VARCHAR (4096),
	ATTR_DATA_TYPE VARCHAR(64) ,
	OBJ_TYPE	VARCHAR (16),
	ATTR_TYPE	VARCHAR (16),
	CREATION_DATE	TIMESTAMP,
	CREATED_BY	VARCHAR (64),
	LAST_UPDATE_BY	VARCHAR (64),
	LAST_UPDATE_TIMESTAMP	TIMESTAMP,
	CONSTRAINT PK_OBJ_ATTR_DATA PRIMARY KEY (OBJ_UUID, ATTR_NAME, ATTR_INDEX, STRUCT_ATTR_NAME)
  );
  

  
  		--1) In case of SingleVal or MultiVal (Non structure) attributes,  ATTR_NAME and STRUCT_ATTR_NAME will hold same value of attribute name.
  		--2) ATTR_TYPE - is SingleValue (SV), MultiValue (MV) , or Structure (ST)
  		--3) ATTR_DATA_TYPE - Text, Integer, Enum, Binary (Use exact datatype mentioned in KMIP specs).
  
  
  
  CREATE view VW_KMIP_ATTRS_DATA
  As
	select 	OBJ_UUID, 
		ATTR_NAME,
		STRUCT_ATTR_NAME,
		ATTR_NAME || '_' || STRUCT_ATTR_NAME as ATTR_COL_NAME,
		OBJ_TYPE,
		ATTR_DATA_TYPE,
		STRING_AGG (ATTR_VALUE,',' order by ATTR_INDEX) as VW_ATTR_VAL
	from KMT_KMIP_ATTRS_DATA
	Group by OBJ_UUID, 
		ATTR_NAME,
		STRUCT_ATTR_NAME,
		OBJ_TYPE,
		ATTR_DATA_TYPE;	
		
	
------Create extension for cross tab query ------------

-- CREATE EXTENSION tablefunc  SCHEMA sklm  VERSION "1.0";
--
---------- Cross tab query ------------------		
--
-- CREATE VIEW VW_KMIP_OBJ_WITH_ADDITIONAL_ATTRS
-- As
--	select * from crosstab ( 'select 	
--								OBJ_UUID, 
--								ATTR_COL_NAME,
--								VW_ATTR_VAL
--						from VW_KMIP_ATTRS_DATA
--						order by OBJ_UUID' ,
--		
--						'Select distinct ATTR_NAME  || ''_'' || STRUCT_ATTR_NAME from KMT_KMIP_SUPPORTED_ATTRS order by 1'
--		)
--		As (
--			 OBJ_UUID  character varying,
--			 ALTERNATIVE_NAME_ALTERNATIVE_NAME_TYPE text,
--			 ALTERNATIVE_NAME_ALTERNATIVE_NAME_VALUE text,
--			 ALWAYS_SENSITIVE_ALWAYS_SENSITIVE text,
--			 APPLICATION_SPECIFIC_INFORMATION_APPLICATION_DATA text,
--			 APPLICATION_SPECIFIC_INFORMATION_APPLICATION_NAMESPACE text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_C text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_CN text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_DC text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_DN_QUALIFIER text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_EMAIL text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_L text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_O text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_OU text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_SERIAL_NUMBER text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_ST text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_TITLE text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_UID text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_C text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_CN text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_DC text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_DN_QUALIFIER text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_EMAIL text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_L text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_O text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_OU text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_SERIAL_NUMBER text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_ST text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_TITLE text,
--			 CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_UID text,
--			 CRYPTOGRAPHIC_DOMAIN_PARAMETERS_QLENGTH text,
--			 CRYPTOGRAPHIC_DOMAIN_PARAMETERS_RECOMMENDED_CURVE text,
--			 CRYPTOGRAPHIC_PARAMETERS_BLOCK_CIPHER_MODE text,
--			 CRYPTOGRAPHIC_PARAMETERS_COUNTER_LENGTH text,
--			 CRYPTOGRAPHIC_PARAMETERS_CRYPTOGRAPHIC_ALGORITHM text,
--			 CRYPTOGRAPHIC_PARAMETERS_DIGITAL_SIGNATURE_ALGORITHM_ text,
--			 CRYPTOGRAPHIC_PARAMETERS_FIXED_FIELD_LENGTH text,
--			 CRYPTOGRAPHIC_PARAMETERS_HASHING_ALGORITHM text,
--			 CRYPTOGRAPHIC_PARAMETERS_INITIAL_COUNTER_VALUE text,
--			 CRYPTOGRAPHIC_PARAMETERS_INVOCATION_FIELD_LENGTH text,
--			 CRYPTOGRAPHIC_PARAMETERS_IV_LENGTH text,
--			 CRYPTOGRAPHIC_PARAMETERS_KEY_ROLE_TYPE text,
--			 CRYPTOGRAPHIC_PARAMETERS_MASK_GENERATOR text,
--			 CRYPTOGRAPHIC_PARAMETERS_MASK_GENERATOR_HASHING_ALGORITHM text,
--			 CRYPTOGRAPHIC_PARAMETERS_PADDING_METHOD text,
--			 CRYPTOGRAPHIC_PARAMETERS_P_SOURCE text,
--			 CRYPTOGRAPHIC_PARAMETERS_RANDOM_IV text,
--			 CRYPTOGRAPHIC_PARAMETERS_SALT_LENGTH text,
--			 CRYPTOGRAPHIC_PARAMETERS_TAG_LENGTH text,
--			 CRYPTOGRAPHIC_PARAMETERS_TRAILER_FIELD text,
--			 DIGEST_DIGEST_VALUE text,
--			 DIGEST_HASHING_ALGORITHM text,
--			 DIGEST_KEY_FORMAT_TYPE text,
--			 EXTRACTABLE_EXTRACTABLE text,
--			 FRESH_FRESH text,
--			 KEY_FORMAT_TYPE_KEY_FORMAT_TYPE text,
--			 KEY_VALUE_LOCATION_KEY_VALUE_LOCATION_TYPE text,
--			 KEY_VALUE_LOCATION_KEY_VALUE_LOCATION_VALUE text,
--			 KEY_VALUE_PRESENT_KEY_VALUE_PRESENT text,
--			 LINK_LINKED_OBJECT_IDENTIFIER text,
--			 LINK_LINK_TYPE text,
--			 NAME_NAME_TYPE text,
--			 NAME_NAME_VALUE text,
--			 NEVER_EXTRACTABLE_NEVER_EXTRACTABLE text,
--			 NIST_KEY_TYPE_NIST_KEY_TYPE text,
--			 OBJECT_GROUP_OBJECT_GROUP text,
--			 PKCS_12_FRIENDLY_NAME_PKCS_12_FRIENDLY_NAME text,
--			 PROTECTION_LEVEL_PROTECTION_LEVEL text,
--			 PROTECTION_PERIOD_PROTECTION_PERIOD text,
--			 PROTECTION_STORAGE_MASK_PROTECTION_STORAGE_MASK text,
--			 QUANTUM_SAFE_QUANTUM_SAFE text,
--			 RANDOM_NUMBER_GENERATOR_RANDOM_NUMBER_GENERATOR text,
--			 ROTATE_DATE_ROTATE_DATE text,
--			 ROTATE_GENERATION_ROTATE_GENERATION text,
--			 ROTATE_INTERVAL_ROTATE_INTERVAL text,
--			 ROTATE_LATEST_ROTATE_LATEST text,
--			 ROTATE_NAME_ROTATE_NAME_TYPE text,
--			 ROTATE_NAME_ROTATE_NAME_VALUE text,
--			 ROTATE_OFFSET_ROTATE_OFFSET text,
--			 SENSITIVE_SENSITIVE text,
--			 SHORT_UNIQUE_IDENTIFIER_SHORT_UNIQUE_IDENTIFIER text,
--			 UNIQUE_IDENTIFIER_UNIQUE_IDENTIFIER text,
--			 USAGE_LIMITS_USAGE_LIMITS_COUNT text,
--			 USAGE_LIMITS_USAGE_LIMITS_TOTAL text,
--			 USAGE_LIMITS_USAGE_LIMITS_UNIT text,
--			 VENDOR_ATTRIBUTE_ATTRIBUTE_NAME text,
--			 VENDOR_ATTRIBUTE_ATTRIBUTE_VALUE text,
--			 VENDOR_ATTRIBUTE_VENDOR_IDENTIFICATION text,
--			 X_509_CERTIFICATE_IDENTIFIER_CERTIFICATE_SERIAL_NUMBER text,
--			 X_509_CERTIFICATE_IDENTIFIER_ISSUER_DISTINGUISHED_NAME text,
--			 X_509_CERTIFICATE_ISSUER_ISSUER_ALTERNATIVE_NAME text,
--			 X_509_CERTIFICATE_ISSUER_ISSUER_DISTINGUISHED_NAME text,
--			 X_509_CERTIFICATE_SUBJECT_SUBJECT_ALTERNATIVE_NAME text,
--			 X_509_CERTIFICATE_SUBJECT_SUBJECT_DISTINGUISHED_NAME text
--		);		
--
--
-- CREATE VIEW VW_KMIP_CRYPTO_OBJECTS
--	As 
--	SELECT 
--		UUID as UUID,
--		TYPE as TYPE,
--		DESCRIPTION  as DESCRIPTION ,
--		ALGORITHM as ALGORITHM,
--		LENGTH as LENGTH,
--		CREATIONDATE as CREATIONDATE,
--		EXPIRATIONDATE as EXPIRATIONDATE,
--		RETIREDATE as RETIREDATE,
--		DESTROYDATE as DESTROYDATE,
--		AUTOSTATECHANGE as AUTOSTATECHANGE,
--		ACTIVATIONDATE as ACTIVATIONDATE,
--		COMPROMISEDATE as COMPROMISEDATE,
--		ARCHIVETIME as ARCHIVETIME,
--		STATE  as STATE ,
--		PREVSTATE as PREVSTATE,
--		OWNER as OWNER,
--		HASHVALUE as HASHVALUE,
--		VERSION as VERSION,
--		PENDING as PENDING,
--		FORMAT as FORMAT,
--		LEASE_TIME as LEASE_TIME,
--		CONTACT_INFO as CONTACT_INFO,
--		LAST_CHANGED_DATE as LAST_CHANGED_DATE,
--		OPERATIONAL_POLICY as OPERATIONAL_POLICY,
--		COMPROMISE_OCCURRENCE_DATE as COMPROMISE_OCCURRENCE_DATE,
--		PROCESS_START_DATE as PROCESS_START_DATE,
--		PROTECT_STOP_DATE as PROTECT_STOP_DATE,
--		REVOKE_REASON_CODE as REVOKE_REASON_CODE,
--		REVOKE_REASON_MESSAGE as REVOKE_REASON_MESSAGE,
--		USAGE_VALUE as USAGE_VALUE,
--		USAGE_TOTAL as USAGE_TOTAL,
--		USAGE_LIMIT_TYPE as USAGE_LIMIT_TYPE,
--		CRYPTO_USAGE as CRYPTO_USAGE,
--		X509EXT_SKI as X509EXT_SKI,
--		SHA1PUBKEY_SKI as SHA1PUBKEY_SKI,
--		ORIGINAL_CREATION_DATE as ORIGINAL_CREATION_DATE,
--		NULL as ISSUERNAME,
--		NULL as SERIALNUMBER,
--		NULL as SUBJECTNAME,
--		NULL as TARGETUUID,
--		NULL :: SMALLINT as NOTIFY,
--		NULL :: SMALLINT as TRUSTED,
--		NULL :: SMALLINT as PENDING_TRUST,
--		NULL :: TIMESTAMP as PENDING_TRUST_DATE,
--		NULL :: INTEGER as CERTIFICATE_LENGTH,
--		NULL :: SMALLINT as DIGITAL_SIGNATURE_ALGORITHM,
--		NULL :: INTEGER as CERTIFICATE_TYPE,
--		NULL :: TIMESTAMP as INITIAL_DATE,
--		NULL as ALIAS,
--		NULL as KEYSTORE_UUID,
--		NULL :: TIMESTAMP as DEACTIVATION_DATE,
--		NULL as APPNAME,
--		NULL as TEMPLNAME,
--		NULL :: SMALLINT as DEVICE_TYPE_ID,
--		CREATED_BY as CREATED_BY,
--		NULL :: INTEGER as OPAQUE_DATA_TYPE,
--		NULL :: INTEGER as SECRET_DATA_TYPE,
--		NULL as TEMPL_TYPE
--	FROM KMT_KEY
--	UNION
--	SELECT  
--		UUID as UUID,
--		'CERTIFICATE' as TYPE,
--		DESCRIPTION as DESCRIPTION ,
--		ALGORITHM as ALGORITHM,
--		LENGTH as LENGTH,
--		CREATIONDATE as CREATIONDATE,
--		EXPIRATIONDATE as EXPIRATIONDATE,
--		RETIREDATE as RETIREDATE,
--		DESTROYDATE as DESTROYDATE,
--		AUTOSTATECHANGE as AUTOSTATECHANGE,
--		ACTIVATIONDATE as ACTIVATIONDATE,
--		COMPROMISEDATE as COMPROMISEDATE,
--		ARCHIVETIME as ARCHIVETIME,
--		STATE as STATE ,
--		PREVSTATE as PREVSTATE,
--		OWNER as OWNER,
--		HASHVALUE as HASHVALUE,
--		VERSION as VERSION,
--		NULL as PENDING,
--		NULL as FORMAT,
--		LEASE_TIME as LEASE_TIME,
--		CONTACT_INFO as CONTACT_INFO,
--		LAST_CHANGED_DATE as LAST_CHANGED_DATE,
--		OPERATIONAL_POLICY as OPERATIONAL_POLICY,
--		COMPROMISE_OCCURRENCE_DATE as COMPROMISE_OCCURRENCE_DATE,
--		PROCESS_START_DATE as PROCESS_START_DATE,
--		PROTECT_STOP_DATE as PROTECT_STOP_DATE,
--		REVOKE_REASON_CODE as REVOKE_REASON_CODE,
--		REVOKE_REASON_MESSAGE as REVOKE_REASON_MESSAGE,
--		USAGE_VALUE as USAGE_VALUE,
--		USAGE_TOTAL as USAGE_TOTAL,
--		USAGE_LIMIT_TYPE as USAGE_LIMIT_TYPE,
--		CRYPTO_USAGE as CRYPTO_USAGE,
--		X509EXT_SKI as X509EXT_SKI,
--		SHA1PUBKEY_SKI as SHA1PUBKEY_SKI,
--		ORIGINAL_CREATION_DATE as ORIGINAL_CREATION_DATE,
--		ISSUERNAME as ISSUERNAME,
--		SERIALNUMBER as SERIALNUMBER,
--		SUBJECTNAME as SUBJECTNAME,
--		TARGETUUID as TARGETUUID,
--		NOTIFY as NOTIFY,
--		TRUSTED as TRUSTED,
--		PENDING_TRUST as PENDING_TRUST,
--		PENDING_TRUST_DATE as PENDING_TRUST_DATE,
--		CERTIFICATE_LENGTH as CERTIFICATE_LENGTH,
--		DIGITAL_SIGNATURE_ALGORITHM as DIGITAL_SIGNATURE_ALGORITHM,
--		CERTIFICATE_TYPE as CERTIFICATE_TYPE,
--		NULL as INITIAL_DATE,
--		NULL as ALIAS,
--		NULL as KEYSTORE_UUID,
--		NULL as DEACTIVATION_DATE,
--		NULL as APPNAME,
--		NULL as TEMPLNAME,
--		NULL as DEVICE_TYPE_ID,
--		CREATED_BY as CREATED_BY,
--		NULL as OPAQUE_DATA_TYPE,
--		NULL as SECRET_DATA_TYPE,
--		NULL as TEMPL_TYPE
--	FROM  KMT_CERT
--	UNION
--	SELECT  
--		UUID as UUID,
--		'OPAQUE' as TYPE,
--		NULL as DESCRIPTION ,
--		NULL as ALGORITHM,
--		NULL as LENGTH,
--		NULL as CREATIONDATE,
--		NULL as EXPIRATIONDATE,
--		NULL as RETIREDATE,
--		DESTROYDATE as DESTROYDATE,
--		NULL as AUTOSTATECHANGE,
--		ACTIVATIONDATE as ACTIVATIONDATE,
--		COMPROMISE_DATE as COMPROMISEDATE,
--		ARCHIVE_DATE as ARCHIVETIME,
--		NULL as STATE ,
--		NULL as PREVSTATE,
--		OWNER as OWNER,
--		NULL as HASHVALUE,
--		VERSION as VERSION,
--		NULL as PENDING,
--		NULL as FORMAT,
--		LEASE_TIME as LEASE_TIME,
--		CONTACT_INFO as CONTACT_INFO,
--		LAST_CHANGED_DATE as LAST_CHANGED_DATE,
--		OPERATIONAL_POLICY as OPERATIONAL_POLICY,
--		COMPROMISE_OCCURRENCE_DATE as COMPROMISE_OCCURRENCE_DATE,
--		NULL as PROCESS_START_DATE,
--		NULL as PROTECT_STOP_DATE,
--		REVOKE_REASON_CODE as REVOKE_REASON_CODE,
--		REVOKE_REASON_MESSAGE as REVOKE_REASON_MESSAGE,
--		USAGE_VALUE as USAGE_VALUE,
--		USAGE_TOTAL as USAGE_TOTAL,
--		USAGE_LIMIT_TYPE as USAGE_LIMIT_TYPE,
--		NULL as CRYPTO_USAGE,
--		NULL as X509EXT_SKI,
--		NULL as SHA1PUBKEY_SKI,
--		ORIGINAL_CREATION_DATE as ORIGINAL_CREATION_DATE,
--		NULL as ISSUERNAME,
--		NULL as SERIALNUMBER,
--		NULL as SUBJECTNAME,
--		NULL as TARGETUUID,
--		NULL as NOTIFY,
--		NULL as TRUSTED,
--		NULL as PENDING_TRUST,
--		NULL as PENDING_TRUST_DATE,
--		NULL as CERTIFICATE_LENGTH,
--		NULL as DIGITAL_SIGNATURE_ALGORITHM,
--		NULL as CERTIFICATE_TYPE,
--		INITIAL_DATE as INITIAL_DATE,
--		NULL as ALIAS,
--		NULL as KEYSTORE_UUID,
--		DEACTIVATION_DATE as DEACTIVATION_DATE,
--		NULL as APPNAME,
--		NULL as TEMPLNAME,
--		DEVICE_TYPE_ID as DEVICE_TYPE_ID,
--		CREATED_BY as CREATED_BY,
--		OPAQUE_DATA_TYPE as OPAQUE_DATA_TYPE,
--		NULL as SECRET_DATA_TYPE,
--		NULL as TEMPL_TYPE
--	FROM  KMT_KMIP_OBJECT_OPAQUE
--	UNION
--	SELECT  
--		UUID as UUID,
--		'SECRETDATA' as TYPE,
--		NULL as DESCRIPTION ,
--		NULL as ALGORITHM,
--		CRYPTO_LENGTH as LENGTH,
--		NULL as CREATIONDATE,
--		NULL as EXPIRATIONDATE,
--		NULL as RETIREDATE,
--		DESTROYDATE as DESTROYDATE,
--		NULL as AUTOSTATECHANGE,
--		ACTIVATIONDATE as ACTIVATIONDATE,
--		COMPROMISEDATE as COMPROMISEDATE,
--		ARCHIVE_DATE as ARCHIVETIME,
--		NULL as STATE ,
--		PREVSTATE as PREVSTATE,
--		OWNER as OWNER,
--		NULL as HASHVALUE,
--		VERSION as VERSION,
--		NULL as PENDING,
--		FORMAT as FORMAT,
--		LEASE_TIME as LEASE_TIME,
--		CONTACT_INFO as CONTACT_INFO,
--		LAST_CHANGED_DATE as LAST_CHANGED_DATE,
--		OPERATIONAL_POLICY as OPERATIONAL_POLICY,
--		COMPROMISE_OCCURRENCE_DATE as COMPROMISE_OCCURRENCE_DATE,
--		NULL as PROCESS_START_DATE,
--		NULL as PROTECT_STOP_DATE,
--		REVOKE_REASON_CODE as REVOKE_REASON_CODE,
--		REVOKE_REASON_MESSAGE as REVOKE_REASON_MESSAGE,
--		NULL as USAGE_VALUE,
--		NULL as USAGE_TOTAL,
--		NULL as USAGE_LIMIT_TYPE,
--		CRYPTO_USAGE as CRYPTO_USAGE,
--		NULL as X509EXT_SKI,
--		NULL as SHA1PUBKEY_SKI,
--		ORIGINAL_CREATION_DATE as ORIGINAL_CREATION_DATE,
--		NULL as ISSUERNAME,
--		NULL as SERIALNUMBER,
--		NULL as SUBJECTNAME,
--		NULL as TARGETUUID,
--		NULL as NOTIFY,
--		NULL as TRUSTED,
--		NULL as PENDING_TRUST,
--		NULL as PENDING_TRUST_DATE,
--		NULL as CERTIFICATE_LENGTH,
--		NULL as DIGITAL_SIGNATURE_ALGORITHM,
--		NULL as CERTIFICATE_TYPE,
--		INITIAL_DATE as INITIAL_DATE,
--		ALIAS as ALIAS,
--		KEYSTORE_UUID as KEYSTORE_UUID,
--		DEACTIVATION_DATE as DEACTIVATION_DATE,
--		NULL as APPNAME,
--		NULL as TEMPLNAME,
--		DEVICE_TYPE_ID as DEVICE_TYPE_ID,
--		CREATED_BY as CREATED_BY,
--		NULL as OPAQUE_DATA_TYPE,
--		TYPE as SECRET_DATA_TYPE,
--		NULL as TEMPL_TYPE
--	FROM  KMT_KMIP_OBJECT_SECRET_DATA
--	UNION
--	SELECT  
--		UUID as UUID,
--		'TEMPLATE' as TYPE,
--		NULL as DESCRIPTION ,
--		NULL as ALGORITHM,
--		NULL as LENGTH,
--		NULL as CREATIONDATE,
--		NULL as EXPIRATIONDATE,
--		NULL as RETIREDATE,
--		NULL as DESTROYDATE,
--		NULL as AUTOSTATECHANGE,
--		NULL as ACTIVATIONDATE,
--		NULL as COMPROMISEDATE,
--		NULL as ARCHIVETIME,
--		NULL as STATE ,
--		NULL as PREVSTATE,
--		NULL as OWNER,
--		NULL as HASHVALUE,
--		VERSION as VERSION,
--		NULL as PENDING,
--		NULL as FORMAT,
--		NULL as LEASE_TIME,
--		NULL as CONTACT_INFO,
--		LAST_UPDATE_TIMESTAMP as LAST_CHANGED_DATE,
--		NULL as OPERATIONAL_POLICY,
--		NULL as COMPROMISE_OCCURRENCE_DATE,
--		NULL as PROCESS_START_DATE,
--		NULL as PROTECT_STOP_DATE,
--		NULL as REVOKE_REASON_CODE,
--		NULL as REVOKE_REASON_MESSAGE,
--		NULL as USAGE_VALUE,
--		NULL as USAGE_TOTAL,
--		NULL as USAGE_LIMIT_TYPE,
--		NULL as CRYPTO_USAGE,
--		NULL as X509EXT_SKI,
--		NULL as SHA1PUBKEY_SKI,
--		NULL as ORIGINAL_CREATION_DATE,
--		NULL as ISSUERNAME,
--		NULL as SERIALNUMBER,
--		NULL as SUBJECTNAME,
--		NULL as TARGETUUID,
--		NULL as NOTIFY,
--		NULL as TRUSTED,
--		NULL as PENDING_TRUST,
--		NULL as PENDING_TRUST_DATE,
--		NULL as CERTIFICATE_LENGTH,
--		NULL as DIGITAL_SIGNATURE_ALGORITHM,
--		NULL as CERTIFICATE_TYPE,
--		NULL as INITIAL_DATE,
--		NULL as ALIAS,
--		NULL as KEYSTORE_UUID,
--		NULL as DEACTIVATION_DATE,
--		APPNAME as APPNAME,
--		TEMPLNAME as TEMPLNAME,
--		NULL as DEVICE_TYPE_ID,
--		NULL as CREATED_BY,
--		NULL as OPAQUE_DATA_TYPE,
--		NULL as SECRET_DATA_TYPE,
--		TYPE as TEMPL_TYPE
--	FROM  KMT_TEMPL
--;
--
-- CREATE VIEW VW_KMIP_CRYPTO_OBJ_WITH_ALL_ATTRS
-- As
--	Select a.* , b.* 
--	from VW_KMIP_CRYPTO_OBJECTS a LEFT OUTER JOIN VW_KMIP_OBJ_WITH_ADDITIONAL_ATTRS b 
--	ON a.UUID = b.OBJ_UUID;
--

-----------End changes of KMIP DB restructuring --------------
----------------------------BEGIN CONTAINER SCHEDULER------------------------------------------------

CREATE TABLE KMT_TIMER_PART (
		ID  BIGINT GENERATED ALWAYS AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL,
		EXECUTOR VARCHAR(100) NOT NULL,
		EXPIRY BIGINT NOT NULL,
		HOSTNAME VARCHAR(100) NOT NULL,
		LSERVER VARCHAR(100) NOT NULL,
		STATES BIGINT NOT NULL,
		USERDIR VARCHAR(254) NOT NULL,
		CONSTRAINT UNQ_KMT_TIMER_PART_0 UNIQUE (EXECUTOR, HOSTNAME, LSERVER, USERDIR),
		PRIMARY KEY (ID));

CREATE TABLE KMT_TIMER_PROP (
		ID VARCHAR(254) NOT NULL, 
		VAL VARCHAR(254) NOT NULL, 
		PRIMARY KEY (ID));


CREATE TABLE KMT_TIMER_TASK (
		ID  BIGINT GENERATED ALWAYS AS IDENTITY (START WITH 1 INCREMENT BY 1) NOT NULL, 
		INAME VARCHAR(254) NOT NULL, 
		LOADER VARCHAR(254) NOT NULL, 
		MBITS SMALLINT NOT NULL, 
		NEXTEXEC BIGINT NOT NULL, 
		ORIGSUBMT BIGINT NOT NULL, 
		OWNR VARCHAR(120) NOT NULL, 
		PARTN BIGINT NOT NULL, 
		PREVSCHED BIGINT, 
		PREVSTART BIGINT, 
		PREVSTOP BIGINT, 
		RESLT BYTEA, 
		RFAILS SMALLINT NOT NULL, 
		STATES SMALLINT NOT NULL, 
		TASKB BYTEA, 
		TASKINFO BYTEA NOT NULL, 
		TRIG BYTEA, 
		TXTIMEOUT INTEGER NOT NULL, 
		VERSION INTEGER NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP,
		PRIMARY KEY (ID));




------------------------------ END CONTAINER SCHEDULER -----------------------------------------------
 -- commits the changes to DB2		 

----------------------------- END TABLE CREATION ------------------------------------------------------


----------------------------- BEGIN INSERT STATEMENTS -------------------------------------------------------

INSERT INTO KMT_KEYSTR(UUID,KEYSTORELOCATION,KEYSTOREPWD,KEYSTORETYPE,KEYSTORENAME,VERSION) VALUES
('DUMMY-KEYSTORE-1','DummyLoc','DummyPwd','DummyType','defaultKeyStore',1);


INSERT INTO KMT_METADATA
(property_name,property_value,last_update_timestamp)
VALUES
('SchemaMajorVersion','2',(now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_METADATA
(property_name,property_value,last_update_timestamp)
VALUES
('SchemaMinorVersion','0',(now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_METADATA
(property_name,property_value,last_update_timestamp)
VALUES
('SchemaPtfLevel','0',(now() AT TIME ZONE 'UTC'));


--DELETE FROM KMT_TEMPL;

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000001', 'KLM_CERTIFICATE_METADATA_DEFAULTS', 'CERT_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_CERTIFICATE_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000002', 'UI_CONFIG_CERIFICATE_PANEL',
'UI_CONFIG_CERIFICATE_PANEL', '', 

'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="UI_CONFIG_CERTIFICATE_PANEL">
  
  <Element ElementID="CERT_RADIO_DEFAULT" ElementValue="SELF_SIGNED"></Element>
    
  <Element ElementID="SET_DEFAULT_CERT_ENABLED" ElementValue="true"></Element>
    
  <Element ElementID="DEFAULT_FILE_CERT_LOCATION" ElementValue="C:/Certs/"></Element>
    
  <Element ElementID="SELF_SIGNED_RADIO_ENABLED" ElementValue="true"></Element>
  <Element ElementID="CERT_REQ_RADIO_ENABLED" ElementValue="true"></Element>
  <Element ElementID="KS_CERT_RADIO_ENABLED" ElementValue="true"></Element>
  <Element ElementID="FILE_CERT_RADIO_ENABLED" ElementValue="true"></Element>
    
  <Element ElementID="KS_ALIAS_ENABLED" ElementValue="true"></Element>
  <Element ElementID="KS_ALIAS_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="KS_ALIAS_DEFAULT" ElementValue=""></Element>
    
  <Element ElementID="CN_ENABLED" ElementValue="true"></Element>
  <Element ElementID="CN_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="CN_DEFAULT" ElementValue=""></Element>
    
  <Element ElementID="OU_ENABLED" ElementValue="true"></Element>
  <Element ElementID="OU_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="OU_DEFAULT" ElementValue=""></Element>
  
  <Element ElementID="ORG_ENABLED" ElementValue="true"></Element>
  <Element ElementID="ORG_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="ORG_DEFAULT" ElementValue=""></Element>
  
  <Element ElementID="C_ALIAS_ENABLED" ElementValue="true"></Element>
  <Element ElementID="C_ALIAS_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="C_ALIAS_DEFAULT" ElementValue=""></Element>
    
  <Element ElementID="S_ALIAS_ENABLED" ElementValue="true"></Element>
  <Element ElementID="S_ALIAS_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="S_ALIAS_DEFAULT" ElementValue=""></Element>
  <Element ElementID="CO_ALIAS_ENABLED" ElementValue="true"></Element>
  <Element ElementID="CO_ALIAS_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="CO_ALIAS_DEFAULT" ElementValue=""></Element>
    
  <Element ElementID="VALIDITY_ENABLED" ElementValue="true"></Element>
  <Element ElementID="VALIDITY_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="VALIDITY_DEFAULT" ElementValue="1095"></Element>
  <Element ElementID="VALIDITY_MIN" ElementValue="365"></Element>
  <Element ElementID="VALIDITY_MAX" ElementValue="9999"></Element>
          
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000003', 'KLM_KEY_METADATA_DEFAULTS', 'KEY_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_KEY_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="RSA"></Element>
      <Element ElementID="KeyType" ElementValue="SYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="2048"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000004', 'UI_CONFIG_AUDIT_DEBUG_PANEL',
'UI_CONFIG_AUDIT_DEBUG_PANEL', '', 

'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="UI_CONFIG_AUDIT_DEBUG_PANEL">
  <Element ElementID="AUDIT_LEVEL_DEFAULT" ElementValue="1"></Element>
  <Element ElementID="DEBUG_LEVEL_DEFAULT" ElementValue="0"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000005', 'UI_CONFIG_KEYSERVING_PARAMS_PANEL',
'UI_CONFIG_KEYSERVING_PARAMS_PANEL', '', 

'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="UI_CONFIG_KEYSERVING_PARAMS_PANEL">
  
  <Element ElementID="TCP_PORT_DEFAULT" ElementValue="3801"></Element>
  <Element ElementID="TCP_TIMEOUT_DEFAULT" ElementValue="10"></Element>
  <Element ElementID="SSL_PORT_DEFAULT" ElementValue="1441"></Element>
  <Element ElementID="KMIP_SSL_PORT_DEFAULT" ElementValue="5696"></Element>
  <Element ElementID="SKLM_AGENT_PORT_DEFAULT" ElementValue="60015"></Element>
  <Element ElementID="SSL_TIMEOUT_DEFAULT" ElementValue="10"></Element>
  <Element ElementID="AGENT_MONITORING_SVC_INTERVAL_DEFAULT" ElementValue="3600"></Element>
  <Element ElementID="PORT_MONITORING_SVC_INTERVAL_DEFAULT" ElementValue="3600"></Element>
  <Element ElementID="AGENT_TAKEOVER_SVC_INTERVAL_DEFAULT" ElementValue="300"></Element>
  <Element ElementID="DATA_SYNCHORNIZING_SVC_INTERVAL_DEFAULT" ElementValue="3600"></Element>
  <Element ElementID="ENABLE_ZOS_KEY_DEFAULT" ElementValue="false"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));



INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000006', 
'KEYSTORE_JCEKS', 
'UI_KEYSTORE_PANEL', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KEYSTORE_JCEKS">
  <Element ElementID="KEYSTORE_ALIAS_DEFAULT" ElementValue="defaultKeyStore"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000007', 
'KEYSTORE_JCERACFKS', 
'UI_KEYSTORE_PANEL', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KEYSTORE_JCERACFKS">
  <Element ElementID="KEYSTORE_ALIAS_DEFAULT" ElementValue="defaultKeyStore"></Element>
  <Element ElementID="HARDWARE_PROTECTION_DEFAULT" ElementValue="true"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000008', 
'KEYSTORE_JCECCARACFKS', 
'UI_KEYSTORE_PANEL', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KEYSTORE_JCECCARACFKS">
  <Element ElementID="KEYSTORE_ALIAS_DEFAULT" ElementValue="defaultKeyStore"></Element>
  <Element ElementID="HARDWARE_PROTECTION_DEFAULT" ElementValue="true"></Element>
</TKLMTemplate>', 0, (now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000009', 
'KEYSTORE_JCECCAKS', 
'UI_KEYSTORE_PANEL', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KEYSTORE_JCECCAKS">
  <Element ElementID="KEYSTORE_ALIAS_DEFAULT" ElementValue="defaultKeyStore"></Element>
  <Element ElementID="HARDWARE_PROTECTION_DEFAULT" ElementValue="true"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000010', 
'KLM_SYMMETRICKEY_AES_METADATA_DEFAULTS', 
'KEY_TEMPLATE', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_SYMMETRICKEY_AES_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="AES"></Element>
      <Element ElementID="KeyType" ElementValue="SYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="256"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000011', 
'KLM_SYMMETRICKEY_DESede_METADATA_DEFAULTS', 
'KEY_TEMPLATE', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_SYMMETRICKEY_DESede_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="TRIPLE_DES"></Element>
      <Element ElementID="KeyType" ElementValue="SYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="168"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000012', 'KLM_CERTIFICATE_METADATA_SPIKE', 'CERT_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_CERTIFICATE_METADATA_SPIKE">
  <Element ElementID="APPLICATION_NAME" ElementValue="SPIKE"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000013', 'KLM_KEY_METADATA_SPIKE', 'KEY_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_KEY_METADATA_SPIKE">
  <Element ElementID="APPLICATION_NAME" ElementValue="SPIKE"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="ECDSA"></Element>
      <Element ElementID="KeyType" ElementValue="SYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="521"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000014', 'KLM_EC_KEY_METADATA_DEFAULTS', 'KEY_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_KEY_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="ECDSA"></Element>
      <Element ElementID="KeyType" ElementValue="ASYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="384"></Element>
</TKLMTemplate>',0, (now() AT TIME ZONE 'UTC'));


INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 0, 0, 0, 'UNKNOWN', null);
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1, 1, 0, '3592', 'TS3592');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 2, 2, 0, 'LTO', 'LTO');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 3, 3, 0, 'DS8000', 'DS8000');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 4, 4, 0, 'DS5000', 'DS5000');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 5, 5, 0, 'GENERIC', 'GENERIC');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 6, 0, 0, 'UNSET', null);
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 7, 0, 0, 'SSLSERVER', 'CONFIG');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 8, 0, 0, 'SSLCLIENT', 'CONFIG');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 9, 0, 0, 'IKEV2SERVER', 'CONFIG');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 10, 0, 0, 'IKEV2CLIENT', 'CONFIG');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 11, 0, 0, 'CONFLICTED', null);
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1000, 2, 0, 'BRCD_ENCRYPTOR', 'BRCD_ENCRYPTOR');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1001, 4, 0, 'ONESECURE', 'ONESECURE');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1002, 4, 0, 'ETERNUS_DX', 'ETERNUS_DX');
-- Commenting this for V2.5 GA. Add/uncomment this when needed
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1003, 4, 0, 'IBM_SYSTEM_X_SED', 'IBM_SYSTEM_X_SED');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1004, 4, 0, 'XIV', 'XIV');
INSERT INTO KMT_DEVICE_TYPE(UUID,BASE_FAMILY_ID,VERSION,NAME,
ROLE_NAME) VALUES(12,12,0,'GPFS','GPFS');
INSERT INTO KMT_DEVICE_TYPE(UUID,BASE_FAMILY_ID,VERSION,NAME,
ROLE_NAME) VALUES(13,0,0,'SYSLOG','CONFIG');



-- Commented all statements for SYSTEM_X device with devicetypeId = 1003. Add/uncomment later when needed        
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 0, 'DEVTYPEATTR-0');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1, 'DEVTYPEATTR-1');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 2, 'DEVTYPEATTR-2');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 3, 'DEVTYPEATTR-3');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 4, 'DEVTYPEATTR-4');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 4, 'DEVTYPEATTR-12');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 5, 'DEVTYPEATTR-5');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 6, 'DEVTYPEATTR-6');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 7, 'DEVTYPEATTR-7');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 8, 'DEVTYPEATTR-8');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 9, 'DEVTYPEATTR-9');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 10, 'DEVTYPEATTR-10');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 11, 'DEVTYPEATTR-11');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1000, 'DEVTYPEATTR-1000');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1001, 'DEVTYPEATTR-1001');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 1001, 'DEVTYPEATTR-1002');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1002, 'DEVTYPEATTR-1003');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 1002, 'DEVTYPEATTR-1004');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1003, 'DEVTYPEATTR-1005');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 1003, 'DEVTYPEATTR-1006');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1004, 'DEVTYPEATTR-1007');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 1004, 'DEVTYPEATTR-1008');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('AddNewCertsToPending', 'false', 12, 'DEVTYPEATTR-13');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('enableKMIPDelete', 'false', 12, 'DEVTYPEATTR-14');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1, 'DEVTYPEATTR-15');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 2, 'DEVTYPEATTR-16');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 3, 'DEVTYPEATTR-17');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 4, 'DEVTYPEATTR-18');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1000, 'DEVTYPEATTR-19');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1001, 'DEVTYPEATTR-20');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1002, 'DEVTYPEATTR-21');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1003, 'DEVTYPEATTR-22');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1004, 'DEVTYPEATTR-23');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 12, 'DEVTYPEATTR-24');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.enableVolserAffinity', 'false', 4, 'DEVTYPEATTR-1009');


INSERT INTO KMT_BACKUP (LASTBACKUPDATE) VALUES (NULL);
	
-- Adds the default Key groups
    
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1', '3592', 0, '1', '3592 Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '2', 'LTO', 0, '2', 'LTO Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '3', 'DS8000', 0, '3',  'DS8000 Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '4', 'DS5000', 0, '4', 'DS5000 Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '5', 'GENERIC', 0, '5', 'GENERIC Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1000', 'BRCD_ENCRYPTOR', 0, '1000', 'BRCD_ENCRYPTOR Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1001', 'ONESECURE', 0, '1001', 'ONESECURE Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1002', 'ETERNUS_DX', 0, '1002', 'ETERNUS_DX Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1004', 'XIV', 0, '1004', 'XIV Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '12', 'GPFS', 0, '12', 'GPFS Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1003', 'IBM_SYSTEM_X_SED', 0, '1003', 'IBM_SYSTEM_X_SED Key Group');


INSERT INTO KMT_DEVICE_TYPE(UUID,BASE_FAMILY_ID,VERSION,NAME,ROLE_NAME) VALUES(14,14,0,'PEER_TO_PEER','PEER_TO_PEER');	
		
INSERT INTO KMT_KEY_GROUPS(UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES(14,'PEER_TO_PEER',0,14,'PEER_TO_PEER KEY GROUP');	
				
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,UUID) VALUES ('enableKMIPDelete', 'true', 14, 'DEVTYPEATTR-25');
		
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,UUID) VALUES ('AddNewCertsToPending', 'false', 14, 'DEVTYPEATTR-26');

INSERT INTO KMT_DEVICE_TYPE(UUID,BASE_FAMILY_ID,VERSION,NAME,ROLE_NAME) VALUES(15,12,0,'DS8000_TCT','DS8000_TCT');	
		
INSERT INTO KMT_KEY_GROUPS(UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES(15,'DS8000_TCT',0,12,'DS8000_TCT KEY GROUP');
						
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,UUID) VALUES ('enableKMIPDelete', '0', 15, 'DEVTYPEATTR-27');
		
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,UUID) VALUES ('AddNewCertsToPending', 'false', 15, 'DEVTYPEATTR-28');



INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-1','CREATE','*');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-2','CREATE_KEY_PAIR','*');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-3','REGISTER','*');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-4','CERTIFY','*');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-5','VALIDATE','*');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-6','QUERY','*');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-7','CANCEL','*');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-8','POLL','*');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-9','RE_KEY','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-10','RE_KEY_KEY_PAIR','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-11','DERIVE_KEY','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-12','LOCATE','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-13','CHECK','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-14','GET','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-15','GET_ATTRIBUTES','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-16','GET_ATTRIBUTE_LIST','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-17','ADD_ATTRIBUTE','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-18','MODIFY_ATTRIBUTE','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-19','DELETE_ATTRIBUTE','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-20','OBTAIN_LEASE','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-21','GET_USAGE_ALLOCATION','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-22','ACTIVATE','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-23','REVOKE','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-24','DESTROY','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-25','ARCHIVE','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-26','RECOVER','SECRETOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-27','CERTIFY','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-28','RE_CERTIFY','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-29','LOCATE','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-30','CHECK','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-31','GET','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-32','GET_ATTRIBUTES','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-33','GET_ATTRIBUTE_LIST','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-34','ADD_ATTRIBUTE','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-35','MODIFY_ATTRIBUTE','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-36','DELETE_ATTRIBUTE','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-37','OBTAIN_LEASE','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-38','ACTIVATE','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-39','REVOKE','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-40','DESTROY','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-41','ARCHIVE','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-42','RECOVER','PUBLICOBJECT');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-43','LOCATE','TEMPLATE');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-44','GET','TEMPLATE');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-45','GET_ATTRIBUTES','TEMPLATE');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-46','GET_ATTRIBUTE_LIST','TEMPLATE');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-47','ADD_ATTRIBUTE','TEMPLATE');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-48','MODIFY_ATTRIBUTE','TEMPLATE');
INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-49','DELETE_ATTRIBUTE','TEMPLATE');

INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-1','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-2','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-3','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-4','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-5','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-6','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-7','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-8','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-9','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-10','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-11','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-12','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-13','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-14','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-15','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-16','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-17','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-18','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-19','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-20','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-21','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-22','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-23','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-24','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-25','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-26','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-27','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-28','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-29','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-30','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-31','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-32','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-33','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-34','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-35','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-36','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-37','SYSTEM','*');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-38','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-39','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-40','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-41','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-42','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-43','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-44','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-45','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-46','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-47','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-48','SYSTEM','=');
INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-49','SYSTEM','=');



INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000009', 'klmSecurityOfficer', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000010', 'klmBackup', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000011', 'klmConfigure', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000012', 'klmRestore', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000013', 'klmAudit', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000014', 'klmView', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000015', 'klmCreate', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000016', 'klmModify', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000017', 'klmDelete', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000018', 'klmGet', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));	
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000019', 'klmAdminDeviceGroup', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000020', 'LTO', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000021', 'TS3592', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000022', 'DS5000', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000023', 'DS8000', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000024', 'GENERIC', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000025', 'BRCD_ENCRYPTOR', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000026', 'ONESECURE', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000027', 'suppressmonitor', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000028', 'ETERNUS_DX', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000030', 'IBM_SYSTEM_X_SED', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000031', 'XIV', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000032', 'GPFS', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000033', 'PEER_TO_PEER', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000034', 'DS8000_TCT', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000035', 'klmClientUser', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000036', 'klmFileTransfer', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));


INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000001', 'klmGUICLIAccessGroup', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000002', 'klmSecurityOfficerGroup', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000003', 'LTOAdmin', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000004', 'LTOAuditor', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000005', 'LTOOperator', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000006', 'klmBackupRestoreGroup', (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));



--FILEUSER INSERT INTO kmt_app_usergroup_members(
--FILEUSER 	uuid, user_id, group_uuid, creation_timestamp, last_update_timestamp)
--FILEUSER 	VALUES ('00000000-0000-0000-0000-000000000001', 'filesklmadmin', (select uuid from kmt_app_user_group where name='klmGUICLIAccessGroup'), (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));

--FILEUSER INSERT INTO kmt_app_usergroup_members(
--FILEUSER 	uuid, user_id, group_uuid, creation_timestamp, last_update_timestamp)
--FILEUSER 	VALUES ('00000000-0000-0000-0000-000000000002', 'filesklmadmin', (select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));	

--LDAPUSER INSERT INTO kmt_app_usergroup_members(
--LDAPUSER 	uuid, user_id, group_uuid, creation_timestamp, last_update_timestamp)
--LDAPUSER 	VALUES ('00000000-0000-0000-0000-000000000003', 'ldapsklmadmin', (select uuid from kmt_app_user_group where name='klmGUICLIAccessGroup'), (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));

--LDAPUSER INSERT INTO kmt_app_usergroup_members(
--LDAPUSER 	uuid, user_id, group_uuid, creation_timestamp, last_update_timestamp)
--LDAPUSER 	VALUES ('00000000-0000-0000-0000-000000000004', 'ldapsklmadmin', (select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));	
 

INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000002',
	(select uuid from kmt_app_role where name='klmSecurityOfficer'),
	(select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));

INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000003',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000004',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='klmBackupRestoreGroup'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000005',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000006',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000007',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='LTOAuditor'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000008',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='klmGUICLIAccessGroup'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000009',
	(select uuid from kmt_app_role where name='klmBackup'),
	(select uuid from kmt_app_user_group where name='klmBackupRestoreGroup'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000010',
	(select uuid from kmt_app_role where name='klmBackup'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000011',
	(select uuid from kmt_app_role where name='klmBackup'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000012',
	(select uuid from kmt_app_role where name='klmRestore'),
	(select uuid from kmt_app_user_group where name='klmBackupRestoreGroup'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000013',
	(select uuid from kmt_app_role where name='LTO'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000014',
	(select uuid from kmt_app_role where name='LTO'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000015',
	(select uuid from kmt_app_role where name='LTO'),
	(select uuid from kmt_app_user_group where name='LTOAuditor'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000016',
	(select uuid from kmt_app_role where name='klmCreate'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000017',
	(select uuid from kmt_app_role where name='klmCreate'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000018',
	(select uuid from kmt_app_role where name='klmView'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000019',
	(select uuid from kmt_app_role where name='klmView'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000020',
	(select uuid from kmt_app_role where name='klmView'),
	(select uuid from kmt_app_user_group where name='LTOAuditor'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000021',
	(select uuid from kmt_app_role where name='klmDelete'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000022',
	(select uuid from kmt_app_role where name='klmModify'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000023',
	(select uuid from kmt_app_role where name='klmModify'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000024',
	(select uuid from kmt_app_role where name='klmGet'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000025',
	(select uuid from kmt_app_role where name='klmAudit'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000026',
	(select uuid from kmt_app_role where name='klmAudit'),
	(select uuid from kmt_app_user_group where name='LTOAuditor'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000027',
	(select uuid from kmt_app_role where name='klmConfigure'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000028',
	(select uuid from kmt_app_role where name='klmConfigure'),
	(select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), 0, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	



--FILEUSER INSERT INTO kmt_app_role_members(
--FILEUSER	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
--FILEUSER	VALUES ('00000000-0000-0000-0000-000000000029',
--FILEUSER	(select uuid from kmt_app_role where name='klmSecurityOfficer'),
--FILEUSER	'filesklmadmin', 1, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
--FILEUSER INSERT INTO kmt_app_role_members(
--FILEUSER	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
--FILEUSER	VALUES ('00000000-0000-0000-0000-000000000030',
--FILEUSER	(select uuid from kmt_app_role where name='suppressmonitor'),
--FILEUSER	'filesklmadmin', 1, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));

--LDAPUSER INSERT INTO kmt_app_role_members(
--LDAPUSER	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
--LDAPUSER	VALUES ('00000000-0000-0000-0000-000000000031',
--LDAPUSER	(select uuid from kmt_app_role where name='klmSecurityOfficer'),
--LDAPUSER	'ldapsklmadmin', 1, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
--LDAPUSER INSERT INTO kmt_app_role_members(
--LDAPUSER	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
--LDAPUSER	VALUES ('00000000-0000-0000-0000-000000000032',
--LDAPUSER	(select uuid from kmt_app_role where name='suppressmonitor'),
--LDAPUSER	'ldapsklmadmin', 1, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));

--FILEUSER INSERT INTO kmt_app_role_members(
--FILEUSER	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
--FILEUSER	VALUES ('00000000-0000-0000-0000-000000000033',
--FILEUSER	(select uuid from kmt_app_role where name='klmClientUser'),
--FILEUSER	'filesklmadmin', 1, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));

--LDAPUSER INSERT INTO kmt_app_role_members(
--LDAPUSER	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
--LDAPUSER	VALUES ('00000000-0000-0000-0000-000000000034',
--LDAPUSER	(select uuid from kmt_app_role where name='klmClientUser'),
--LDAPUSER	'ldapsklmadmin', 1, (now() AT TIME ZONE 'UTC'), (now() AT TIME ZONE 'UTC'));
	


INSERT INTO KMT_VERSIONINFO
(app_version,was_version,java_version,build_level,image_level,last_update_timestamp)
VALUES
('4.1.0.5','','','202304071902','@IMAGELEVEL@',(now() AT TIME ZONE 'UTC'));


		
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ALTERNATIVE_NAME','ST','ALTERNATIVE_NAME_VALUE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ALTERNATIVE_NAME','ST','ALTERNATIVE_NAME_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ALWAYS_SENSITIVE','SV','ALWAYS_SENSITIVE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('APPLICATION_SPECIFIC_INFORMATION','ST','APPLICATION_NAMESPACE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('APPLICATION_SPECIFIC_INFORMATION','ST','APPLICATION_DATA', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_CN', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_O', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_OU', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_EMAIL', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_C', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_ST', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_L', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_UID', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_SERIAL_NUMBER', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_TITLE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_DC', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_DN_QUALIFIER', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_CN', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_O', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_OU', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_EMAIL', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_C', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_ST', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_L', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_UID', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_SERIAL_NUMBER', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_TITLE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_DC', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_DN_QUALIFIER', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_DOMAIN_PARAMETERS','ST','QLENGTH', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_DOMAIN_PARAMETERS','ST','RECOMMENDED_CURVE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','BLOCK_CIPHER_MODE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','PADDING_METHOD', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','HASHING_ALGORITHM', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','KEY_ROLE_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','DIGITAL_SIGNATURE_ALGORITHM_', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','CRYPTOGRAPHIC_ALGORITHM', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','RANDOM_IV', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','IV_LENGTH', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','TAG_LENGTH', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','FIXED_FIELD_LENGTH', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','INVOCATION_FIELD_LENGTH', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','COUNTER_LENGTH', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','INITIAL_COUNTER_VALUE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','SALT_LENGTH', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','MASK_GENERATOR', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','MASK_GENERATOR_HASHING_ALGORITHM', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','P_SOURCE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','TRAILER_FIELD', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('DIGEST','ST','HASHING_ALGORITHM', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('DIGEST','ST','DIGEST_VALUE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('DIGEST','ST','KEY_FORMAT_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('EXTRACTABLE','SV','EXTRACTABLE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('FRESH','SV','FRESH', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('KEY_FORMAT_TYPE','SV','KEY_FORMAT_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('KEY_VALUE_LOCATION','ST','KEY_VALUE_LOCATION_VALUE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('KEY_VALUE_LOCATION','ST','KEY_VALUE_LOCATION_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('KEY_VALUE_PRESENT','SV','KEY_VALUE_PRESENT', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('LINK','ST','LINK_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('LINK','ST','LINKED_OBJECT_IDENTIFIER', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('NAME','ST','NAME_VALUE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('NAME','ST','NAME_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('NEVER_EXTRACTABLE','SV','NEVER_EXTRACTABLE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('NIST_KEY_TYPE','MV','NIST_KEY_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('OBJECT_GROUP','MV','OBJECT_GROUP', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('PKCS_12_FRIENDLY_NAME','SV','PKCS_12_FRIENDLY_NAME', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('PROTECTION_LEVEL','SV','PROTECTION_LEVEL', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('PROTECTION_PERIOD','SV','PROTECTION_PERIOD', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('PROTECTION_STORAGE_MASK','SV','PROTECTION_STORAGE_MASK', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('QUANTUM_SAFE','SV','QUANTUM_SAFE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('RANDOM_NUMBER_GENERATOR','SV','RANDOM_NUMBER_GENERATOR', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_DATE','SV','ROTATE_DATE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_GENERATION','SV','ROTATE_GENERATION', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_INTERVAL','SV','ROTATE_INTERVAL', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_LATEST','SV','ROTATE_LATEST', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_NAME','ST','ROTATE_NAME_VALUE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_NAME','ST','ROTATE_NAME_TYPE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_OFFSET','SV','ROTATE_OFFSET', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('SENSITIVE','SV','SENSITIVE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('SHORT_UNIQUE_IDENTIFIER','SV','SHORT_UNIQUE_IDENTIFIER', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('UNIQUE_IDENTIFIER','SV','UNIQUE_IDENTIFIER', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('USAGE_LIMITS','ST','USAGE_LIMITS_TOTAL', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('USAGE_LIMITS','ST','USAGE_LIMITS_COUNT', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('USAGE_LIMITS','ST','USAGE_LIMITS_UNIT', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('VENDOR_ATTRIBUTE','ST','VENDOR_IDENTIFICATION', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('VENDOR_ATTRIBUTE','ST','ATTRIBUTE_NAME', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('VENDOR_ATTRIBUTE','ST','ATTRIBUTE_VALUE', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_IDENTIFIER','ST','ISSUER_DISTINGUISHED_NAME', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_IDENTIFIER','ST','CERTIFICATE_SERIAL_NUMBER', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_ISSUER','ST','ISSUER_DISTINGUISHED_NAME', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_ISSUER','ST','ISSUER_ALTERNATIVE_NAME', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_SUBJECT','ST','SUBJECT_DISTINGUISHED_NAME', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_SUBJECT','ST','SUBJECT_ALTERNATIVE_NAME', null, null, (now() AT TIME ZONE 'UTC') ,'User1', 'User2', (now() AT TIME ZONE 'UTC'));
	

----------------------------- END INSERT STATEMENTS -------------------------------------------------------


commit;

