-- disable auto-commit option
update command options using c off;

-------------------------------------- BEGIN CREATE TABLESPACES ----------------------------

CREATE BUFFERPOOL TKLMBP_LG 
  SIZE 3000
  PAGESIZE 8K;

CREATE BUFFERPOOL TKLMBP_8K_LG 
  SIZE 3000
  PAGESIZE 8K;

CREATE BUFFERPOOL TKLMBP_32K_LG 
  SIZE 3000
  PAGESIZE 32K;

CREATE BUFFERPOOL TKLMBP_SM 
  SIZE 3000
  PAGESIZE 8K;

CREATE BUFFERPOOL TKLMBP_4K_LG_IDX 
  SIZE 3000
  PAGESIZE 4K;

CREATE BUFFERPOOL TKLMBP_IDX 
  SIZE 3000
  PAGESIZE 8K;
  
CREATE BUFFERPOOL TKLMBP_32K_IDX 
  SIZE 3000
  PAGESIZE 32K;

CREATE  REGULAR  TABLESPACE TKLM_DATA_LG PAGESIZE 8 K  
  MANAGED BY DATABASE  
  USING ( FILE 'tklm_data_lg' 128M)
  AUTORESIZE YES INCREASESIZE 128M 
  EXTENTSIZE 8
  OVERHEAD 24.1 
  PREFETCHSIZE 16 
  TRANSFERRATE 0.9 
  BUFFERPOOL TKLMBP_LG;

COMMENT ON TABLESPACE TKLM_DATA_LG IS 'Tablespace used for storing large 8k tklm tables';

CREATE  REGULAR  TABLESPACE TKLM_DATA_32K_LG PAGESIZE 32 K  
  MANAGED BY DATABASE  
  USING ( FILE 'tklm_data_32k_lg' 512M)
  AUTORESIZE YES INCREASESIZE 512M 
  EXTENTSIZE 8
  OVERHEAD 24.1 
  PREFETCHSIZE 16 
  TRANSFERRATE 0.9 
  BUFFERPOOL TKLMBP_32K_LG;

COMMENT ON TABLESPACE TKLM_DATA_32K_LG IS 'Tablespace used for storing large 32k tklm tables';

CREATE  REGULAR  TABLESPACE TKLM_DATA_SM PAGESIZE 8 K  
  MANAGED BY DATABASE  
  USING ( FILE 'tklm_data_sm' 4M)
  AUTORESIZE YES INCREASESIZE 4M 
  EXTENTSIZE 8
  OVERHEAD 24.1 
  PREFETCHSIZE 16 
  TRANSFERRATE 0.9 
  BUFFERPOOL TKLMBP_SM;

COMMENT ON TABLESPACE TKLM_DATA_SM IS 'Tablespace used for storing small 8k tklm tables';

CREATE  REGULAR  TABLESPACE TKLM_4K_IDX PAGESIZE 4 K  
  MANAGED BY DATABASE  
  USING ( FILE 'tklm_4k_indices' 32M)
  AUTORESIZE YES INCREASESIZE 32M  
  EXTENTSIZE 8 
  OVERHEAD 24.1 
  PREFETCHSIZE 16 
  TRANSFERRATE 0.9 
  BUFFERPOOL TKLMBP_4K_LG_IDX;

  COMMENT ON TABLESPACE TKLM_4K_IDX IS 'Tablespace used for storing tklm 4k indices';

CREATE  REGULAR  TABLESPACE TKLM_IDX PAGESIZE 8 K  
  MANAGED BY DATABASE  
  USING ( FILE 'tklm_indices' 64M)
  AUTORESIZE YES INCREASESIZE 64M  
  EXTENTSIZE 8 
  OVERHEAD 24.1 
  PREFETCHSIZE 16 
  TRANSFERRATE 0.9 
  BUFFERPOOL TKLMBP_IDX;

  COMMENT ON TABLESPACE TKLM_IDX IS 'Tablespace used for storing tklm 8k indices';

  CREATE  REGULAR  TABLESPACE TKLM_32K_IDX PAGESIZE 32 K  
  MANAGED BY DATABASE  
  USING ( FILE 'tklm_32k_indices' 256M)
  AUTORESIZE YES INCREASESIZE 256M  
  EXTENTSIZE 8 
  OVERHEAD 24.1 
  PREFETCHSIZE 16 
  TRANSFERRATE 0.9 
  BUFFERPOOL TKLMBP_32K_IDX;

  COMMENT ON TABLESPACE TKLM_32K_IDX IS 'Tablespace used for storing tklm indices for tables in 32k tablespaces';

CREATE  SYSTEM TEMPORARY TABLESPACE TEMP_DATA PAGESIZE 8 K  
  MANAGED BY DATABASE  
  USING ( FILE 'system_data' 64M) 
  AUTORESIZE YES INCREASESIZE 64M
  EXTENTSIZE 8 
  OVERHEAD 24.1 
  PREFETCHSIZE 16 
  TRANSFERRATE 0.9 
  BUFFERPOOL TKLMBP_LG;

COMMENT ON TABLESPACE TEMP_DATA IS 'Temporary tablespace managed by database system';

----------------------------BEGIN SCHEDULER------------------------------------------------

CREATE BUFFERPOOL TKLMBP_SCH 
  SIZE 3000
  PAGESIZE 8K;

CREATE TABLESPACE TKLM_SCHEDULER PAGESIZE 8 K  
  MANAGED BY DATABASE 
  USING ( FILE 'tklm_scheduler' 32M)
  AUTORESIZE YES INCREASESIZE 32M  
  EXTENTSIZE 8 
  OVERHEAD 24.1 
  PREFETCHSIZE 16 
  TRANSFERRATE 0.9 
  BUFFERPOOL TKLMBP_SCH;

COMMENT ON TABLESPACE TKLM_DATA_SM IS 'Tablespace used for Websphere-based TKLM scheduler';

-------------------------------END SCHEDULER------------------------------------------------

--GRANT USE OF TABLESPACE TKLM_DATA_LG TO USER $user_name WITH GRANT OPTION;
--GRANT USE OF TABLESPACE TKLM_DATA_SM TO USER $user_name WITH GRANT OPTION;
--GRANT USE OF TABLESPACE TKLM_INDICES TO USER $user_name WITH GRANT OPTION;
--GRANT USE OF TABLESPACE TKLM_SCHEDULER TO USER $user_name WITH GRANT OPTION;
--GRANT CREATETAB, CONNECT,IMPLICIT_SCHEMA ON DATABASE TO USER $user_name;



-- commits the changes to DB2
commit;
-------------------------------END CREATE TABLESPACES --------------------------------------


-------------------------------------- CREATE TABLES ---------------------------------------

CREATE TABLE KMT_METADATA (
    PROPERTY_NAME VARCHAR(254) NOT NULL,
    PROPERTY_VALUE VARCHAR(1024) NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_SM INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

--Table commented out because it is not clear if it will be used (by RBAC or otherwise)
--CREATE TABLE KMT_KMIP_ATTR_OPERATIONAL_POLICY (
--		UUID VARCHAR(64) NOT NULL,
--		POLICY_NAME VARCHAR(256) NOT NULL
--		--more columns representing policy details like a pointer to flat def file, etc 
--	)
--	IN TKLM_DATA_LG INDEX IN TKLM_IDX
--	DATA CAPTURE NONE ;
--ALTER TABLE KMT_KMIP_ATTR_OPERATIONAL_POLICY ADD CONSTRAINT PK_OP_POLICY PRIMARY KEY (UUID);
--CREATE UNIQUE INDEX IDX_OPPOL_NAME ON KMT_KMIP_ATTR_OPERATIONAL_POLICY (POLICY_NAME) MINPCTUSED 20;

CREATE TABLE KMT_KEY (
	UUID VARCHAR(64) NOT NULL,
	TYPE VARCHAR (64) NOT NULL,
	DESCRIPTION VARCHAR(256),
	ALGORITHM VARCHAR(512),
	LENGTH INT,
	CREATIONDATE TIMESTAMP,
	EXPIRATIONDATE TIMESTAMP,
--Obsolete column:
	RETIREDATE TIMESTAMP,
	DESTROYDATE TIMESTAMP,
--Obsolete column:	
	AUTOSTATECHANGE SMALLINT NOT NULL,
	CONSTRAINT CCAUTOSTATECHANGE1 CHECK (AUTOSTATECHANGE in(0,1)),
	ACTIVATIONDATE TIMESTAMP,
	COMPROMISEDATE TIMESTAMP,
	ARCHIVETIME TIMESTAMP,
--Obsolete column:	
	STATE INTEGER,
	PREVSTATE INTEGER,
	OWNER VARCHAR(128),
	HASHVALUE VARCHAR(256) FOR BIT DATA NOT NULL,
	VERSION INT NOT NULL,
	PENDING SMALLINT DEFAULT 0,
	FORMAT SMALLINT,
	--KMIP:
	LEASE_TIME INTEGER,
	CONTACT_INFO VARCHAR(1024),
	LAST_CHANGED_DATE TIMESTAMP,
	OPERATIONAL_POLICY VARCHAR(64),
	COMPROMISE_OCCURRENCE_DATE TIMESTAMP,
	PROCESS_START_DATE TIMESTAMP,
	PROTECT_STOP_DATE TIMESTAMP,
	REVOKE_REASON_CODE INTEGER,
	REVOKE_REASON_MESSAGE VARCHAR(2048),
	USAGE_VALUE DECIMAL(18,0),
	USAGE_TOTAL DECIMAL(18,0),
	USAGE_LIMIT_TYPE SMALLINT,
	CRYPTO_USAGE VARCHAR(32),
	KEY_DATA BLOB,
	 -- SKI SUPPORT
	X509EXT_SKI VARCHAR(256),
	SHA1PUBKEY_SKI VARCHAR(256),
	ORIGINAL_CREATION_DATE TIMESTAMP
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE;

ALTER TABLE KMT_KEY ADD CONSTRAINT PK_KEY PRIMARY KEY (UUID);
--ALTER TABLE KMT_KEY ADD CONSTRAINT FK_OP_POLICY FOREIGN KEY (OPERATIONAL_POLICY)
--	REFERENCES KMT_KMIP_ATTR_OPERATIONAL_POLICY (UUID);

CREATE INDEX IDX_KEY_01 ON KMT_KEY (CREATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_02 ON KMT_KEY (EXPIRATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_03 ON KMT_KEY (ACTIVATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_04 ON KMT_KEY (COMPROMISEDATE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_05 ON KMT_KEY (DESTROYDATE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_06 ON KMT_KEY (HASHVALUE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_07 ON KMT_KEY (PENDING) MINPCTUSED 20;
CREATE INDEX IDX_KEY_08 ON KMT_KEY (ALGORITHM) MINPCTUSED 20;
CREATE INDEX IDX_KEY_09 ON KMT_KEY (LENGTH) MINPCTUSED 20;
CREATE INDEX IDX_KEY_10 ON KMT_KEY (LEASE_TIME) MINPCTUSED 20;
CREATE INDEX IDX_KEY_11 ON KMT_KEY (OWNER) MINPCTUSED 20;
CREATE INDEX IDX_KEY_12 ON KMT_KEY (REVOKE_REASON_CODE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_13 ON KMT_KEY (PROCESS_START_DATE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_14 ON KMT_KEY (PROTECT_STOP_DATE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_15 ON KMT_KEY (USAGE_VALUE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_16 ON KMT_KEY (USAGE_TOTAL) MINPCTUSED 20;
CREATE INDEX IDX_KEY_17 ON KMT_KEY (USAGE_LIMIT_TYPE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_18 ON KMT_KEY (CRYPTO_USAGE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_19 ON KMT_KEY (PREVSTATE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_20 ON KMT_KEY (TYPE) MINPCTUSED 20;
CREATE INDEX IDX_KEY_21 ON KMT_KEY (X509EXT_SKI) MINPCTUSED 20;
CREATE INDEX IDX_KEY_22 ON KMT_KEY (SHA1PUBKEY_SKI) MINPCTUSED 20;
CREATE INDEX IDX_KEY_23 ON KMT_KEY (ORIGINAL_CREATION_DATE) MINPCTUSED 20;


CREATE TABLE KMT_CERT (
	UUID VARCHAR(64) NOT NULL,
	DESCRIPTION VARCHAR(256),
	ISSUERNAME VARCHAR(512),
	SERIALNUMBER VARCHAR(64),
	SUBJECTNAME VARCHAR(512),
--Obsolete column:	
	TARGETUUID VARCHAR(64),
	CREATIONDATE TIMESTAMP,
	ACTIVATIONDATE TIMESTAMP,
	EXPIRATIONDATE TIMESTAMP,        
	DESTROYDATE TIMESTAMP,
	COMPROMISEDATE TIMESTAMP,
--Obsolete column:	
	RETIREDATE TIMESTAMP,
--Obsolete column:	
	AUTOSTATECHANGE SMALLINT NOT NULL,
--Obsolete column:	
	STATE INTEGER,
	PREVSTATE INTEGER,
	OWNER VARCHAR(128),
	ARCHIVETIME TIMESTAMP,
	HASHVALUE VARCHAR(256) FOR BIT DATA NOT NULL,
	VERSION INT NOT NULL,
	NOTIFY SMALLINT NOT NULL DEFAULT 1,
	TRUSTED SMALLINT NOT NULL DEFAULT 1,
	--KMIP:
	LEASE_TIME INTEGER,
	CONTACT_INFO VARCHAR(1024),
	LAST_CHANGED_DATE TIMESTAMP,
	COMPROMISE_OCCURRENCE_DATE TIMESTAMP,
	OPERATIONAL_POLICY VARCHAR(64),
	CERTIFICATE_TYPE INTEGER,
	PROCESS_START_DATE TIMESTAMP,
	PROTECT_STOP_DATE TIMESTAMP,
	REVOKE_REASON_CODE INTEGER,
	REVOKE_REASON_MESSAGE VARCHAR(2048),
	CONSTRAINT NOTIFY1 CHECK (NOTIFY in(0,1)),
	USAGE_VALUE DECIMAL(18,0),
	USAGE_TOTAL DECIMAL(18,0),
	USAGE_LIMIT_TYPE SMALLINT,
	KEY_DATA BLOB,
	PENDING_TRUST SMALLINT DEFAULT 0,
	PENDING_TRUST_DATE TIMESTAMP,
--New for V3 Cert support:
    DIGITAL_SIGNATURE_ALGORITHM SMALLINT NOT NULL,
    CERTIFICATE_LENGTH INTEGER NOT NULL,
    -- SKI SUPPORT
    X509EXT_SKI VARCHAR(256),
    SHA1PUBKEY_SKI VARCHAR(256),
	CRYPTO_USAGE VARCHAR(32),
	ALGORITHM VARCHAR(512),
	LENGTH INT,
    ORIGINAL_CREATION_DATE TIMESTAMP
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_CERT ADD CONSTRAINT PK_CERT PRIMARY KEY (UUID);
--ALTER TABLE KMT_CERT ADD CONSTRAINT FK_OP_POLICY FOREIGN KEY (OPERATIONAL_POLICY)
--	REFERENCES KMT_KMIP_ATTR_OPERATIONAL_POLICY (UUID);
CREATE INDEX IDX_CERT_01 ON KMT_CERT (CREATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_02 ON KMT_CERT (EXPIRATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_03 ON KMT_CERT (ACTIVATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_04 ON KMT_CERT (COMPROMISEDATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_05 ON KMT_CERT (DESTROYDATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_06 ON KMT_CERT (HASHVALUE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_07 ON KMT_CERT (NOTIFY) MINPCTUSED 20;
CREATE INDEX IDX_CERT_08 ON KMT_CERT (TRUSTED) MINPCTUSED 20;
CREATE INDEX IDX_CERT_09 ON KMT_CERT (LEASE_TIME) MINPCTUSED 20;
CREATE INDEX IDX_CERT_10 ON KMT_CERT (SERIALNUMBER) MINPCTUSED 20;
CREATE INDEX IDX_CERT_11 ON KMT_CERT (ISSUERNAME) MINPCTUSED 20;
CREATE INDEX IDX_CERT_12 ON KMT_CERT (SUBJECTNAME) MINPCTUSED 20;
CREATE INDEX IDX_CERT_13 ON KMT_CERT (OWNER) MINPCTUSED 20;
CREATE INDEX IDX_CERT_14 ON KMT_CERT (REVOKE_REASON_CODE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_15 ON KMT_CERT (PROCESS_START_DATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_16 ON KMT_CERT (PROTECT_STOP_DATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_17 ON KMT_CERT (USAGE_VALUE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_18 ON KMT_CERT (USAGE_TOTAL) MINPCTUSED 20;
CREATE INDEX IDX_CERT_19 ON KMT_CERT (USAGE_LIMIT_TYPE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_20 ON KMT_CERT (PREVSTATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_21 ON KMT_CERT (DIGITAL_SIGNATURE_ALGORITHM) MINPCTUSED 20;
CREATE INDEX IDX_CERT_22 ON KMT_CERT (X509EXT_SKI) MINPCTUSED 20;
CREATE INDEX IDX_CERT_23 ON KMT_CERT (SHA1PUBKEY_SKI) MINPCTUSED 20;
CREATE INDEX IDX_CERT_24 ON KMT_CERT (ORIGINAL_CREATION_DATE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_25 ON KMT_CERT (CRYPTO_USAGE) MINPCTUSED 20;
CREATE INDEX IDX_CERT_26 ON KMT_CERT (ALGORITHM) MINPCTUSED 20;
CREATE INDEX IDX_CERT_27 ON KMT_CERT (LENGTH) MINPCTUSED 20;

CREATE TABLE KMT_POLICY (
    UUID VARCHAR(64) NOT NULL,
    MANADATORY SMALLINT NOT NULL,
    POLICYTYPE SMALLINT NOT NULL,
    POLICY  VARCHAR (3072) NOT NULL,
    VERSION INT NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  ) 
  IN TKLM_DATA_SM INDEX IN TKLM_IDX
  DATA CAPTURE NONE;

ALTER TABLE KMT_POLICY ADD CONSTRAINT PK_POLICY PRIMARY KEY(UUID);

CREATE TABLE KMT_KEYPOLICY_RN (
    UUID VARCHAR(64) NOT NULL,
    POLICYID VARCHAR(64) NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;



ALTER TABLE KMT_KEYPOLICY_RN ADD CONSTRAINT PK_KEYPOLICYRN PRIMARY KEY(POLICYID, UUID);



CREATE TABLE KMT_CERPOLICY_RN (
    UUID VARCHAR(64) NOT NULL,
    POLICYID VARCHAR(64) NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_CERPOLICY_RN ADD CONSTRAINT PK_CERPOLICYRN  PRIMARY KEY (POLICYID, UUID);



-- NOT NEEDED FOR V1
--CREATE TABLE KMT_EXKEYATT (
--    UUID VARCHAR(64) NOT NULL,
--    NAME VARCHAR(256) NOT NULL,
--    VALUE VARCHAR(1020),
--    ATTRDATATYPE SMALLINT
--  )
--IN TKLM_DATA_LG INDEX IN TKLM_IDX
--   DATA CAPTURE NONE ;



CREATE TABLE KMT_KEYSTR (
    UUID VARCHAR(64) NOT NULL,
    KEYSTORELOCATION VARCHAR(2048) NOT NULL,
    KEYSTOREPWD VARCHAR(256),
    KEYSTORETYPE VARCHAR(64),
    KEYSTORENAME VARCHAR(64) NOT NULL,
    USERID    VARCHAR (256),
    VERSION INT NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_SM INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;


ALTER TABLE KMT_KEYSTR ADD CONSTRAINT PK_KEYSTR PRIMARY KEY (UUID);
CREATE UNIQUE INDEX IDX_KEYSTR_01 ON KMT_KEYSTR(KEYSTORENAME);

INSERT INTO KMT_KEYSTR(UUID,KEYSTORELOCATION,KEYSTOREPWD,KEYSTORETYPE,KEYSTORENAME,VERSION) VALUES
('DUMMY-KEYSTORE-1','DummyLoc','DummyPwd','DummyType','defaultKeyStore',1);


CREATE TABLE KMT_KEYSTR_RN (
    UUID VARCHAR(64) NOT NULL,
    KEYSTOREID VARCHAR(64) NOT NULL,
    ALIAS VARCHAR(256) NOT NULL,
    KEYPASSWORD VARCHAR(256)
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_KEYSTR_RN ADD CONSTRAINT PK_KEYSTR_RN PRIMARY KEY (UUID, KEYSTOREID, ALIAS);
ALTER TABLE KMT_KEYSTR_RN ADD CONSTRAINT KEYSTRRN_FK1 FOREIGN KEY (KEYSTOREID)
  REFERENCES KMT_KEYSTR (UUID) ON DELETE RESTRICT;
ALTER TABLE KMT_KEYSTR_RN ADD CONSTRAINT KEYSTRRN_FK2 FOREIGN KEY (UUID)
  REFERENCES KMT_KEY (UUID) ON DELETE CASCADE;
CREATE INDEX IDX_KEYSTRRN_01 ON KMT_KEYSTR_RN(ALIAS) MINPCTUSED 20;
CREATE INDEX IDX_KEYSTRRN_02 ON KMT_KEYSTR_RN(UUID) MINPCTUSED 20;



CREATE TABLE KMT_CERTSTR_RN (
    UUID VARCHAR(64) NOT NULL,
    KEYSTOREID VARCHAR(64) NOT NULL,
    ALIAS VARCHAR(256) NOT NULL
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_CERTSTR_RN ADD CONSTRAINT PK_CERTSTR_RN PRIMARY KEY (UUID, KEYSTOREID, ALIAS);

ALTER TABLE KMT_CERTSTR_RN ADD CONSTRAINT CERTSTRRN_FK1 FOREIGN KEY (KEYSTOREID)
  REFERENCES KMT_KEYSTR (UUID)
  ON DELETE RESTRICT;

CREATE UNIQUE INDEX IDX_CERTSTRRN_01 ON KMT_CERTSTR_RN(KEYSTOREID, ALIAS);
CREATE INDEX IDX_CERTSTRRN_02 ON KMT_CERTSTR_RN(UUID);


ALTER TABLE KMT_CERTSTR_RN ADD CONSTRAINT CERTSTRRN_FK2 FOREIGN KEY (UUID)
  REFERENCES KMT_CERT (UUID)
  ON DELETE CASCADE;

-- table store data about groupings of TKLM entities.
--GROUPTYPE: 1=key, 2=device
CREATE TABLE KMT_GROUP (
    UUID VARCHAR(64) NOT NULL,
    GROUPTYPE SMALLINT NOT NULL,
    GROUPNAME VARCHAR(256) NOT NULL,
    INITIALIZATIONDATE TIMESTAMP,
    ACTIVESTATEDURATION INT,
    ACTIVATIONDATE TIMESTAMP,
    LASTACTIVEMEMBER VARCHAR(256), 
    KEYCOUNT INT DEFAULT 0, 
    KEYUNUSED INT DEFAULT 0, 
    VERSION INT NOT NULL
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_GROUP ADD CONSTRAINT PK_GROUP PRIMARY KEY (UUID);
CREATE UNIQUE INDEX IDX_GROUP_01 ON KMT_GROUP(GROUPNAME, GROUPTYPE);
CREATE INDEX IDX_GROUP_02 ON KMT_GROUP(KEYCOUNT);
CREATE INDEX IDX_GROUP_03 ON KMT_GROUP(KEYUNUSED);
CREATE INDEX IDX_GROUP_04 ON KMT_GROUP(GROUPTYPE);
CREATE INDEX IDX_GROUP_05 ON KMT_GROUP(LASTACTIVEMEMBER);
CREATE INDEX GRP_NAME_IDX ON KMT_GROUP(GROUPNAME);




-- table stores data about group memebers
--MEMBERTYPE: 0=subgroup, 1=key, 2=certificate, 3=device
CREATE TABLE KMT_GROUP_MEMBERS (
    GROUPID VARCHAR(64) NOT NULL,
    MEMBERID  VARCHAR(64) NOT NULL,
    MEMBERTYPE  SMALLINT NOT NULL,
    MEMSEQNO INT GENERATED ALWAYS AS IDENTITY (START WITH -2147483648, INCREMENT BY 1),
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_GROUP_MEMBERS ADD CONSTRAINT PK_GR_MEMB_ID PRIMARY KEY (GROUPID, MEMBERID);
ALTER TABLE KMT_GROUP_MEMBERS ADD CONSTRAINT GROUP_MEMBERS_FK1 FOREIGN KEY (GROUPID)
  REFERENCES KMT_GROUP (UUID) ON DELETE CASCADE;
CREATE INDEX IDX_KMT_GROUP_MEMBERS_01 ON KMT_GROUP_MEMBERS(GROUPID) MINPCTUSED 20;
CREATE INDEX IDX_KMT_GROUP_MEMBERS_02 ON KMT_GROUP_MEMBERS(MEMBERID) MINPCTUSED 20;
CREATE INDEX IDX_KMT_GROUP_MEMBERS_03 ON KMT_GROUP_MEMBERS(MEMSEQNO) MINPCTUSED 20;
CREATE INDEX IDX_KMT_GROUP_MEMBERS_04 ON KMT_GROUP_MEMBERS(MEMBERTYPE) MINPCTUSED 20;





-- NOT A V1
-- CREATE TABLE KMT_EXCERTATT (
--    UUID VARCHAR(64) NOT NULL,
--    NAME VARCHAR(256) NOT NULL,
--    VALUE VARCHAR(1020),
--    ATTRDATATYPE SMALLINT
--  )
--  DATA CAPTURE NONE ;

CREATE TABLE KMT_TEMPL (
    UUID VARCHAR(64) NOT NULL,
    TEMPLNAME VARCHAR(256),
    TYPE VARCHAR(64),
    APPNAME VARCHAR(256),
    TEMPL VARCHAR(7072),
    VERSION INT NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_SM INDEX IN TKLM_IDX
  DATA CAPTURE NONE;

ALTER TABLE KMT_TEMPL ADD CONSTRAINT PK_TEMPL PRIMARY KEY(UUID);

CREATE INDEX IDX_TEMPL_01 on KMT_TEMPL(TEMPLNAME) MINPCTUSED 20;
CREATE INDEX IDX_TEMPL_02 on KMT_TEMPL(TYPE) MINPCTUSED 20;
CREATE INDEX IDX_TEMPL_03 On KMT_TEMPL(APPNAME) MINPCTUSED 20;

-- table store metadata about devices.
-- 0 for UNKNOWN, 1 - JAG 2 - LTO-4
-- no known attribute is unique
CREATE TABLE KMT_DEVICE (
    UUID VARCHAR(64) NOT NULL,
    DEVICETYPE SMALLINT,
    SERIALNO VARCHAR(256) NOT NULL,
    WWN VARCHAR(128) NOT NULL,
    SYMALIAS VARCHAR(256),
    DEVICECERT VARCHAR(2048) FOR BIT DATA,
    KEYALIAS1 VARCHAR(256),
    KEYALIAS2 VARCHAR(256),
    DESCRIPTION VARCHAR(256),
    VERSION INT NOT NULL,
	DEVICETEXT VARCHAR(256),
	DEVICEPENDING SMALLINT,
	DEVICEPENDINGDATE TIMESTAMP,
	ORIGDEVICETYPE SMALLINT,
	LAST_UPDATE_TIMESTAMP TIMESTAMP  
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_DEVICE ADD CONSTRAINT PK_DEV PRIMARY KEY (UUID);
--CREATE UNIQUE INDEX IDX_DEVICE_01 On KMT_DEVICE(SERIALNO, DEVICETYPE, WWN) MINPCTUSED 20;
CREATE UNIQUE INDEX IDX_DEVICE_01 On KMT_DEVICE(SERIALNO) MINPCTUSED 20;


CREATE TABLE KMT_DEVAUDIT (
    UUID VARCHAR(64) NOT NULL, 
    SERIALNO VARCHAR(64),
    VOLSERIALNO VARCHAR(128),
    WWN VARCHAR(128),
    KEYALIAS1 VARCHAR(256),
    KEYALIAS2 VARCHAR(256),
    TIME_STAMP TIMESTAMP,
    DKI VARCHAR(128),
    EXTATTR VARCHAR(2800)
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;


ALTER TABLE KMT_DEVAUDIT ADD CONSTRAINT PK_DEVAUDIT PRIMARY KEY (UUID);


INSERT INTO KMT_METADATA
(property_name,property_value,last_update_timestamp)
VALUES
('SchemaMajorVersion','2',(CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_METADATA
(property_name,property_value,last_update_timestamp)
VALUES
('SchemaMinorVersion','0',(CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_METADATA
(property_name,property_value,last_update_timestamp)
VALUES
('SchemaPtfLevel','0',(CURRENT TIMESTAMP - CURRENT TIMEZONE));


--DELETE FROM KMT_TEMPL;

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000001', 'KLM_CERTIFICATE_METADATA_DEFAULTS', 'CERT_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_CERTIFICATE_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000002', 'UI_CONFIG_CERIFICATE_PANEL',
'UI_CONFIG_CERIFICATE_PANEL', '', 

'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="UI_CONFIG_CERTIFICATE_PANEL">
  
  <Element ElementID="CERT_RADIO_DEFAULT" ElementValue="SELF_SIGNED"></Element>
    
  <Element ElementID="SET_DEFAULT_CERT_ENABLED" ElementValue="true"></Element>
    
  <Element ElementID="DEFAULT_FILE_CERT_LOCATION" ElementValue="C:/Certs/"></Element>
    
  <Element ElementID="SELF_SIGNED_RADIO_ENABLED" ElementValue="true"></Element>
  <Element ElementID="CERT_REQ_RADIO_ENABLED" ElementValue="true"></Element>
  <Element ElementID="KS_CERT_RADIO_ENABLED" ElementValue="true"></Element>
  <Element ElementID="FILE_CERT_RADIO_ENABLED" ElementValue="true"></Element>
    
  <Element ElementID="KS_ALIAS_ENABLED" ElementValue="true"></Element>
  <Element ElementID="KS_ALIAS_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="KS_ALIAS_DEFAULT" ElementValue=""></Element>
    
  <Element ElementID="CN_ENABLED" ElementValue="true"></Element>
  <Element ElementID="CN_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="CN_DEFAULT" ElementValue=""></Element>
    
  <Element ElementID="OU_ENABLED" ElementValue="true"></Element>
  <Element ElementID="OU_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="OU_DEFAULT" ElementValue=""></Element>
  
  <Element ElementID="ORG_ENABLED" ElementValue="true"></Element>
  <Element ElementID="ORG_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="ORG_DEFAULT" ElementValue=""></Element>
  
  <Element ElementID="C_ALIAS_ENABLED" ElementValue="true"></Element>
  <Element ElementID="C_ALIAS_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="C_ALIAS_DEFAULT" ElementValue=""></Element>
    
  <Element ElementID="S_ALIAS_ENABLED" ElementValue="true"></Element>
  <Element ElementID="S_ALIAS_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="S_ALIAS_DEFAULT" ElementValue=""></Element>

  <Element ElementID="CO_ALIAS_ENABLED" ElementValue="true"></Element>
  <Element ElementID="CO_ALIAS_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="CO_ALIAS_DEFAULT" ElementValue=""></Element>
    
  <Element ElementID="VALIDITY_ENABLED" ElementValue="true"></Element>
  <Element ElementID="VALIDITY_VISIBLE" ElementValue="true"></Element>
  <Element ElementID="VALIDITY_DEFAULT" ElementValue="1095"></Element>
  <Element ElementID="VALIDITY_MIN" ElementValue="365"></Element>
  <Element ElementID="VALIDITY_MAX" ElementValue="9999"></Element>
          
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000003', 'KLM_KEY_METADATA_DEFAULTS', 'KEY_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_KEY_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="RSA"></Element>
      <Element ElementID="KeyType" ElementValue="SYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="2048"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000004', 'UI_CONFIG_AUDIT_DEBUG_PANEL',
'UI_CONFIG_AUDIT_DEBUG_PANEL', '', 

'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="UI_CONFIG_AUDIT_DEBUG_PANEL">

  <Element ElementID="AUDIT_LEVEL_DEFAULT" ElementValue="1"></Element>
  <Element ElementID="DEBUG_LEVEL_DEFAULT" ElementValue="0"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000005', 'UI_CONFIG_KEYSERVING_PARAMS_PANEL',
'UI_CONFIG_KEYSERVING_PARAMS_PANEL', '', 

'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="UI_CONFIG_KEYSERVING_PARAMS_PANEL">
  
  <Element ElementID="TCP_PORT_DEFAULT" ElementValue="3801"></Element>
  <Element ElementID="TCP_TIMEOUT_DEFAULT" ElementValue="10"></Element>
  <Element ElementID="SSL_PORT_DEFAULT" ElementValue="1441"></Element>
  <Element ElementID="KMIP_SSL_PORT_DEFAULT" ElementValue="5696"></Element>
  <Element ElementID="SKLM_AGENT_PORT_DEFAULT" ElementValue="60015"></Element>
  <Element ElementID="SSL_TIMEOUT_DEFAULT" ElementValue="10"></Element>
  <Element ElementID="AGENT_MONITORING_SVC_INTERVAL_DEFAULT" ElementValue="3600"></Element>
  <Element ElementID="PORT_MONITORING_SVC_INTERVAL_DEFAULT" ElementValue="3600"></Element>
  <Element ElementID="AGENT_TAKEOVER_SVC_INTERVAL_DEFAULT" ElementValue="300"></Element>
  <Element ElementID="DATA_SYNCHORNIZING_SVC_INTERVAL_DEFAULT" ElementValue="3600"></Element>
  <Element ElementID="ENABLE_ZOS_KEY_DEFAULT" ElementValue="false"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));



INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000006', 
'KEYSTORE_JCEKS', 
'UI_KEYSTORE_PANEL', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KEYSTORE_JCEKS">
  <Element ElementID="KEYSTORE_ALIAS_DEFAULT" ElementValue="defaultKeyStore"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000007', 
'KEYSTORE_JCERACFKS', 
'UI_KEYSTORE_PANEL', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KEYSTORE_JCERACFKS">
  <Element ElementID="KEYSTORE_ALIAS_DEFAULT" ElementValue="defaultKeyStore"></Element>
  <Element ElementID="HARDWARE_PROTECTION_DEFAULT" ElementValue="true"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000008', 
'KEYSTORE_JCECCARACFKS', 
'UI_KEYSTORE_PANEL', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KEYSTORE_JCECCARACFKS">
  <Element ElementID="KEYSTORE_ALIAS_DEFAULT" ElementValue="defaultKeyStore"></Element>
  <Element ElementID="HARDWARE_PROTECTION_DEFAULT" ElementValue="true"></Element>
</TKLMTemplate>', 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000009', 
'KEYSTORE_JCECCAKS', 
'UI_KEYSTORE_PANEL', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KEYSTORE_JCECCAKS">
  <Element ElementID="KEYSTORE_ALIAS_DEFAULT" ElementValue="defaultKeyStore"></Element>
  <Element ElementID="HARDWARE_PROTECTION_DEFAULT" ElementValue="true"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000010', 
'KLM_SYMMETRICKEY_AES_METADATA_DEFAULTS', 
'KEY_TEMPLATE', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_SYMMETRICKEY_AES_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="AES"></Element>
      <Element ElementID="KeyType" ElementValue="SYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="256"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000011', 
'KLM_SYMMETRICKEY_DESede_METADATA_DEFAULTS', 
'KEY_TEMPLATE', '', 
'<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_SYMMETRICKEY_DESede_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="TRIPLE_DES"></Element>
      <Element ElementID="KeyType" ElementValue="SYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="168"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000012', 'KLM_CERTIFICATE_METADATA_SPIKE', 'CERT_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_CERTIFICATE_METADATA_SPIKE">
  <Element ElementID="APPLICATION_NAME" ElementValue="SPIKE"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000013', 'KLM_KEY_METADATA_SPIKE', 'KEY_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_KEY_METADATA_SPIKE">
  <Element ElementID="APPLICATION_NAME" ElementValue="SPIKE"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="ECDSA"></Element>
      <Element ElementID="KeyType" ElementValue="SYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="521"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));


INSERT INTO KMT_TEMPL (UUID, TEMPLNAME, TYPE, APPNAME, TEMPL, VERSION, LAST_UPDATE_TIMESTAMP) VALUES('00000000-0000-0000-0000-000000000014', 'KLM_EC_KEY_METADATA_DEFAULTS', 'KEY_TEMPLATE', '', '<?xml version="1.0" encoding="UTF-8"?>
<TKLMTemplate TemplateName="KLM_KEY_METADATA_DEFAULTS">
  <Element ElementID="APPLICATION_NAME" ElementValue="TS1120ENCRYPTION"></Element>
      <Element ElementID="ACTIVATION_START_IN_DAYS" ElementValue="0"></Element>
      <Element ElementID="RETIREMENT_NUMBER_OF_DAYS_AFTER_ACTIVATION" ElementValue="7300"></Element>
      <Element ElementID="Algorithm" ElementValue="ECDSA"></Element>
      <Element ElementID="KeyType" ElementValue="ASYMMETRIC_KEY"></Element>
      <Element ElementID="KeySize"  ElementValue="384"></Element>
</TKLMTemplate>',0, (CURRENT TIMESTAMP - CURRENT TIMEZONE));


----------------------------BEGIN SCHEDULER------------------------------------------------

CREATE TABLE "KMT_SCH_TASK" ("TASKID" DECIMAL(19) NOT NULL ,
              "VERSION" VARCHAR(5) NOT NULL ,
              "ROW_VERSION" INTEGER NOT NULL ,
              "TASKTYPE" INTEGER NOT NULL ,
              "TASKSUSPENDED" SMALLINT NOT NULL ,
              "CANCELLED" SMALLINT NOT NULL ,
              "NEXTFIRETIME" DECIMAL(19) NOT NULL ,
              "STARTBYINTERVAL" VARCHAR(254) ,
              "STARTBYTIME" DECIMAL(19) ,
              "VALIDFROMTIME" DECIMAL(19) ,
              "VALIDTOTIME" DECIMAL(19) ,
              "REPEATINTERVAL" VARCHAR(254) ,
              "MAXREPEATS" INTEGER NOT NULL ,
              "REPEATSLEFT" INTEGER NOT NULL ,
              "TASKINFO" BLOB(102400) LOGGED NOT COMPACT,
              "NAME" VARCHAR(1024) NOT NULL ,
              "AUTOPURGE" INTEGER NOT NULL ,
              "FAILUREACTION" INTEGER ,
              "MAXATTEMPTS" INTEGER ,
              "QOS" INTEGER ,
              "PARTITIONID" INTEGER ,
              "OWNERTOKEN" VARCHAR(200) NOT NULL ,
              "CREATETIME" DECIMAL(19) NOT NULL) IN "TKLM_SCHEDULER" INDEX IN "TKLM_IDX";

ALTER TABLE "KMT_SCH_TASK" ADD PRIMARY KEY ("TASKID");

CREATE INDEX "KMT_SCH_TASK_IDX1" ON "KMT_SCH_TASK" ("TASKID",
              "OWNERTOKEN") ;

CREATE INDEX "KMT_SCH_TASK_IDX2" ON "KMT_SCH_TASK" ("NEXTFIRETIME" ASC,
               "REPEATSLEFT",
               "PARTITIONID") CLUSTER;

CREATE INDEX "KMT_SCH_TASK_IDX3" ON "KMT_SCH_TASK"("NAME") MINPCTUSED 20;

CREATE TABLE "KMT_SCH_TREG" ("REGKEY" VARCHAR(254) NOT NULL ,
              "REGVALUE" VARCHAR(254) ) IN "TKLM_SCHEDULER" INDEX IN "TKLM_IDX";

ALTER TABLE "KMT_SCH_TREG" ADD PRIMARY KEY ("REGKEY");

CREATE TABLE "KMT_SCH_LMGR" (LEASENAME VARCHAR(254) NOT NULL,
               LEASEOWNER VARCHAR(254) NOT NULL,
               LEASE_EXPIRE_TIME  DECIMAL(19),
              DISABLED VARCHAR(5))IN "TKLM_SCHEDULER" INDEX IN "TKLM_IDX";

ALTER TABLE "KMT_SCH_LMGR" ADD PRIMARY KEY ("LEASENAME");

CREATE TABLE "KMT_SCH_LMPR" (LEASENAME VARCHAR(254) NOT NULL,
              NAME VARCHAR(254) NOT NULL,
              VALUE VARCHAR(254) NOT NULL)IN "TKLM_SCHEDULER"  INDEX IN "TKLM_IDX";

CREATE INDEX "KMT_SCH_LMPR_IDX1" ON "KMT_SCH_LMPR" (LEASENAME,
               NAME);

------------------------------ END SCHEDULER -----------------------------------------------

------------------------------- START V2 UPDATES -------------------------------------------------

------------------------------- START DEVICE TYPE RELATED UPDATES --------------------------------
CREATE TABLE KMT_DEVICE_TYPE (
		BASE_FAMILY_ID SMALLINT NOT NULL,
		NAME VARCHAR(128) NOT NULL,
		ROLE_NAME VARCHAR(128),
		VERSION INTEGER NOT NULL,
		UUID SMALLINT NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 10000 INCREMENT BY 1 MINVALUE 1 MAXVALUE 32767 CYCLE CACHE 20),
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_IDX
	DATA CAPTURE NONE ;

CREATE INDEX DEVTYPE_BASE_FAMILY_IDX ON KMT_DEVICE_TYPE (BASE_FAMILY_ID ASC, UUID ASC) PCTFREE 0;

CREATE INDEX DEVTYPE_ROLE_IDX ON KMT_DEVICE_TYPE (ROLE_NAME ASC, UUID ASC) PCTFREE 0;

ALTER TABLE KMT_DEVICE_TYPE ADD CONSTRAINT DEVICE_TYPE_PK PRIMARY KEY (UUID);

ALTER TABLE KMT_DEVICE_TYPE ADD CONSTRAINT DEVTYPE_NAME_UN UNIQUE (NAME);

INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 0, 0, 0, 'UNKNOWN', null);
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1, 1, 0, '3592', 'TS3592');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 2, 2, 0, 'LTO', 'LTO');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 3, 3, 0, 'DS8000', 'DS8000');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 4, 4, 0, 'DS5000', 'DS5000');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 5, 5, 0, 'GENERIC', 'GENERIC');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 6, 0, 0, 'UNSET', null);
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 7, 0, 0, 'SSLSERVER', 'CONFIG');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 8, 0, 0, 'SSLCLIENT', 'CONFIG');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 9, 0, 0, 'IKEV2SERVER', 'CONFIG');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 10, 0, 0, 'IKEV2CLIENT', 'CONFIG');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 11, 0, 0, 'CONFLICTED', null);
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1000, 2, 0, 'BRCD_ENCRYPTOR', 'BRCD_ENCRYPTOR');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1001, 4, 0, 'ONESECURE', 'ONESECURE');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1002, 4, 0, 'ETERNUS_DX', 'ETERNUS_DX');
-- Commenting this for V2.5 GA. Add/uncomment this when needed
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1003, 4, 0, 'IBM_SYSTEM_X_SED', 'IBM_SYSTEM_X_SED');
INSERT INTO KMT_DEVICE_TYPE  (UUID, BASE_FAMILY_ID, VERSION, NAME,
ROLE_NAME) VALUES( 1004, 4, 0, 'XIV', 'XIV');
INSERT INTO KMT_DEVICE_TYPE(UUID,BASE_FAMILY_ID,VERSION,NAME,
ROLE_NAME) VALUES(12,12,0,'GPFS','GPFS');
INSERT INTO KMT_DEVICE_TYPE(UUID,BASE_FAMILY_ID,VERSION,NAME,
ROLE_NAME) VALUES(13,0,0,'SYSLOG','CONFIG');




CREATE TABLE KMT_DEVICE_TYPE_ATTRIBUTES (
		ATTR_NAME VARCHAR(256) NOT NULL,
		ATTR_VALUE VARCHAR(2048) NOT NULL,
		DEVICE_TYPE_ID SMALLINT NOT NULL,
		UUID VARCHAR(64) NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_IDX
	DATA CAPTURE NONE ;

CREATE INDEX DEVTYPE_ATTRNAME_IDX ON KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME ASC, DEVICE_TYPE_ID ASC) PCTFREE 0;

ALTER TABLE KMT_DEVICE_TYPE_ATTRIBUTES ADD CONSTRAINT DEVTYPE_ATTRS_PK PRIMARY KEY (UUID);

ALTER TABLE KMT_DEVICE_TYPE_ATTRIBUTES ADD CONSTRAINT DEVTYPE_FK FOREIGN KEY (DEVICE_TYPE_ID)
	REFERENCES KMT_DEVICE_TYPE (UUID)
	ON DELETE CASCADE;

-- Commented all statements for SYSTEM_X device with devicetypeId = 1003. Add/uncomment later when needed        
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 0, 'DEVTYPEATTR-0');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1, 'DEVTYPEATTR-1');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 2, 'DEVTYPEATTR-2');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 3, 'DEVTYPEATTR-3');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 4, 'DEVTYPEATTR-4');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 4, 'DEVTYPEATTR-12');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 5, 'DEVTYPEATTR-5');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 6, 'DEVTYPEATTR-6');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 7, 'DEVTYPEATTR-7');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 8, 'DEVTYPEATTR-8');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 9, 'DEVTYPEATTR-9');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 10, 'DEVTYPEATTR-10');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 11, 'DEVTYPEATTR-11');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1000, 'DEVTYPEATTR-1000');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1001, 'DEVTYPEATTR-1001');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 1001, 'DEVTYPEATTR-1002');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1002, 'DEVTYPEATTR-1003');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 1002, 'DEVTYPEATTR-1004');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1003, 'DEVTYPEATTR-1005');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 1003, 'DEVTYPEATTR-1006');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('enableKMIPDelete', 'false', 1004, 'DEVTYPEATTR-1007');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME, ATTR_VALUE, DEVICE_TYPE_ID, 
UUID) VALUES ('device.enableMachineAffinity', 'false', 1004, 'DEVTYPEATTR-1008');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('AddNewCertsToPending', 'false', 12, 'DEVTYPEATTR-13');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('enableKMIPDelete', 'false', 12, 'DEVTYPEATTR-14');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1, 'DEVTYPEATTR-15');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 2, 'DEVTYPEATTR-16');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 3, 'DEVTYPEATTR-17');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 4, 'DEVTYPEATTR-18');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1000, 'DEVTYPEATTR-19');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1001, 'DEVTYPEATTR-20');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1002, 'DEVTYPEATTR-21');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1003, 'DEVTYPEATTR-22');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 1004, 'DEVTYPEATTR-23');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.AutoPendingAutoDiscovery', '0', 12, 'DEVTYPEATTR-24');
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,
UUID) VALUES ('device.enableVolserAffinity', 'false', 4, 'DEVTYPEATTR-1009');

ALTER TABLE KMT_CERTSTR_RN ADD COLUMN DEVICE_TYPE_ID SMALLINT NOT NULL WITH DEFAULT 0;
ALTER TABLE KMT_CERTSTR_RN ADD COLUMN LAST_UPDATE_TIMESTAMP TIMESTAMP ;

CREATE INDEX KMT_CERTSTR_RN_DEVTYPE_IDX ON KMT_CERTSTR_RN (UUID ASC, DEVICE_TYPE_ID ASC) PCTFREE 0;

ALTER TABLE KMT_CERTSTR_RN ADD CONSTRAINT CERT_DEVTYPE_FK FOREIGN KEY (DEVICE_TYPE_ID)
	REFERENCES KMT_DEVICE_TYPE (UUID)
	ON DELETE CASCADE;


ALTER TABLE KMT_KEYSTR_RN ADD COLUMN DEVICE_TYPE_ID SMALLINT NOT NULL WITH DEFAULT 0;
ALTER TABLE KMT_KEYSTR_RN ADD COLUMN LAST_UPDATE_TIMESTAMP TIMESTAMP ;


CREATE INDEX KMT_KEYSTR_RN_DEVTYPE_IDX ON KMT_KEYSTR_RN (UUID ASC, DEVICE_TYPE_ID ASC) PCTFREE 0;

ALTER TABLE KMT_KEYSTR_RN ADD CONSTRAINT KEY_DEVTYPE_FK FOREIGN KEY (DEVICE_TYPE_ID)
	REFERENCES KMT_DEVICE_TYPE (UUID)
	ON DELETE CASCADE;

	
ALTER TABLE KMT_GROUP ADD COLUMN DEVICE_TYPE_ID SMALLINT NOT NULL WITH DEFAULT 0 ;
ALTER TABLE KMT_GROUP ADD COLUMN LAST_UPDATE_TIMESTAMP TIMESTAMP ;


CREATE INDEX KMT_GROUP_DEVTYPE_IDX ON KMT_GROUP (UUID ASC, DEVICE_TYPE_ID ASC) PCTFREE 0;

ALTER TABLE KMT_GROUP ADD CONSTRAINT GROUP_DEVTYPE_FK FOREIGN KEY (DEVICE_TYPE_ID)
	REFERENCES KMT_DEVICE_TYPE (UUID)
	ON DELETE CASCADE;
ALTER TABLE KMT_DEVAUDIT ADD COLUMN DEVICE_TYPE_NAME VARCHAR(64) WITH DEFAULT 'UNSET';
ALTER TABLE KMT_DEVAUDIT ADD COLUMN LAST_UPDATE_TIMESTAMP TIMESTAMP ;
ALTER TABLE KMT_DEVAUDIT ADD COLUMN KMIP_CLIENT_CERT_UUID VARCHAR (64);

CREATE INDEX KMT_DEVAUDIT_DEVTYPENAME_IDX ON KMT_DEVAUDIT (DEVICE_TYPE_NAME) PCTFREE 0;
CREATE INDEX IDX_DEVAUDIT_01 ON KMT_DEVAUDIT(SERIALNO) MINPCTUSED 20;
CREATE INDEX IDX_DEVAUDIT_02 ON KMT_DEVAUDIT(VOLSERIALNO) MINPCTUSED 20;
CREATE INDEX IDX_DEVAUDIT_03 ON KMT_DEVAUDIT(KMIP_CLIENT_CERT_UUID) MINPCTUSED 20;


------------------------------- END DEVICE TYPE RELATED UPDATES --------------------------------

------------------------------- START MACHINE AFFINITY UPDATES --------------------------------

CREATE TABLE KMT_MACHINE (
    UUID VARCHAR(64) NOT NULL,
    MACHINEID VARCHAR(64) NOT NULL,
    DESCRIPTION VARCHAR(256),
    MACHINETEXT VARCHAR (256),
	FAMILYTYPE SMALLINT,
	VERSION INTEGER NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP 	
  )
  IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
  DATA CAPTURE NONE ;
 
ALTER TABLE KMT_MACHINE ADD CONSTRAINT PK_MACHINE_ID PRIMARY KEY (UUID);
CREATE UNIQUE INDEX IDX_MACHINE_01 On KMT_MACHINE(MACHINEID, MACHINETEXT) MINPCTUSED 20;

CREATE TABLE KMT_MACHINE_DEVICE (
    DEVICEID VARCHAR(64) NOT NULL,
    MACHINEID  VARCHAR(64) NOT NULL,
    PENDING_DATE TIMESTAMP,
	PENDINGAUTO SMALLINT,
	VERSION INTEGER NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP 	
  )	
  IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
  DATA CAPTURE NONE ;
 
ALTER TABLE KMT_MACHINE_DEVICE ADD CONSTRAINT PK_MACHE_DEV_ID PRIMARY KEY (DEVICEID, MACHINEID);
ALTER TABLE KMT_MACHINE_DEVICE ADD CONSTRAINT MACHINE_DEVICE_FK1 FOREIGN KEY (DEVICEID)
   REFERENCES KMT_DEVICE (UUID);
ALTER TABLE KMT_MACHINE_DEVICE ADD CONSTRAINT MACHINE_DEVICE_FK2 FOREIGN KEY (MACHINEID)
   REFERENCES KMT_MACHINE (UUID);

------------------------------- END MACHINE AFFINITY UPDATES --------------------------------

------------------------------- START KMIP RELATED UPDATES --------------------------------
CREATE TABLE KMT_KMIP_ATTR_APPINFO (
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		APP_NAMESPACE VARCHAR(1024) NOT NULL,
		APP_INFO VARCHAR(2048) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_APPINFO ADD CONSTRAINT KMT_APPINFO_PK PRIMARY KEY (MANAGED_OBJECT_UUID, INDEX_ID);
CREATE INDEX KMT_KMIP_ATTR_APPINFO_IDX ON KMT_KMIP_ATTR_APPINFO (MANAGED_OBJECT_UUID) PCTFREE 0;

CREATE TABLE KMT_KMIP_ATTR_CERTSUBJECT (
		CERT_UUID VARCHAR(64) NOT NULL,
		ALTERNATIVE_NAME VARCHAR(1024),
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_CERTSUBJECT ADD CONSTRAINT FK_CERT FOREIGN KEY (CERT_UUID)
	REFERENCES KMT_CERT (UUID)
	ON DELETE CASCADE;
ALTER TABLE KMT_KMIP_ATTR_CERTSUBJECT ADD CONSTRAINT KMT_CERTSUB_PK PRIMARY KEY (CERT_UUID, INDEX_ID);

CREATE TABLE KMT_KMIP_ATTR_CERTISSUER (
		CERT_UUID VARCHAR(64) NOT NULL,
		ALTERNATIVE_NAME VARCHAR(1024),
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_CERTISSUER ADD CONSTRAINT FK_CERT FOREIGN KEY (CERT_UUID)
	REFERENCES KMT_CERT (UUID)
	ON DELETE CASCADE;
ALTER TABLE KMT_KMIP_ATTR_CERTISSUER ADD CONSTRAINT KMT_CERTISS_PK PRIMARY KEY (CERT_UUID, INDEX_ID);

CREATE TABLE KMT_KMIP_ATTR_CRYPTOPARAMS (
		BLOCK_CIPHER_MODE INTEGER,
		PADDING_METHOD INTEGER,
		HASHING_ALGORITHM INTEGER,
		ROLE_TYPE INTEGER,
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_CRYPTOPARAMS ADD CONSTRAINT PK_CRYPTOPARAMS PRIMARY KEY (MANAGED_OBJECT_UUID, INDEX_ID);
ALTER TABLE KMT_KMIP_ATTR_CRYPTOPARAMS ADD COLUMN CRYPTOGRAPHIC_ALGORITHM INTEGER;
ALTER TABLE KMT_KMIP_ATTR_CRYPTOPARAMS ADD COLUMN SALT_LENGTH INTEGER;
ALTER TABLE KMT_KMIP_ATTR_CRYPTOPARAMS ADD COLUMN P_SOURCE VARCHAR(256);
ALTER TABLE KMT_KMIP_ATTR_CRYPTOPARAMS ADD COLUMN MASK_GENERATOR_HASHING_ALGO INTEGER;
ALTER TABLE KMT_KMIP_ATTR_CRYPTOPARAMS ADD COLUMN MASK_GENERATOR INTEGER;
ALTER TABLE KMT_KMIP_ATTR_CRYPTOPARAMS ADD COLUMN TAG_LENGTH INTEGER;
CREATE INDEX KMT_KMIP_ATTR_CRYPTOPARAMS_IDX ON KMT_KMIP_ATTR_CRYPTOPARAMS (MANAGED_OBJECT_UUID) PCTFREE 0;

CREATE TABLE KMT_KMIP_ATTR_CUSTOM (
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		TYPE INTEGER,
		ATTR_NAME VARCHAR(1024) NOT NULL,
		ATTR_VALUE VARCHAR(2048) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_CUSTOM ADD CONSTRAINT PK_CUSTOMATTR PRIMARY KEY (MANAGED_OBJECT_UUID, ATTR_NAME, INDEX_ID);
CREATE INDEX KMT_KMIP_ATTR_CUSTOM_IDX ON KMT_KMIP_ATTR_CUSTOM (MANAGED_OBJECT_UUID) PCTFREE 0;

CREATE TABLE KMT_KMIP_ATTR_DIGEST (
		HASHING_ALGORITHM INTEGER NOT NULL,
		DIGEST_VALUE VARCHAR(1024) NOT NULL,
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		KEY_FORMAT SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_DIGEST ADD CONSTRAINT PK_DIGEST PRIMARY KEY (MANAGED_OBJECT_UUID, INDEX_ID);
CREATE INDEX KMT_KMIP_ATTR_DIGEST_IDX ON KMT_KMIP_ATTR_DIGEST (MANAGED_OBJECT_UUID) PCTFREE 0;

CREATE TABLE KMT_KMIP_ATTR_LINK (
		LINK_TARGET_OBJECT_UUID VARCHAR(64) NOT NULL,
		LINK_TYPE INTEGER NOT NULL,
		LINK_SOURCE_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_LINK ADD CONSTRAINT PK_LINK PRIMARY KEY (LINK_SOURCE_OBJECT_UUID, INDEX_ID);
CREATE INDEX KMT_KMIP_ATTR_LINK_IDX1 ON KMT_KMIP_ATTR_LINK (LINK_TARGET_OBJECT_UUID) PCTFREE 0;
CREATE INDEX KMT_KMIP_ATTR_LINK_IDX2 ON KMT_KMIP_ATTR_LINK (LINK_SOURCE_OBJECT_UUID) PCTFREE 0;

CREATE TABLE KMT_KMIP_GLOBAL_NAMES (                
		NAME_TYPE INTEGER NOT NULL,
		NAME_VALUE VARCHAR(512) NOT NULL,
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
        NAME_UUID VARCHAR(64) NOT NULL,
        LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
  DATA CAPTURE NONE;
ALTER TABLE KMT_KMIP_GLOBAL_NAMES ADD CONSTRAINT KMT_KMIP_GN_PK PRIMARY KEY (NAME_UUID);
ALTER TABLE KMT_KMIP_GLOBAL_NAMES ADD CONSTRAINT UNQ_NAME UNIQUE (NAME_VALUE, NAME_TYPE);
CREATE INDEX KMT_KMIP_GLOBAL_NAMES_IDX ON KMT_KMIP_GLOBAL_NAMES (MANAGED_OBJECT_UUID) PCTFREE 0;

CREATE TABLE KMT_KMIP_ATTR_NAME (                
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
        NAME_UUID VARCHAR(64) NOT NULL,
        LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
  DATA CAPTURE NONE;
ALTER TABLE KMT_KMIP_ATTR_NAME 
    ADD CONSTRAINT UNQ_INSTANCE 
    UNIQUE (MANAGED_OBJECT_UUID, INDEX_ID);
ALTER TABLE KMT_KMIP_ATTR_NAME 
    ADD CONSTRAINT FK 
    FOREIGN KEY (NAME_UUID) REFERENCES KMT_KMIP_GLOBAL_NAMES (NAME_UUID) ON DELETE CASCADE;
CREATE INDEX KMT_KMIP_ATTR_NAME_IDX ON KMT_KMIP_ATTR_NAME (MANAGED_OBJECT_UUID) PCTFREE 0;
CREATE INDEX KMT_KMIP_ATTR_NAME_IDX2 ON KMT_KMIP_ATTR_NAME (NAME_UUID) PCTFREE 0;

CREATE TABLE KMT_KMIP_ATTR_OBJECTGROUP (
		GROUP_NAME VARCHAR(512) NOT NULL,
		MEMBER_OBJECT_UUID VARCHAR(64) NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_OBJECTGROUP ADD CONSTRAINT PK_OBJGROUP PRIMARY KEY (MEMBER_OBJECT_UUID, INDEX_ID);
CREATE INDEX KMT_KMIP_ATTR_OBJECTGROUP_IDX ON KMT_KMIP_ATTR_OBJECTGROUP (MEMBER_OBJECT_UUID) PCTFREE 0;

-- KMIP 1.2 addition
CREATE TABLE KMT_KMIP_ATTR_ALTERNATIVE_NAME (
		MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
		ALTERNATIVE_NAME VARCHAR(512) NOT NULL,
		TYPE SMALLINT NOT NULL,
		INDEX_ID SMALLINT NOT NULL,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_ATTR_ALTERNATIVE_NAME ADD CONSTRAINT PK_ALTNAME PRIMARY KEY (MANAGED_OBJECT_UUID, INDEX_ID);
CREATE INDEX KMT_KMIP_ATTR_ALTERNATIVE_NAME_IDX ON KMT_KMIP_ATTR_ALTERNATIVE_NAME (MANAGED_OBJECT_UUID) PCTFREE 0;
CREATE INDEX KMT_KMIP_ATTR_ALTERNATIVE_NAME_IDX2 ON KMT_KMIP_ATTR_ALTERNATIVE_NAME (ALTERNATIVE_NAME) PCTFREE 0;
CREATE INDEX KMT_KMIP_ATTR_ALTERNATIVE_NAME_IDX3 ON KMT_KMIP_ATTR_ALTERNATIVE_NAME (TYPE) PCTFREE 0;
-- end of KMIP 1.2 addition

-- outplan ?
CREATE TABLE KMT_KMIP_OBJECT_OPAQUE (
		UUID VARCHAR(64) NOT NULL,
		ARCHIVE_DATE TIMESTAMP,
		LAST_CHANGED_DATE TIMESTAMP,
		INITIAL_DATE TIMESTAMP NOT NULL,
		DESTROYDATE TIMESTAMP,
		ACTIVATIONDATE TIMESTAMP,
		DATA VARCHAR (16000) FOR BIT DATA,
		LARGE_DATA BLOB,
		CONTACT_INFO VARCHAR(1024),
		VERSION INT NOT NULL,	
		OPERATIONAL_POLICY VARCHAR(64),
		USAGE_VALUE DECIMAL(18,0),
		USAGE_TOTAL DECIMAL(18,0),
		USAGE_LIMIT_TYPE SMALLINT,
		OWNER VARCHAR(128),
		ORIGINAL_CREATION_DATE TIMESTAMP
	)
	IN TKLM_DATA_32K_LG INDEX IN TKLM_32K_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD CONSTRAINT PK_OBJ_OPAQUE PRIMARY KEY (UUID);
--ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD CONSTRAINT FK_OP_POLICY FOREIGN KEY (OPERATIONAL_POLICY)
--	REFERENCES KMT_KMIP_ATTR_OPERATIONAL_POLICY (UUID);
CREATE INDEX IDX_OPQOBJ_01 ON KMT_KMIP_OBJECT_OPAQUE(INITIAL_DATE) MINPCTUSED 20;
CREATE INDEX IDX_OPQOBJ_02 ON KMT_KMIP_OBJECT_OPAQUE (ACTIVATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_OPQOBJ_03 ON KMT_KMIP_OBJECT_OPAQUE (DESTROYDATE) MINPCTUSED 20;
CREATE INDEX IDX_OPQOBJ_04 ON KMT_KMIP_OBJECT_OPAQUE (OWNER) MINPCTUSED 20;
CREATE INDEX IDX_OPQOBJ_05 ON KMT_KMIP_OBJECT_OPAQUE (ORIGINAL_CREATION_DATE) MINPCTUSED 20;

CREATE TABLE KMT_KMIP_OBJECT_SECRET_DATA (
		UUID VARCHAR(64) NOT NULL,
		TYPE INT NOT NULL,
		CRYPTO_LENGTH INTEGER,			
		ACTIVATIONDATE TIMESTAMP,
		DEACTIVATION_DATE TIMESTAMP,		
		ARCHIVE_DATE TIMESTAMP,
		INITIAL_DATE TIMESTAMP NOT NULL,
		LAST_CHANGED_DATE TIMESTAMP NOT NULL,
		DESTROYDATE TIMESTAMP,
		COMPROMISE_OCCURRENCE_DATE TIMESTAMP,
		COMPROMISEDATE TIMESTAMP,
		REVOKE_REASON_CODE INTEGER,
		REVOKE_REASON_MESSAGE VARCHAR(2048),
		CONTACT_INFO VARCHAR(1024),
		ALIAS VARCHAR(256) NOT NULL, 
		KEYPASSWORD VARCHAR(32600),
		KEYSTORE_UUID VARCHAR(64) NOT NULL,
		VERSION INT NOT NULL,	
		OPERATIONAL_POLICY VARCHAR(64),
		OWNER VARCHAR(128),
		LEASE_TIME INTEGER,
		PREVSTATE INTEGER,
		FORMAT SMALLINT,
		CRYPTO_USAGE VARCHAR(32),
		ORIGINAL_CREATION_DATE TIMESTAMP
	)
	IN TKLM_DATA_LG INDEX IN TKLM_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_OBJECT_SECRET_DATA ADD CONSTRAINT PK_SECDATA PRIMARY KEY (UUID);
ALTER TABLE KMT_KMIP_OBJECT_SECRET_DATA ADD CONSTRAINT FK_KS_UUID FOREIGN KEY (KEYSTORE_UUID)
	REFERENCES KMT_KEYSTR (UUID) ON DELETE RESTRICT;
ALTER TABLE KMT_KMIP_OBJECT_SECRET_DATA ADD CONSTRAINT UN_SECDATA_1 UNIQUE (KEYSTORE_UUID,ALIAS);
CREATE INDEX IDX_SECDATA_01 ON KMT_KMIP_OBJECT_SECRET_DATA (INITIAL_DATE) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_02 ON KMT_KMIP_OBJECT_SECRET_DATA (DEACTIVATION_DATE) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_03 ON KMT_KMIP_OBJECT_SECRET_DATA (ACTIVATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_04 ON KMT_KMIP_OBJECT_SECRET_DATA (COMPROMISEDATE) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_05 ON KMT_KMIP_OBJECT_SECRET_DATA (DESTROYDATE) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_06 ON KMT_KMIP_OBJECT_SECRET_DATA (LEASE_TIME) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_07 ON KMT_KMIP_OBJECT_SECRET_DATA (OWNER) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_08 ON KMT_KMIP_OBJECT_SECRET_DATA (REVOKE_REASON_CODE) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_09 ON KMT_KMIP_OBJECT_SECRET_DATA (ALIAS) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_10 ON KMT_KMIP_OBJECT_SECRET_DATA (PREVSTATE) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_11 ON KMT_KMIP_OBJECT_SECRET_DATA (CRYPTO_USAGE) MINPCTUSED 20;
CREATE INDEX IDX_SECDATA_12 ON KMT_KMIP_OBJECT_SECRET_DATA (ORIGINAL_CREATION_DATE) MINPCTUSED 20;

CREATE TABLE KMT_KMIP_OBJECT_TEMPLATE (
		UUID VARCHAR(64) NOT NULL,
		ALGORITHM VARCHAR(512),
		CRYPTO_LENGTH INTEGER,
		CONTACT_INFO VARCHAR(1024),
		INITIAL_DATE TIMESTAMP NOT NULL,
		ACTIVATIONDATE TIMESTAMP,
		DESTROYDATE TIMESTAMP,
		ARCHIVE_DATE TIMESTAMP,
		LAST_CHANGED_DATE TIMESTAMP NOT NULL,
		CRYPTO_USAGE VARCHAR(32),
		PROCESS_START_DATE TIMESTAMP,
		PROTECT_STOP_DATE TIMESTAMP,
		DEACTIVATION_DATE TIMESTAMP,
		VERSION INT NOT NULL,
		USAGE_VALUE DECIMAL(18,0),
		USAGE_TOTAL DECIMAL(18,0),
		USAGE_LIMIT_TYPE SMALLINT,		
		OWNER VARCHAR(128),
		OPERATIONAL_POLICY VARCHAR(64),
-- new field                
		BODY_UUID VARCHAR(64),
		ORIGINAL_CREATION_DATE TIMESTAMP
	)
	IN TKLM_DATA_LG INDEX IN TKLM_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_OBJECT_TEMPLATE ADD CONSTRAINT PK_TEMPLATE PRIMARY KEY (UUID);
CREATE INDEX IDX_TMPL_01 ON KMT_KMIP_OBJECT_TEMPLATE (INITIAL_DATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_02 ON KMT_KMIP_OBJECT_TEMPLATE (DEACTIVATION_DATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_03 ON KMT_KMIP_OBJECT_TEMPLATE (ACTIVATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_04 ON KMT_KMIP_OBJECT_TEMPLATE (DESTROYDATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_05 ON KMT_KMIP_OBJECT_TEMPLATE (ALGORITHM) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_06 ON KMT_KMIP_OBJECT_TEMPLATE (CRYPTO_LENGTH) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_07 ON KMT_KMIP_OBJECT_TEMPLATE (OWNER) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_08 ON KMT_KMIP_OBJECT_TEMPLATE (PROCESS_START_DATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_09 ON KMT_KMIP_OBJECT_TEMPLATE (PROTECT_STOP_DATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_10 ON KMT_KMIP_OBJECT_TEMPLATE (USAGE_VALUE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_11 ON KMT_KMIP_OBJECT_TEMPLATE (USAGE_TOTAL) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_12 ON KMT_KMIP_OBJECT_TEMPLATE (USAGE_LIMIT_TYPE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_13 ON KMT_KMIP_OBJECT_TEMPLATE (CRYPTO_USAGE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_14 ON KMT_KMIP_OBJECT_TEMPLATE (BODY_UUID) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_15 ON KMT_KMIP_OBJECT_TEMPLATE (ORIGINAL_CREATION_DATE) MINPCTUSED 20;

CREATE TABLE KMT_KMIP_OBJECT_TEMPLATE_BODY (
		UUID VARCHAR(64) NOT NULL,
		PARENT_UUID VARCHAR(64) NOT NULL,
		ALGORITHM VARCHAR(512),
		CRYPTO_LENGTH INTEGER,
		CONTACT_INFO VARCHAR(1024),
		INITIAL_DATE TIMESTAMP NOT NULL,
		ACTIVATIONDATE TIMESTAMP,
		DESTROYDATE TIMESTAMP,
		ARCHIVE_DATE TIMESTAMP,
		LAST_CHANGED_DATE TIMESTAMP NOT NULL,
		CRYPTO_USAGE VARCHAR(32),
		PROCESS_START_DATE TIMESTAMP,
		PROTECT_STOP_DATE TIMESTAMP,
		DEACTIVATION_DATE TIMESTAMP,
		VERSION INT NOT NULL,
		USAGE_VALUE DECIMAL(18,0),
		USAGE_TOTAL DECIMAL(18,0),
		USAGE_LIMIT_TYPE SMALLINT,		
		OWNER VARCHAR(128),
		OPERATIONAL_POLICY VARCHAR(64)
	)
	IN TKLM_DATA_LG INDEX IN TKLM_IDX
	DATA CAPTURE NONE ;
ALTER TABLE KMT_KMIP_OBJECT_TEMPLATE_BODY ADD CONSTRAINT PK_TEMPLATE_BODY PRIMARY KEY (UUID);
CREATE INDEX IDX_TMPL_B_01 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (INITIAL_DATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_02 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (DEACTIVATION_DATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_03 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (ACTIVATIONDATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_04 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (DESTROYDATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_05 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (ALGORITHM) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_06 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (CRYPTO_LENGTH) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_07 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (OWNER) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_08 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (PROCESS_START_DATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_09 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (PROTECT_STOP_DATE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_10 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (USAGE_VALUE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_11 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (USAGE_TOTAL) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_12 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (USAGE_LIMIT_TYPE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_13 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (CRYPTO_USAGE) MINPCTUSED 20;
CREATE INDEX IDX_TMPL_B_14 ON KMT_KMIP_OBJECT_TEMPLATE_BODY (PARENT_UUID) MINPCTUSED 20;

ALTER TABLE KMT_KMIP_OBJECT_TEMPLATE_BODY 
    ADD CONSTRAINT FK 
    FOREIGN KEY (PARENT_UUID) REFERENCES KMT_KMIP_OBJECT_TEMPLATE (UUID) ON DELETE CASCADE;

CREATE TABLE KMT_CLIENT (
		IP_HOSTNAME VARCHAR(255),
		PORT INTEGER,
		PRI_EMAIL VARCHAR(256),
		PRI_PHONE VARCHAR(15),
		BKUP_EMAIL VARCHAR(256),
		BKUP_PHONE VARCHAR(15),
		CAPABILITIES VARCHAR(512),
		MECHANISMS VARCHAR(256),
		INFO VARCHAR(256),
		CRYPTO_USAGE VARCHAR(32),
		UUID VARCHAR(128) PRIMARY KEY NOT NULL,
		NAME VARCHAR(64),
		TYPE INTEGER NOT NULL,
		DEV_TYPE_UUID SMALLINT,
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		ADD_COL_3 VARCHAR(256),
		ADD_COL_4 VARCHAR(256),
		ADD_COL_5 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP ,
		CONSTRAINT CL_FK1 FOREIGN KEY (DEV_TYPE_UUID) REFERENCES KMT_DEVICE_TYPE (UUID) ON DELETE CASCADE
	);


CREATE TABLE KMT_CLIENT_KEY_CERT_LIST (
		CLIENT_UUID VARCHAR(128) NOT NULL,
		KEYCERT_UUID VARCHAR(128) NOT NULL,
		KEYCERT_HASH VARCHAR(256) FOR BIT DATA,
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	);

ALTER TABLE KMT_CLIENT_KEY_CERT_LIST ADD CONSTRAINT UQ_CLIENT_CERT UNIQUE (CLIENT_UUID,KEYCERT_UUID);

ALTER TABLE KMT_CLIENT_KEY_CERT_LIST ADD CONSTRAINT CKL_FK1 FOREIGN KEY (CLIENT_UUID)
  REFERENCES KMT_CLIENT (UUID)
  ON DELETE CASCADE;
  
ALTER TABLE KMT_CLIENT_KEY_CERT_LIST ADD CONSTRAINT CKL_FK2 FOREIGN KEY (KEYCERT_UUID)
  REFERENCES KMT_CERT (UUID)
  ON DELETE CASCADE;
  
CREATE INDEX IDX_CLT_KL_01 ON KMT_CLIENT_KEY_CERT_LIST (CLIENT_UUID, KEYCERT_UUID) MINPCTUSED 20;
CREATE INDEX IDX_CLT_KL_02 ON KMT_CLIENT_KEY_CERT_LIST (CLIENT_UUID) MINPCTUSED 20;
CREATE INDEX IDX_CLT_KL_03 ON KMT_CLIENT_KEY_CERT_LIST (KEYCERT_UUID) MINPCTUSED 20;


CREATE TABLE KMT_NOTIFICATIONS (
		UUID VARCHAR(128) NOT NULL,
		CLIENT_UUID VARCHAR(128) NOT NULL,
		KEYCERT_UUID VARCHAR(128) NOT NULL,
		STATE INTEGER,
		NOTIFY_POLICY_UUID VARCHAR(128) NOT NULL,
		NUM_NOTIFY_ATTEMPTS INTEGER NOT NULL,
		NUM_NOTIFY_REMAINING INTEGER NOT NULL,
		TIMESTAMP_LAST_NOTIFY TIMESTAMP,
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		ADD_COL_3 VARCHAR(256),
		ADD_COL_4 VARCHAR(256),
		ADD_COL_5 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	);

ALTER TABLE KMT_NOTIFICATIONS ADD CONSTRAINT NTFN_FK1 FOREIGN KEY (CLIENT_UUID)
  REFERENCES KMT_CLIENT (UUID)
  ON DELETE CASCADE;
  
ALTER TABLE KMT_NOTIFICATIONS ADD CONSTRAINT NTFN_FK2 FOREIGN KEY (KEYCERT_UUID)
  REFERENCES KMT_KEY (UUID)
  ON DELETE CASCADE;
  
ALTER TABLE KMT_NOTIFICATIONS ADD CONSTRAINT NTFN_FK3 FOREIGN KEY (KEYCERT_UUID)
  REFERENCES KMT_CERT (UUID)
  ON DELETE CASCADE;

CREATE INDEX IDX_NOTIFN_01 ON KMT_NOTIFICATIONS (UUID) MINPCTUSED 20;

CREATE TABLE KMT_NOTIFICATION_POLICY (
		UUID VARCHAR(128) NOT NULL,
		LONG_NOTIFY_PERIOD INTEGER,
		SHORT_NOTIFY_PERIOD INTEGER,
		PRI_NOTIFY_TYPE INTEGER,
		BKUP_NOTIFY_TYPE INTEGER,
		NUM_NOTIFY_FAILURES INTEGER,
		NUM_NOTIFY INTEGER,
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		ADD_COL_3 VARCHAR(256),
		ADD_COL_4 VARCHAR(256),
		ADD_COL_5 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	);

CREATE INDEX IDX_NOTIFN_PLCY_01 ON KMT_NOTIFICATION_POLICY (UUID) MINPCTUSED 20;
		


------------------------------- END KMIP RELATED UPDATES ----------------------------------

-------------------------------- START DELL LICENSE UPDATES --------------------------------

CREATE TABLE KMT_LICENSE (
    DEVICETYPE SMALLINT NOT NULL,
    COUNT INTEGER NOT NULL, 
    CREATIONTIME TIMESTAMP NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
    )
    IN TKLM_DATA_SM INDEX IN TKLM_IDX
    DATA CAPTURE NONE;

ALTER TABLE KMT_LICENSE ADD CONSTRAINT PK_LICENSE PRIMARY KEY (DEVICETYPE);

------------------------------- END DELL LICENSE UPDATES ----------------------------------
-------------------------------- START DELL BACKUP BEFORE SERVING UPDATES --------------------------------

CREATE TABLE KMT_BACKUP (
	LASTBACKUPDATE TIMESTAMP,
	LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_IDX
    DATA CAPTURE NONE;

INSERT INTO KMT_BACKUP (LASTBACKUPDATE) VALUES (NULL);
	
------------------------------- END DELL BACKUP BEFORE SERVING UPDATES ----------------------------------
------------------------------- END V2 UPDATES -------------------------------------------------


------------------------------------------------------ V2.6 update  ---------------------------------------

ALTER TABLE KMT_CLIENT ADD COLUMN PUUID VARCHAR(128);

ALTER TABLE KMT_CLIENT ADD CONSTRAINT CLIENT_PARENT_FK FOREIGN KEY (PUUID)
  REFERENCES KMT_CLIENT (UUID)
  ON DELETE CASCADE;


CREATE TABLE KMT_OBJECT (
		UUID VARCHAR(128) PRIMARY KEY NOT NULL,
		PUUID VARCHAR(128),
		NAME VARCHAR(64),
		TYPE INTEGER NOT NULL,
		TYPE_TABLE VARCHAR(128),		
		ADD_COL_1 VARCHAR(256),
		ADD_COL_2 VARCHAR(256),
		ADD_COL_3 VARCHAR(256),
		ADD_COL_4 VARCHAR(256),
		ADD_COL_5 VARCHAR(256),
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	);



ALTER TABLE KMT_OBJECT ADD CONSTRAINT COBJ_PARENT_FK FOREIGN KEY (PUUID)
  REFERENCES KMT_OBJECT (UUID)
  ON DELETE CASCADE;


CREATE TABLE KMT_OBJECT_CLIENT_RN (
		CLIENT_UUID VARCHAR(128) NOT NULL,
		OBJECT_UUID VARCHAR(128) NOT NULL,
		USED INTEGER);


ALTER TABLE KMT_OBJECT_CLIENT_RN ADD CONSTRAINT COBJ_CLI_RN_CLI_FK1 FOREIGN KEY (CLIENT_UUID)
  REFERENCES KMT_CLIENT (UUID)
  ON DELETE CASCADE;

ALTER TABLE KMT_OBJECT_CLIENT_RN ADD CONSTRAINT COBJ_CLI_RN_OBJ_FK1 FOREIGN KEY (OBJECT_UUID)
  REFERENCES KMT_OBJECT (UUID)
  ON DELETE CASCADE;

ALTER TABLE KMT_OBJECT_CLIENT_RN ADD CONSTRAINT PK_OBJCLIRN  PRIMARY KEY (CLIENT_UUID, OBJECT_UUID);

------------------------------------------------------ V2.7 update  ---------------------------------------

ALTER TABLE KMT_KMIP_ATTR_CRYPTOPARAMS ADD COLUMN RANDOM_IV SMALLINT;

CREATE TABLE KMT_KMIP_CLIENT_ENCRYPT_DECRYPT (
		CLIENT_UUID VARCHAR(128),
		KEY_UUID VARCHAR(64) NOT NULL,
		IV_FLAG INTEGER NOT NULL,
		OPERATION INTEGER,
		LAST_UPDATE_TIMESTAMP TIMESTAMP );
		
ALTER TABLE KMT_KMIP_CLIENT_ENCRYPT_DECRYPT ADD CONSTRAINT KEY_PARENT_FK FOREIGN KEY (KEY_UUID)
  REFERENCES KMT_KEY (UUID)
  ON DELETE CASCADE;
  
ALTER TABLE KMT_KMIP_CLIENT_ENCRYPT_DECRYPT ADD CONSTRAINT CLIENT_PARENT_FK FOREIGN KEY (CLIENT_UUID)
  REFERENCES KMT_CLIENT (UUID)
  ON DELETE CASCADE;

ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN OPAQUE_DATA_TYPE INTEGER NOT NULL WITH DEFAULT 0;
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN LEASE_TIME INTEGER;
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN DEACTIVATION_DATE TIMESTAMP;
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN COMPROMISE_OCCURRENCE_DATE TIMESTAMP;
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN COMPROMISE_DATE TIMESTAMP;
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN REVOKE_REASON_CODE INTEGER;
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN REVOKE_REASON_MESSAGE VARCHAR(2048);

CREATE TABLE KMT_KEY_GROUPS (                
		UUID VARCHAR(64) PRIMARY KEY NOT NULL,
        NAME VARCHAR(256) NOT NULL,
		KEY_GROUP_TYPE SMALLINT NOT NULL,
		REF_IDENTIFIER VARCHAR(256),
		DESCRIPTION VARCHAR(512),
        LAST_UPDATE_TIMESTAMP TIMESTAMP 
  );
  
 CREATE TABLE KMT_KEY_GROUP_MEMBERS (                
		GROUP_ID VARCHAR(64) NOT NULL,
        MEMBER_TYPE SMALLINT NOT NULL,
		MEMBER_ID VARCHAR(256) NOT NULL,
        LAST_UPDATE_TIMESTAMP TIMESTAMP 
  );
  
ALTER TABLE KMT_KEY_GROUP_MEMBERS 
    ADD CONSTRAINT GROUP_ID_FK 
    FOREIGN KEY (GROUP_ID) REFERENCES KMT_KEY_GROUPS (UUID) ON DELETE CASCADE;
    
ALTER TABLE KMT_KEY_GROUP_MEMBERS 
    ADD CONSTRAINT MEMBER_ID_FK 
    FOREIGN KEY (MEMBER_ID) REFERENCES KMT_KEY_GROUPS (UUID) ON DELETE CASCADE;
    
-- Adds the default Key groups
    
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1', '3592', 0, '1', '3592 Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '2', 'LTO', 0, '2', 'LTO Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '3', 'DS8000', 0, '3',  'DS8000 Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '4', 'DS5000', 0, '4', 'DS5000 Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '5', 'GENERIC', 0, '5', 'GENERIC Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1000', 'BRCD_ENCRYPTOR', 0, '1000', 'BRCD_ENCRYPTOR Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1001', 'ONESECURE', 0, '1001', 'ONESECURE Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1002', 'ETERNUS_DX', 0, '1002', 'ETERNUS_DX Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1004', 'XIV', 0, '1004', 'XIV Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '12', 'GPFS', 0, '12', 'GPFS Key Group');
INSERT INTO KMT_KEY_GROUPS  (UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES( '1003', 'IBM_SYSTEM_X_SED', 0, '1003', 'IBM_SYSTEM_X_SED Key Group');

CREATE TABLE KMT_CFGT_INSTDETAILS(
	INPUTSEED BIGINT NOT NULL,
	INSTANCEID VARCHAR(64) NOT NULL,
	GENERATEDTIME TIMESTAMP NOT NULL);
	
CREATE TABLE KMT_ALIAS_HANDLE(
	HANDLE_ID VARCHAR(64) NOT NULL,
	PREFIX VARCHAR(8) NOT NULL,
	INSTANCE_ID VARCHAR(64) NOT NULL,
	COUNTER_OFFSET BIGINT NOT NULL);

ALTER TABLE KMT_ALIAS_HANDLE ADD CONSTRAINT UQ_PREFIX UNIQUE (PREFIX,INSTANCE_ID);


CREATE TABLE KMT_CONFLICT_CHANGES (
	UUID VARCHAR(64)  PRIMARY KEY NOT NULL,
	OBJECT_TYPE SMALLINT NOT NULL,
	CHANGE_TYPE SMALLINT NOT NULL,
	OLD_VALUE VARCHAR(512) NOT NULL,
	NEW_VALUE VARCHAR(512) NOT NULL,
	CHANGED_TIME TIMESTAMP NOT NULL );
	
CREATE TABLE KMT_EXPORT_KEYGROUP_SUMMARY (
		EXPORT_UUID VARCHAR(64) NOT NULL,
		START_TIME TIMESTAMP NOT NULL,
        END_TIME TIMESTAMP,
		OPERATION SMALLINT NOT NULL,
		STATUS SMALLINT NOT NULL,
		TARGET_EXPECTED INTEGER,
		TARGET_COMPLETED INTEGER,
		SUMMARY CLOB,
		FILE_NAME VARCHAR(512),
		DEVICE_TYPE VARCHAR(128),
		DESCRIPTION VARCHAR(512),
        LAST_UPDATE_TIMESTAMP TIMESTAMP 
  );
  CREATE TABLE KMT_MM_INSTANCE (
		INSTANCE_ID VARCHAR(64) NOT NULL,
		NAME VARCHAR(255) NOT NULL,
		CLUSTER_NAME VARCHAR(255),
		IP_HOSTNAME VARCHAR(255) NOT NULL,
		TCP_PORT INTEGER NOT NULL,
		HTTP_PORT INTEGER NOT NULL,
		ADMIN_PORT INTEGER NOT NULL,
		SSL_PORT INTEGER NOT NULL,
		KMIP_PORT INTEGER NOT NULL,
		DB_PORT INTEGER NOT NULL,
		HADR_PORT INTEGER,
		AGENT_PORT INTEGER NOT NULL,
		HADR_TYPE SMALLINT NOT NULL DEFAULT 0,
		INSTANCE_TYPE SMALLINT NOT NULL DEFAULT 0,
		STATUS SMALLINT NOT NULL DEFAULT 0,
		DB_NAME VARCHAR(255) NOT NULL,
		DB_USERNAME VARCHAR(255) NOT NULL,
		DB_PASSWORD VARCHAR(255) NOT NULL,
		SKLM_USERNAME VARCHAR(255) NOT NULL,
		SKLM_PASSWORD VARCHAR(255) NOT NULL,
		WAS_USERNAME VARCHAR(255) NOT NULL,
		WAS_PASSWORD VARCHAR(255) NOT NULL,
		AGENT_KEYSTORE_PASSWORD VARCHAR(255) NOT NULL,
		STANDBY_PRIORITY_INDEX SMALLINT,
		ACTING_PRIMARY SMALLINT NOT NULL DEFAULT 0,
		IS_FAULTY SMALLINT NOT NULL DEFAULT 0,
		IS_SERVER_RESTART_REQUIRED SMALLINT NOT NULL DEFAULT 0,
		OWNER_EMAIL_ADDR1 VARCHAR(255),
		OWNER_EMAIL_ADDR2 VARCHAR(255),
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
	
	ALTER TABLE KMT_MM_INSTANCE ADD CONSTRAINT UNIQUE_INSTANCE_ID UNIQUE (INSTANCE_ID);
	ALTER TABLE KMT_MM_INSTANCE ADD CONSTRAINT UNIQUE_IP_HOSTNAME UNIQUE (IP_HOSTNAME);

	CREATE TABLE KMT_MM_INSTANCE_STATUS (
		INSTANCE_ID VARCHAR(64) NOT NULL,
		TIME TIMESTAMP NOT NULL,
		SERVICE VARCHAR(64) NOT NULL,
		TCP_PORT_STATUS SMALLINT,
		HTTP_PORT_STATUS SMALLINT,
		ADMIN_PORT_STATUS SMALLINT,
		SSL_PORT_STATUS SMALLINT,
		KMIP_PORT_STATUS SMALLINT,
		DB_PORT_STATUS SMALLINT,
		HADR_PORT_STATUS SMALLINT,
		AGENT_PORT_STATUS SMALLINT,
		NOTIFICATION_SENT_TIME VARCHAR(255),
		NOTIFICATION_SENT_T0 VARCHAR(255),
		AGENTS_REACHABLE VARCHAR(2048),
		HADR_STATUS VARCHAR(512),
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
	DATA CAPTURE NONE ;
	
	ALTER TABLE KMT_MM_INSTANCE_STATUS ADD CONSTRAINT INSTANCE_ID_FK FOREIGN KEY (INSTANCE_ID) 
	REFERENCES KMT_MM_INSTANCE (INSTANCE_ID) ON DELETE CASCADE;
		
CREATE TABLE KMT_MM_AGENT_TRUSTSTORE  (
		INSTANCE_ID VARCHAR(64) NOT NULL,
		ALIAS_NAME VARCHAR(255) NOT NULL,
		KEY_DATA  BLOB NOT NULL,
		TRUSTED SMALLINT NOT NULL DEFAULT 1,
		LAST_UPDATE_TIMESTAMP TIMESTAMP 
	)
	 IN TKLM_DATA_LG INDEX IN TKLM_IDX
	DATA CAPTURE NONE ;

	ALTER TABLE KMT_MM_AGENT_TRUSTSTORE ADD CONSTRAINT UNIQUE_INSTANCE_TT_ID UNIQUE (INSTANCE_ID, ALIAS_NAME);

CREATE TABLE KMT_KMIP_WRAPDATA (
	MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
	MACSIGN_KEY_UUID VARCHAR(64),
	WRAP_KEY_UUID VARCHAR(64),
	BLOCK_CIPHER_MODE INTEGER,
	PADDING_METHOD INTEGER,
	HASHING_ALGORITHM INTEGER,
	WRAPPING_METHOD INTEGER,
	ENCODING_OPTIONS INTEGER,
	MAC_SIGNATURE VARCHAR(256) FOR BIT DATA,
	RANDOM_IV VARCHAR(256) FOR BIT DATA,
	foreign key(MANAGED_OBJECT_UUID) references KMT_KEY(UUID),
	foreign key(MACSIGN_KEY_UUID) references KMT_KEY(UUID),
	foreign key(WRAP_KEY_UUID) references KMT_KEY(UUID)
)
IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
DATA CAPTURE NONE;

CREATE TABLE KMT_CHANGESET_TRACK (
	OBJECT_TYPE VARCHAR(64),
	NAME VARCHAR(64),
	UUID VARCHAR(64),
	REF_TABLE_NAME  VARCHAR(64) NOT NULL,    
	REF_UUID  VARCHAR(64),
	REF_NAME_ALIAS  VARCHAR(512),
	OPERATION_TYPE  SMALLINT NOT NULL,
	CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
	LAST_UPDATE_TIMESTAMP  TIMESTAMP NOT NULL
)
IN TKLM_DATA_LG INDEX IN TKLM_4K_IDX
DATA CAPTURE NONE;

CREATE TABLE KMT_KMIP_ATTR_HSMATTRIBUTES (
	MANAGED_OBJECT_UUID VARCHAR(64) NOT NULL,
	OBJECT_TYPE VARCHAR(64),
	SENSITIVE SMALLINT,
	ALWAYS_SENSITIVE SMALLINT,
	EXTRACTABLE SMALLINT,
	NEVER_EXTRACTABLE SMALLINT,
	PKCS12_FRIENDLY_NAME VARCHAR(64),
	SHORT_UNIQUE_IDENTIFIER VARCHAR(64),
	LAST_UPDATE_TIMESTAMP TIMESTAMP NOT NULL
)
IN TKLM_DATA_SM INDEX IN TKLM_4K_IDX
DATA CAPTURE NONE;

CREATE TABLE KMT_DEVICE_TYPE_MASTER_KEY (
	UUID VARCHAR(64) PRIMARY KEY NOT NULL,
	ALIAS VARCHAR(256) UNIQUE NOT NULL,
	KEY_ALGO VARCHAR(64) NOT NULL,
	KEY_SIZE INT NOT NULL,
	KEY_DATA BLOB NOT NULL,
	ROTATION_PERIOD_DAYS INT NOT NULL,
	CREATION_DATE TIMESTAMP NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP NOT NULL
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE;


CREATE TABLE KMT_MASTER_KEY_MGMT (
	SRNO INT GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1) PRIMARY KEY NOT NULL,
	OPERATION INT NOT NULL,
	FROM_STORE INT NOT NULL,
	TO_STORE INT NOT NULL,
	STATUS  INT NOT NULL,
	STARTED_ON_HOST VARCHAR(256) NOT NULL,
	STARTED_BY_USER VARCHAR(256) NOT NULL,
	MASTER_KEY_SIZE INT NOT NULL,
	TABLES_PROCESSED VARCHAR(1024),
	DESCRIPTION VARCHAR(256),
	CREATION_DATE TIMESTAMP NOT NULL,
	LAST_UPDATE_TIMESTAMP TIMESTAMP NOT NULL
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE;

INSERT INTO KMT_DEVICE_TYPE(UUID,BASE_FAMILY_ID,VERSION,NAME,ROLE_NAME) VALUES(14,14,0,'PEER_TO_PEER','PEER_TO_PEER');	
		
INSERT INTO KMT_KEY_GROUPS(UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES(14,'PEER_TO_PEER',0,14,'PEER_TO_PEER KEY GROUP');	
				
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,UUID) VALUES ('enableKMIPDelete', 'true', 14, 'DEVTYPEATTR-25');
		
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,UUID) VALUES ('AddNewCertsToPending', 'false', 14, 'DEVTYPEATTR-26');

INSERT INTO KMT_DEVICE_TYPE(UUID,BASE_FAMILY_ID,VERSION,NAME,ROLE_NAME) VALUES(15,12,0,'DS8000_TCT','DS8000_TCT');	
		
INSERT INTO KMT_KEY_GROUPS(UUID, NAME, KEY_GROUP_TYPE, REF_IDENTIFIER, DESCRIPTION) VALUES(15,'DS8000_TCT',0,12,'DS8000_TCT KEY GROUP');
						
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,UUID) VALUES ('enableKMIPDelete', '0', 15, 'DEVTYPEATTR-27');
		
INSERT INTO KMT_DEVICE_TYPE_ATTRIBUTES (ATTR_NAME,ATTR_VALUE,DEVICE_TYPE_ID,UUID) VALUES ('AddNewCertsToPending', 'false', 15, 'DEVTYPEATTR-28');

CREATE TABLE KMT_CLIENT_POLICY (
		UUID VARCHAR(64) NOT NULL,
		OPERATION VARCHAR(64),
		TYPE_OF_OBJECT VARCHAR(64),
		LAST_UPDATE_TIMESTAMP TIMESTAMP
	)
	IN TKLM_DATA_LG INDEX IN TKLM_4K_IDX
DATA CAPTURE NONE;

CREATE TABLE KMT_CLIENT_POLICY_ACCESS (
		CLIENT_UUID VARCHAR(64),
		CLIENT_POLICY_UUID VARCHAR(64) NOT NULL,
		TYPE_OF_ENTITY VARCHAR(64) NOT NULL,
		ENTITY_REF VARCHAR(64),
		LAST_UPDATE_TIMESTAMP TIMESTAMP
	)
	IN TKLM_DATA_LG INDEX IN TKLM_4K_IDX
DATA CAPTURE NONE;

CREATE TABLE KMT_CLIENT_USERS (
		UUID VARCHAR(64) NOT NULL,
		CLIENT_UUID VARCHAR(64),
		USER_ID VARCHAR(64),
		LAST_UPDATE_TIMESTAMP TIMESTAMP
	)
	IN TKLM_DATA_LG INDEX IN TKLM_4K_IDX
DATA CAPTURE NONE;

ALTER TABLE KMT_CLIENT_POLICY ADD CONSTRAINT PK_CLIENT_POLICY PRIMARY KEY (UUID);

ALTER TABLE KMT_CLIENT_USERS ADD CONSTRAINT PK_CLIENT_USERS PRIMARY KEY (UUID);

ALTER TABLE KMT_CLIENT_POLICY_ACCESS ADD CONSTRAINT FK1_CLIENT_POLICY_ACCESS FOREIGN KEY
	(CLIENT_UUID)
	REFERENCES KMT_CLIENT
	(UUID)
	ON DELETE CASCADE;

ALTER TABLE KMT_CLIENT_POLICY_ACCESS ADD CONSTRAINT FK2_CLIENT_POLICY_ACCESS FOREIGN KEY (CLIENT_POLICY_UUID) REFERENCES KMT_CLIENT_POLICY (UUID);

ALTER TABLE KMT_CLIENT_USERS ADD CONSTRAINT FK1_CLIENT_USERS FOREIGN KEY (CLIENT_UUID) REFERENCES KMT_CLIENT (UUID) ON DELETE CASCADE;
	
ALTER TABLE KMT_DEVICE_TYPE ADD COLUMN DEVICE_GROUP_TYPE VARCHAR(64);

ALTER TABLE KMT_KMIP_OBJECT_SECRET_DATA ADD COLUMN DEVICE_TYPE_ID SMALLINT;
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN DEVICE_TYPE_ID SMALLINT;

ALTER TABLE KMT_KEY ADD COLUMN CREATED_BY VARCHAR(128);
ALTER TABLE KMT_CERT ADD COLUMN CREATED_BY VARCHAR(128);
ALTER TABLE KMT_KMIP_OBJECT_SECRET_DATA ADD COLUMN CREATED_BY VARCHAR(128);
ALTER TABLE KMT_KMIP_OBJECT_OPAQUE ADD COLUMN CREATED_BY VARCHAR(128);

INSERT INTO KMT_CLIENT_POLICY (UUID,OPERATION,TYPE_OF_OBJECT) VALUES ('policy-1','CREATE','*')
,('policy-2','CREATE_KEY_PAIR','*')
,('policy-3','REGISTER','*')
,('policy-4','CERTIFY','*')
,('policy-5','VALIDATE','*')
,('policy-6','QUERY','*')
,('policy-7','CANCEL','*')
,('policy-8','POLL','*')
,('policy-9','RE_KEY','SECRETOBJECT')
,('policy-10','RE_KEY_KEY_PAIR','SECRETOBJECT')
,('policy-11','DERIVE_KEY','SECRETOBJECT')
,('policy-12','LOCATE','SECRETOBJECT')
,('policy-13','CHECK','SECRETOBJECT')
,('policy-14','GET','SECRETOBJECT')
,('policy-15','GET_ATTRIBUTES','SECRETOBJECT')
,('policy-16','GET_ATTRIBUTE_LIST','SECRETOBJECT')
,('policy-17','ADD_ATTRIBUTE','SECRETOBJECT')
,('policy-18','MODIFY_ATTRIBUTE','SECRETOBJECT')
,('policy-19','DELETE_ATTRIBUTE','SECRETOBJECT')
,('policy-20','OBTAIN_LEASE','SECRETOBJECT')
,('policy-21','GET_USAGE_ALLOCATION','SECRETOBJECT')
,('policy-22','ACTIVATE','SECRETOBJECT')
,('policy-23','REVOKE','SECRETOBJECT')
,('policy-24','DESTROY','SECRETOBJECT')
,('policy-25','ARCHIVE','SECRETOBJECT')
,('policy-26','RECOVER','SECRETOBJECT')
,('policy-27','CERTIFY','PUBLICOBJECT')
,('policy-28','RE_CERTIFY','PUBLICOBJECT')
,('policy-29','LOCATE','PUBLICOBJECT')
,('policy-30','CHECK','PUBLICOBJECT')
,('policy-31','GET','PUBLICOBJECT')
,('policy-32','GET_ATTRIBUTES','PUBLICOBJECT')
,('policy-33','GET_ATTRIBUTE_LIST','PUBLICOBJECT')
,('policy-34','ADD_ATTRIBUTE','PUBLICOBJECT')
,('policy-35','MODIFY_ATTRIBUTE','PUBLICOBJECT')
,('policy-36','DELETE_ATTRIBUTE','PUBLICOBJECT')
,('policy-37','OBTAIN_LEASE','PUBLICOBJECT')
,('policy-38','ACTIVATE','PUBLICOBJECT')
,('policy-39','REVOKE','PUBLICOBJECT')
,('policy-40','DESTROY','PUBLICOBJECT')
,('policy-41','ARCHIVE','PUBLICOBJECT')
,('policy-42','RECOVER','PUBLICOBJECT')
,('policy-43','LOCATE','TEMPLATE')
,('policy-44','GET','TEMPLATE')
,('policy-45','GET_ATTRIBUTES','TEMPLATE')
,('policy-46','GET_ATTRIBUTE_LIST','TEMPLATE')
,('policy-47','ADD_ATTRIBUTE','TEMPLATE')
,('policy-48','MODIFY_ATTRIBUTE','TEMPLATE')
,('policy-49','DELETE_ATTRIBUTE','TEMPLATE');

INSERT INTO KMT_CLIENT_POLICY_ACCESS(CLIENT_POLICY_UUID,TYPE_OF_ENTITY,ENTITY_REF) VALUES ('policy-1','SYSTEM','*')
,('policy-2','SYSTEM','*')
,('policy-3','SYSTEM','*')
,('policy-4','SYSTEM','*')
,('policy-5','SYSTEM','*')
,('policy-6','SYSTEM','*')
,('policy-7','SYSTEM','*')
,('policy-8','SYSTEM','*')
,('policy-9','SYSTEM','=')
,('policy-10','SYSTEM','=')
,('policy-11','SYSTEM','=')
,('policy-12','SYSTEM','=')
,('policy-13','SYSTEM','=')
,('policy-14','SYSTEM','=')
,('policy-15','SYSTEM','=')
,('policy-16','SYSTEM','=')
,('policy-17','SYSTEM','=')
,('policy-18','SYSTEM','=')
,('policy-19','SYSTEM','=')
,('policy-20','SYSTEM','=')
,('policy-21','SYSTEM','=')
,('policy-22','SYSTEM','=')
,('policy-23','SYSTEM','=')
,('policy-24','SYSTEM','=')
,('policy-25','SYSTEM','=')
,('policy-26','SYSTEM','=')
,('policy-27','SYSTEM','=')
,('policy-28','SYSTEM','=')
,('policy-29','SYSTEM','*')
,('policy-30','SYSTEM','*')
,('policy-31','SYSTEM','*')
,('policy-32','SYSTEM','*')
,('policy-33','SYSTEM','*')
,('policy-34','SYSTEM','=')
,('policy-35','SYSTEM','=')
,('policy-36','SYSTEM','=')
,('policy-37','SYSTEM','*')
,('policy-38','SYSTEM','=')
,('policy-39','SYSTEM','=')
,('policy-40','SYSTEM','=')
,('policy-41','SYSTEM','=')
,('policy-42','SYSTEM','=')
,('policy-43','SYSTEM','=')
,('policy-44','SYSTEM','=')
,('policy-45','SYSTEM','=')
,('policy-46','SYSTEM','=')
,('policy-47','SYSTEM','=')
,('policy-48','SYSTEM','=')
,('policy-49','SYSTEM','=');

ALTER TABLE KMT_KMIP_WRAPDATA ADD COLUMN LAST_UPDATE_TIMESTAMP TIMESTAMP;
ALTER TABLE KMT_OBJECT_CLIENT_RN ADD COLUMN LAST_UPDATE_TIMESTAMP TIMESTAMP;
ALTER TABLE KMT_ALIAS_HANDLE ADD COLUMN LAST_UPDATE_TIMESTAMP TIMESTAMP;
ALTER TABLE KMT_SCH_TASK ADD COLUMN LAST_UPDATE_TIMESTAMP TIMESTAMP;

ALTER TABLE KMT_KMIP_WRAPDATA ADD CONSTRAINT PK_WRAPDATA  PRIMARY KEY (MANAGED_OBJECT_UUID);
ALTER TABLE KMT_KEY_GROUP_MEMBERS ADD CONSTRAINT PK_KEYGRPMEM  PRIMARY KEY (GROUP_ID,MEMBER_ID);

ALTER TABLE KMT_CHANGESET_TRACK ADD COLUMN REF_OBJECT_MAP VARBINARY(2048);
 -- commits the changes to DB2		 
CREATE TABLE KMT_APP_ROLE (
    	UUID VARCHAR(64) NOT NULL,
		NAME VARCHAR(256) NOT NULL,
		CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
		LAST_UPDATE_TIMESTAMP  TIMESTAMP NOT NULL 
	)IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

CREATE INDEX APPROLE_NAME_IDX ON KMT_APP_ROLE(NAME);


ALTER TABLE KMT_APP_ROLE  ADD CONSTRAINT APP_ROLE_PK PRIMARY KEY (UUID);

ALTER TABLE KMT_APP_ROLE  ADD CONSTRAINT APP_ROLE_NAME_UN UNIQUE (NAME);


INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000009', 'klmSecurityOfficer', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000010', 'klmBackup', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000011', 'klmConfigure', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000012', 'klmRestore', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000013', 'klmAudit', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000014', 'klmView', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000015', 'klmCreate', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000016', 'klmModify', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000017', 'klmDelete', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000018', 'klmGet', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));	
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000019', 'klmAdminDeviceGroup', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000020', 'LTO', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000021', 'TS3592', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000022', 'DS5000', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000023', 'DS8000', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000024', 'GENERIC', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000025', 'BRCD_ENCRYPTOR', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000026', 'ONESECURE', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000027', 'suppressmonitor', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000028', 'ETERNUS_DX', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000030', 'IBM_SYSTEM_X_SED', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000031', 'XIV', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000032', 'GPFS', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000033', 'PEER_TO_PEER', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000034', 'DS8000_TCT', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000035', 'klmClientUser', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role(uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000036', 'klmFileTransfer', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));

CREATE TABLE KMT_APP_USER_GROUP (
    	UUID VARCHAR(64) NOT NULL,
		NAME VARCHAR(256) NOT NULL,
		DESCRIPTION VARCHAR(512),
		CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
		LAST_UPDATE_TIMESTAMP  TIMESTAMP NOT NULL 
	)
	IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

CREATE INDEX APPUSERGROUP_NAME_IDX ON KMT_APP_ROLE(NAME);


ALTER TABLE KMT_APP_USER_GROUP  ADD CONSTRAINT APP_USER_GROUP_PK PRIMARY KEY (UUID);

ALTER TABLE KMT_APP_USER_GROUP  ADD CONSTRAINT APP_USER_GROUP_NAME_UN UNIQUE (NAME);

INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000001', 'klmGUICLIAccessGroup', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000002', 'klmSecurityOfficerGroup', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000003', 'LTOAdmin', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000004', 'LTOAuditor', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000005', 'LTOOperator', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_user_group(
	uuid, name, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000006', 'klmBackupRestoreGroup', (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));


 CREATE TABLE KMT_APP_USERGROUP_MEMBERS  (
 	UUID VARCHAR(64) NOT NULL,
    USER_ID  VARCHAR(256) NOT NULL,
    GROUP_UUID   VARCHAR(64) NOT NULL,
	CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_APP_USERGROUP_MEMBERS ADD CONSTRAINT PK_APP_USERGROUP_MEMBERS_ID PRIMARY KEY (UUID);
ALTER TABLE KMT_APP_USERGROUP_MEMBERS ADD CONSTRAINT APP_ROLE_MEMBERS_FK1 FOREIGN KEY (GROUP_UUID)
  REFERENCES KMT_APP_USER_GROUP  (UUID) ON DELETE CASCADE;
CREATE INDEX IDX_KMT_APP_USERGROUP_MEMBERS_01 ON KMT_APP_USERGROUP_MEMBERS(USER_ID);
CREATE INDEX IDX_KMT_APP_USERGROUP_MEMBERS_02 ON KMT_APP_USERGROUP_MEMBERS(GROUP_UUID);


INSERT INTO kmt_app_usergroup_members(
	uuid, user_id, group_uuid, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000001', 'sklmadmin', (select uuid from kmt_app_user_group where name='klmGUICLIAccessGroup'), (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO kmt_app_usergroup_members(
	uuid, user_id, group_uuid, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000002', 'sklmadmin', (select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));	
 

 CREATE TABLE KMT_APP_ROLE_MEMBERS (
 	UUID VARCHAR(64) NOT NULL,
    ROLEID VARCHAR(64) NOT NULL,
    MEMBERID  VARCHAR(256) NOT NULL,
    MEMBERTYPE  SMALLINT NOT NULL,
	CREATION_TIMESTAMP  TIMESTAMP NOT NULL,
    LAST_UPDATE_TIMESTAMP TIMESTAMP 
  );

ALTER TABLE KMT_APP_ROLE_MEMBERS ADD CONSTRAINT PK_APP_ROLE_MEMBERS_ID PRIMARY KEY (UUID);
ALTER TABLE KMT_APP_ROLE_MEMBERS ADD CONSTRAINT APP_ROLE_MEMBERS_FK1 FOREIGN KEY (ROLEID)
  REFERENCES KMT_APP_ROLE (UUID) ON DELETE CASCADE;
CREATE INDEX IDX_KMT_APP_ROLE_MEMBERS_01 ON KMT_APP_ROLE_MEMBERS(ROLEID);
CREATE INDEX IDX_KMT_APP_ROLE_MEMBERS_02 ON KMT_APP_ROLE_MEMBERS(MEMBERID);

INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000002',
	(select uuid from kmt_app_role where name='klmSecurityOfficer'),
	(select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));

INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000003',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000004',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='klmBackupRestoreGroup'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000005',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000006',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000007',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='LTOAuditor'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000008',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	(select uuid from kmt_app_user_group where name='klmGUICLIAccessGroup'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000009',
	(select uuid from kmt_app_role where name='klmBackup'),
	(select uuid from kmt_app_user_group where name='klmBackupRestoreGroup'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000010',
	(select uuid from kmt_app_role where name='klmBackup'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000011',
	(select uuid from kmt_app_role where name='klmBackup'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000012',
	(select uuid from kmt_app_role where name='klmRestore'),
	(select uuid from kmt_app_user_group where name='klmBackupRestoreGroup'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000013',
	(select uuid from kmt_app_role where name='LTO'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000014',
	(select uuid from kmt_app_role where name='LTO'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000015',
	(select uuid from kmt_app_role where name='LTO'),
	(select uuid from kmt_app_user_group where name='LTOAuditor'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000016',
	(select uuid from kmt_app_role where name='klmCreate'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000017',
	(select uuid from kmt_app_role where name='klmCreate'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000018',
	(select uuid from kmt_app_role where name='klmView'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000019',
	(select uuid from kmt_app_role where name='klmView'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000020',
	(select uuid from kmt_app_role where name='klmView'),
	(select uuid from kmt_app_user_group where name='LTOAuditor'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000021',
	(select uuid from kmt_app_role where name='klmDelete'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000022',
	(select uuid from kmt_app_role where name='klmModify'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000023',
	(select uuid from kmt_app_role where name='klmModify'),
	(select uuid from kmt_app_user_group where name='LTOOperator'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000024',
	(select uuid from kmt_app_role where name='klmGet'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000025',
	(select uuid from kmt_app_role where name='klmAudit'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000026',
	(select uuid from kmt_app_role where name='klmAudit'),
	(select uuid from kmt_app_user_group where name='LTOAuditor'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000027',
	(select uuid from kmt_app_role where name='klmConfigure'),
	(select uuid from kmt_app_user_group where name='LTOAdmin'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000028',
	(select uuid from kmt_app_role where name='klmConfigure'),
	(select uuid from kmt_app_user_group where name='klmSecurityOfficerGroup'), 0, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
	
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000029',
	(select uuid from kmt_app_role where name='klmSecurityOfficer'),
	'sklmadmin', 1, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_app_role_members(
	uuid, roleid, memberid, membertype, creation_timestamp, last_update_timestamp)
	VALUES ('00000000-0000-0000-0000-000000000030',
	(select uuid from kmt_app_role where name='suppressmonitor'),
	'sklmadmin', 1, (CURRENT TIMESTAMP - CURRENT TIMEZONE), (CURRENT TIMESTAMP - CURRENT TIMEZONE));

CREATE TABLE KMT_VERSIONINFO (
	UUID SMALLINT NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 32767 CYCLE CACHE 20),
    APP_VERSION VARCHAR(64) NOT NULL, 
    WAS_VERSION VARCHAR(64) NOT NULL,
    JAVA_VERSION VARCHAR(64) NOT NULL,
    BUILD_LEVEL VARCHAR(64) NOT NULL,
    IMAGE_LEVEL VARCHAR(64),
    EXT1 VARCHAR(64),
    EXT2 VARCHAR(64),
    LAST_UPDATE_TIMESTAMP TIMESTAMP
  )
  IN TKLM_DATA_LG INDEX IN TKLM_IDX
  DATA CAPTURE NONE ;

ALTER TABLE KMT_VERSIONINFO ADD CONSTRAINT KMT_VERSIONINFO_PK PRIMARY KEY (UUID);

INSERT INTO KMT_VERSIONINFO
(app_version,was_version,java_version,build_level,image_level,last_update_timestamp)
VALUES
('@FIXPAKVERSION@','9.0.5.0','1.8','@DATENAME@','@IMAGELEVEL@',(CURRENT TIMESTAMP - CURRENT TIMEZONE));
 
 
 ------ Following changes are KMIP DB Restructure related changes ----------

  CREATE TABLE KMT_KMIP_SUPPORTED_ATTRS (
	ATTR_NAME	VARCHAR (64) NOT NULL,
	ATTR_TYPE	VARCHAR (16),
	STRUCT_ATTR_NAME	VARCHAR (64) NOT NULL,
	ATTR_ENUM	VARCHAR (64),
	STRUCT_ATTR_ENUM	VARCHAR (64),
	CREATION_DATE	TIMESTAMP,
	CREATED_BY	VARCHAR (64),
	LAST_UPDATE_BY	VARCHAR (64),
	LAST_UPDATE_TIMESTAMP	TIMESTAMP
  );
  ALTER TABLE KMT_KMIP_SUPPORTED_ATTRS ADD CONSTRAINT PK_SUPP_ATTRS PRIMARY KEY (ATTR_NAME, STRUCT_ATTR_NAME);
  
 

CREATE TABLE KMT_KMIP_ATTRS_DATA (
	OBJ_UUID	VARCHAR (64) NOT NULL,
	ATTR_NAME	VARCHAR (64) NOT NULL,
	ATTR_INDEX	INTEGER  NOT NULL,
	STRUCT_ATTR_NAME	VARCHAR (64)  NOT NULL,
	ATTR_ENUM	VARCHAR (64),
	STRUCT_ATTR_ENUM	VARCHAR (64),
	ATTR_VALUE	VARCHAR (4096),
	ATTR_DATA_TYPE VARCHAR(64) ,
	OBJ_TYPE	VARCHAR (16),
	ATTR_TYPE	VARCHAR (16),
	CREATION_DATE	TIMESTAMP,
	CREATED_BY	VARCHAR (64),
	LAST_UPDATE_BY	VARCHAR (64),
	LAST_UPDATE_TIMESTAMP	TIMESTAMP
  );
  
  ALTER TABLE KMT_KMIP_ATTRS_DATA ADD CONSTRAINT PK_OBJ_ATTR_DATA PRIMARY KEY (OBJ_UUID, ATTR_NAME, ATTR_INDEX, STRUCT_ATTR_NAME);
  
  		--1) In case of SingleVal or MultiVal (Non structure) attributes,  ATTR_NAME and STRUCT_ATTR_NAME will hold same value of attribute name.
  		--2) ATTR_TYPE - is SingleValue (SV), MultiValue (MV) , or Structure (ST)
  		--3) ATTR_DATA_TYPE - Text, Integer, Enum, Binary (Use exact datatype mentioned in KMIP specs).
  
  
  
  CREATE VIEW VW_KMIP_ATTRS_DATA
  As
	select 	OBJ_UUID, 
		ATTR_NAME,
		STRUCT_ATTR_NAME,
		ATTR_NAME || '_' || STRUCT_ATTR_NAME as ATTR_COL_NAME,
		OBJ_TYPE,
		ATTR_DATA_TYPE,
		LISTAGG (ATTR_VALUE,',') as VW_ATTR_VAL
	from KMT_KMIP_ATTRS_DATA
	Group by OBJ_UUID, 
		ATTR_NAME,
		STRUCT_ATTR_NAME,
		OBJ_TYPE,
		ATTR_DATA_TYPE;  
	
		--1) Value of "ATTR_COL_NAME" will be used as Column name in crosstab view
		--2) "VW_ATTR_VAL" will be comma separated arrgegated value of multi valued attributes.
		--3) 
	
  
	Create view VW_KMIP_CRYPTO_OBJECTS
	As 
	SELECT 
		UUID as UUID,
		TYPE as TYPE,
		DESCRIPTION  as DESCRIPTION ,
		ALGORITHM as ALGORITHM,
		LENGTH as LENGTH,
		CREATIONDATE as CREATIONDATE,
		EXPIRATIONDATE as EXPIRATIONDATE,
		RETIREDATE as RETIREDATE,
		DESTROYDATE as DESTROYDATE,
		AUTOSTATECHANGE as AUTOSTATECHANGE,
		ACTIVATIONDATE as ACTIVATIONDATE,
		COMPROMISEDATE as COMPROMISEDATE,
		ARCHIVETIME as ARCHIVETIME,
		STATE  as STATE ,
		PREVSTATE as PREVSTATE,
		OWNER as OWNER,
		HASHVALUE as HASHVALUE,
		VERSION as VERSION,
		PENDING as PENDING,
		FORMAT as FORMAT,
		LEASE_TIME as LEASE_TIME,
		CONTACT_INFO as CONTACT_INFO,
		LAST_CHANGED_DATE as LAST_CHANGED_DATE,
		OPERATIONAL_POLICY as OPERATIONAL_POLICY,
		COMPROMISE_OCCURRENCE_DATE as COMPROMISE_OCCURRENCE_DATE,
		PROCESS_START_DATE as PROCESS_START_DATE,
		PROTECT_STOP_DATE as PROTECT_STOP_DATE,
		REVOKE_REASON_CODE as REVOKE_REASON_CODE,
		REVOKE_REASON_MESSAGE as REVOKE_REASON_MESSAGE,
		USAGE_VALUE as USAGE_VALUE,
		USAGE_TOTAL as USAGE_TOTAL,
		USAGE_LIMIT_TYPE as USAGE_LIMIT_TYPE,
		CRYPTO_USAGE as CRYPTO_USAGE,
		X509EXT_SKI as X509EXT_SKI,
		SHA1PUBKEY_SKI as SHA1PUBKEY_SKI,
		ORIGINAL_CREATION_DATE as ORIGINAL_CREATION_DATE,
		NULL as ISSUERNAME,
		NULL as SERIALNUMBER,
		NULL as SUBJECTNAME,
		NULL as TARGETUUID,
		NULL as NOTIFY,
		NULL as TRUSTED,
		NULL as PENDING_TRUST,
		NULL as PENDING_TRUST_DATE,
		NULL as CERTIFICATE_LENGTH,
		NULL as DIGITAL_SIGNATURE_ALGORITHM,
		NULL as CERTIFICATE_TYPE,
		NULL as INITIAL_DATE,
		NULL as ALIAS,
		NULL as KEYSTORE_UUID,
		NULL as DEACTIVATION_DATE,
		NULL as APPNAME,
		NULL as TEMPLNAME,
		NULL as DEVICE_TYPE_ID,
		CREATED_BY as CREATED_BY,
		NULL as OPAQUE_DATA_TYPE,
		NULL as SECRET_DATA_TYPE,
		NULL as TEMPL_TYPE
	FROM KMT_KEY
	UNION
	SELECT  
		UUID as UUID,
		'CERTIFICATE' as TYPE,
		DESCRIPTION as DESCRIPTION ,
		ALGORITHM as ALGORITHM,
		LENGTH as LENGTH,
		CREATIONDATE as CREATIONDATE,
		EXPIRATIONDATE as EXPIRATIONDATE,
		RETIREDATE as RETIREDATE,
		DESTROYDATE as DESTROYDATE,
		AUTOSTATECHANGE as AUTOSTATECHANGE,
		ACTIVATIONDATE as ACTIVATIONDATE,
		COMPROMISEDATE as COMPROMISEDATE,
		ARCHIVETIME as ARCHIVETIME,
		STATE as STATE ,
		PREVSTATE as PREVSTATE,
		OWNER as OWNER,
		HASHVALUE as HASHVALUE,
		VERSION as VERSION,
		NULL as PENDING,
		NULL as FORMAT,
		LEASE_TIME as LEASE_TIME,
		CONTACT_INFO as CONTACT_INFO,
		LAST_CHANGED_DATE as LAST_CHANGED_DATE,
		OPERATIONAL_POLICY as OPERATIONAL_POLICY,
		COMPROMISE_OCCURRENCE_DATE as COMPROMISE_OCCURRENCE_DATE,
		PROCESS_START_DATE as PROCESS_START_DATE,
		PROTECT_STOP_DATE as PROTECT_STOP_DATE,
		REVOKE_REASON_CODE as REVOKE_REASON_CODE,
		REVOKE_REASON_MESSAGE as REVOKE_REASON_MESSAGE,
		USAGE_VALUE as USAGE_VALUE,
		USAGE_TOTAL as USAGE_TOTAL,
		USAGE_LIMIT_TYPE as USAGE_LIMIT_TYPE,
		CRYPTO_USAGE as CRYPTO_USAGE,
		X509EXT_SKI as X509EXT_SKI,
		SHA1PUBKEY_SKI as SHA1PUBKEY_SKI,
		ORIGINAL_CREATION_DATE as ORIGINAL_CREATION_DATE,
		ISSUERNAME as ISSUERNAME,
		SERIALNUMBER as SERIALNUMBER,
		SUBJECTNAME as SUBJECTNAME,
		TARGETUUID as TARGETUUID,
		NOTIFY as NOTIFY,
		TRUSTED as TRUSTED,
		PENDING_TRUST as PENDING_TRUST,
		PENDING_TRUST_DATE as PENDING_TRUST_DATE,
		CERTIFICATE_LENGTH as CERTIFICATE_LENGTH,
		DIGITAL_SIGNATURE_ALGORITHM as DIGITAL_SIGNATURE_ALGORITHM,
		CERTIFICATE_TYPE as CERTIFICATE_TYPE,
		NULL as INITIAL_DATE,
		NULL as ALIAS,
		NULL as KEYSTORE_UUID,
		NULL as DEACTIVATION_DATE,
		NULL as APPNAME,
		NULL as TEMPLNAME,
		NULL as DEVICE_TYPE_ID,
		CREATED_BY as CREATED_BY,
		NULL as OPAQUE_DATA_TYPE,
		NULL as SECRET_DATA_TYPE,
		NULL as TEMPL_TYPE
	FROM  KMT_CERT
	UNION
	SELECT  
		UUID as UUID,
		'OPAQUE' as TYPE,
		NULL as DESCRIPTION ,
		NULL as ALGORITHM,
		NULL as LENGTH,
		NULL as CREATIONDATE,
		NULL as EXPIRATIONDATE,
		NULL as RETIREDATE,
		DESTROYDATE as DESTROYDATE,
		NULL as AUTOSTATECHANGE,
		ACTIVATIONDATE as ACTIVATIONDATE,
		COMPROMISE_DATE as COMPROMISEDATE,
		ARCHIVE_DATE as ARCHIVETIME,
		NULL as STATE ,
		NULL as PREVSTATE,
		OWNER as OWNER,
		NULL as HASHVALUE,
		VERSION as VERSION,
		NULL as PENDING,
		NULL as FORMAT,
		LEASE_TIME as LEASE_TIME,
		CONTACT_INFO as CONTACT_INFO,
		LAST_CHANGED_DATE as LAST_CHANGED_DATE,
		OPERATIONAL_POLICY as OPERATIONAL_POLICY,
		COMPROMISE_OCCURRENCE_DATE as COMPROMISE_OCCURRENCE_DATE,
		NULL as PROCESS_START_DATE,
		NULL as PROTECT_STOP_DATE,
		REVOKE_REASON_CODE as REVOKE_REASON_CODE,
		REVOKE_REASON_MESSAGE as REVOKE_REASON_MESSAGE,
		USAGE_VALUE as USAGE_VALUE,
		USAGE_TOTAL as USAGE_TOTAL,
		USAGE_LIMIT_TYPE as USAGE_LIMIT_TYPE,
		NULL as CRYPTO_USAGE,
		NULL as X509EXT_SKI,
		NULL as SHA1PUBKEY_SKI,
		ORIGINAL_CREATION_DATE as ORIGINAL_CREATION_DATE,
		NULL as ISSUERNAME,
		NULL as SERIALNUMBER,
		NULL as SUBJECTNAME,
		NULL as TARGETUUID,
		NULL as NOTIFY,
		NULL as TRUSTED,
		NULL as PENDING_TRUST,
		NULL as PENDING_TRUST_DATE,
		NULL as CERTIFICATE_LENGTH,
		NULL as DIGITAL_SIGNATURE_ALGORITHM,
		NULL as CERTIFICATE_TYPE,
		INITIAL_DATE as INITIAL_DATE,
		NULL as ALIAS,
		NULL as KEYSTORE_UUID,
		DEACTIVATION_DATE as DEACTIVATION_DATE,
		NULL as APPNAME,
		NULL as TEMPLNAME,
		DEVICE_TYPE_ID as DEVICE_TYPE_ID,
		CREATED_BY as CREATED_BY,
		OPAQUE_DATA_TYPE as OPAQUE_DATA_TYPE,
		NULL as SECRET_DATA_TYPE,
		NULL as TEMPL_TYPE
	FROM  KMT_KMIP_OBJECT_OPAQUE
	UNION
	SELECT  
		UUID as UUID,
		'SECRETDATA' as TYPE,
		NULL as DESCRIPTION ,
		NULL as ALGORITHM,
		CRYPTO_LENGTH as LENGTH,
		NULL as CREATIONDATE,
		NULL as EXPIRATIONDATE,
		NULL as RETIREDATE,
		DESTROYDATE as DESTROYDATE,
		NULL as AUTOSTATECHANGE,
		ACTIVATIONDATE as ACTIVATIONDATE,
		COMPROMISEDATE as COMPROMISEDATE,
		ARCHIVE_DATE as ARCHIVETIME,
		NULL as STATE ,
		PREVSTATE as PREVSTATE,
		OWNER as OWNER,
		NULL as HASHVALUE,
		VERSION as VERSION,
		NULL as PENDING,
		FORMAT as FORMAT,
		LEASE_TIME as LEASE_TIME,
		CONTACT_INFO as CONTACT_INFO,
		LAST_CHANGED_DATE as LAST_CHANGED_DATE,
		OPERATIONAL_POLICY as OPERATIONAL_POLICY,
		COMPROMISE_OCCURRENCE_DATE as COMPROMISE_OCCURRENCE_DATE,
		NULL as PROCESS_START_DATE,
		NULL as PROTECT_STOP_DATE,
		REVOKE_REASON_CODE as REVOKE_REASON_CODE,
		REVOKE_REASON_MESSAGE as REVOKE_REASON_MESSAGE,
		NULL as USAGE_VALUE,
		NULL as USAGE_TOTAL,
		NULL as USAGE_LIMIT_TYPE,
		CRYPTO_USAGE as CRYPTO_USAGE,
		NULL as X509EXT_SKI,
		NULL as SHA1PUBKEY_SKI,
		ORIGINAL_CREATION_DATE as ORIGINAL_CREATION_DATE,
		NULL as ISSUERNAME,
		NULL as SERIALNUMBER,
		NULL as SUBJECTNAME,
		NULL as TARGETUUID,
		NULL as NOTIFY,
		NULL as TRUSTED,
		NULL as PENDING_TRUST,
		NULL as PENDING_TRUST_DATE,
		NULL as CERTIFICATE_LENGTH,
		NULL as DIGITAL_SIGNATURE_ALGORITHM,
		NULL as CERTIFICATE_TYPE,
		INITIAL_DATE as INITIAL_DATE,
		ALIAS as ALIAS,
		KEYSTORE_UUID as KEYSTORE_UUID,
		DEACTIVATION_DATE as DEACTIVATION_DATE,
		NULL as APPNAME,
		NULL as TEMPLNAME,
		DEVICE_TYPE_ID as DEVICE_TYPE_ID,
		CREATED_BY as CREATED_BY,
		NULL as OPAQUE_DATA_TYPE,
		TYPE as SECRET_DATA_TYPE,
		NULL as TEMPL_TYPE
	FROM  KMT_KMIP_OBJECT_SECRET_DATA
	UNION
	SELECT  
		UUID as UUID,
		'TEMPLATE' as TYPE,
		NULL as DESCRIPTION ,
		NULL as ALGORITHM,
		NULL as LENGTH,
		NULL as CREATIONDATE,
		NULL as EXPIRATIONDATE,
		NULL as RETIREDATE,
		NULL as DESTROYDATE,
		NULL as AUTOSTATECHANGE,
		NULL as ACTIVATIONDATE,
		NULL as COMPROMISEDATE,
		NULL as ARCHIVETIME,
		NULL as STATE ,
		NULL as PREVSTATE,
		NULL as OWNER,
		NULL as HASHVALUE,
		VERSION as VERSION,
		NULL as PENDING,
		NULL as FORMAT,
		NULL as LEASE_TIME,
		NULL as CONTACT_INFO,
		LAST_UPDATE_TIMESTAMP as LAST_CHANGED_DATE,
		NULL as OPERATIONAL_POLICY,
		NULL as COMPROMISE_OCCURRENCE_DATE,
		NULL as PROCESS_START_DATE,
		NULL as PROTECT_STOP_DATE,
		NULL as REVOKE_REASON_CODE,
		NULL as REVOKE_REASON_MESSAGE,
		NULL as USAGE_VALUE,
		NULL as USAGE_TOTAL,
		NULL as USAGE_LIMIT_TYPE,
		NULL as CRYPTO_USAGE,
		NULL as X509EXT_SKI,
		NULL as SHA1PUBKEY_SKI,
		NULL as ORIGINAL_CREATION_DATE,
		NULL as ISSUERNAME,
		NULL as SERIALNUMBER,
		NULL as SUBJECTNAME,
		NULL as TARGETUUID,
		NULL as NOTIFY,
		NULL as TRUSTED,
		NULL as PENDING_TRUST,
		NULL as PENDING_TRUST_DATE,
		NULL as CERTIFICATE_LENGTH,
		NULL as DIGITAL_SIGNATURE_ALGORITHM,
		NULL as CERTIFICATE_TYPE,
		NULL as INITIAL_DATE,
		NULL as ALIAS,
		NULL as KEYSTORE_UUID,
		NULL as DEACTIVATION_DATE,
		APPNAME as APPNAME,
		TEMPLNAME as TEMPLNAME,
		NULL as DEVICE_TYPE_ID,
		NULL as CREATED_BY,
		NULL as OPAQUE_DATA_TYPE,
		NULL as SECRET_DATA_TYPE,
		TYPE as TEMPL_TYPE
	FROM  KMT_TEMPL
;
  
		

INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ALTERNATIVE_NAME','ST','ALTERNATIVE_NAME_VALUE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ALTERNATIVE_NAME','ST','ALTERNATIVE_NAME_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ALWAYS_SENSITIVE','SV','ALWAYS_SENSITIVE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('APPLICATION_SPECIFIC_INFORMATION','ST','APPLICATION_NAMESPACE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('APPLICATION_SPECIFIC_INFORMATION','ST','APPLICATION_DATA', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_CN', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_O', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_OU', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_EMAIL', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_C', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_ST', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_L', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_UID', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_SERIAL_NUMBER', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_TITLE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_DC', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_SUBJECT_DN_QUALIFIER', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_CN', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_O', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_OU', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_EMAIL', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_C', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_ST', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_L', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_UID', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_SERIAL_NUMBER', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_TITLE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_DC', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CERTIFICATE_ATTRIBUTES','ST','CERTIFICATE_ISSUER_DN_QUALIFIER', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_DOMAIN_PARAMETERS','ST','QLENGTH', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_DOMAIN_PARAMETERS','ST','RECOMMENDED_CURVE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','BLOCK_CIPHER_MODE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','PADDING_METHOD', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','HASHING_ALGORITHM', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','KEY_ROLE_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','DIGITAL_SIGNATURE_ALGORITHM_', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','CRYPTOGRAPHIC_ALGORITHM', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','RANDOM_IV', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','IV_LENGTH', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','TAG_LENGTH', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','FIXED_FIELD_LENGTH', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','INVOCATION_FIELD_LENGTH', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','COUNTER_LENGTH', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','INITIAL_COUNTER_VALUE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','SALT_LENGTH', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','MASK_GENERATOR', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','MASK_GENERATOR_HASHING_ALGORITHM', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','P_SOURCE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('CRYPTOGRAPHIC_PARAMETERS','ST','TRAILER_FIELD', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('DIGEST','ST','HASHING_ALGORITHM', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('DIGEST','ST','DIGEST_VALUE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('DIGEST','ST','KEY_FORMAT_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('EXTRACTABLE','SV','EXTRACTABLE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('FRESH','SV','FRESH', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('KEY_FORMAT_TYPE','SV','KEY_FORMAT_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('KEY_VALUE_LOCATION','ST','KEY_VALUE_LOCATION_VALUE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('KEY_VALUE_LOCATION','ST','KEY_VALUE_LOCATION_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('KEY_VALUE_PRESENT','SV','KEY_VALUE_PRESENT', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('LINK','ST','LINK_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('LINK','ST','LINKED_OBJECT_IDENTIFIER', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('NAME','ST','NAME_VALUE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('NAME','ST','NAME_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('NEVER_EXTRACTABLE','SV','NEVER_EXTRACTABLE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('NIST_KEY_TYPE','MV','NIST_KEY_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('OBJECT_GROUP','MV','OBJECT_GROUP', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('PKCS_12_FRIENDLY_NAME','SV','PKCS_12_FRIENDLY_NAME', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('PROTECTION_LEVEL','SV','PROTECTION_LEVEL', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('PROTECTION_PERIOD','SV','PROTECTION_PERIOD', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('PROTECTION_STORAGE_MASK','SV','PROTECTION_STORAGE_MASK', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('QUANTUM_SAFE','SV','QUANTUM_SAFE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('RANDOM_NUMBER_GENERATOR','SV','RANDOM_NUMBER_GENERATOR', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_DATE','SV','ROTATE_DATE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_GENERATION','SV','ROTATE_GENERATION', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_INTERVAL','SV','ROTATE_INTERVAL', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_LATEST','SV','ROTATE_LATEST', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_NAME','ST','ROTATE_NAME_VALUE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_NAME','ST','ROTATE_NAME_TYPE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('ROTATE_OFFSET','SV','ROTATE_OFFSET', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('SENSITIVE','SV','SENSITIVE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('SHORT_UNIQUE_IDENTIFIER','SV','SHORT_UNIQUE_IDENTIFIER', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('UNIQUE_IDENTIFIER','SV','UNIQUE_IDENTIFIER', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('USAGE_LIMITS','ST','USAGE_LIMITS_TOTAL', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('USAGE_LIMITS','ST','USAGE_LIMITS_COUNT', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('USAGE_LIMITS','ST','USAGE_LIMITS_UNIT', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('VENDOR_ATTRIBUTE','ST','VENDOR_IDENTIFICATION', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('VENDOR_ATTRIBUTE','ST','ATTRIBUTE_NAME', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('VENDOR_ATTRIBUTE','ST','ATTRIBUTE_VALUE', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_IDENTIFIER','ST','ISSUER_DISTINGUISHED_NAME', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_IDENTIFIER','ST','CERTIFICATE_SERIAL_NUMBER', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_ISSUER','ST','ISSUER_DISTINGUISHED_NAME', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_ISSUER','ST','ISSUER_ALTERNATIVE_NAME', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_SUBJECT','ST','SUBJECT_DISTINGUISHED_NAME', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));
INSERT INTO kmt_kmip_supported_attrs( attr_name, attr_type, struct_attr_name, attr_enum, struct_attr_enum, creation_date, created_by, last_update_by, last_update_timestamp ) VALUES ('X_509_CERTIFICATE_SUBJECT','ST','SUBJECT_ALTERNATIVE_NAME', null, null, (CURRENT TIMESTAMP - CURRENT TIMEZONE) ,'User1', 'User2', (CURRENT TIMESTAMP - CURRENT TIMEZONE));


CREATE view VW_KMIP_OBJ_WITH_ADDITIONAL_ATTRS 
as 
	select  OBJ_UUID, 
		max(decode(ATTR_COL_NAME, 'ALTERNATIVE_NAME_ALTERNATIVE_NAME_VALUE', VW_ATTR_VAL)) as ALTERNATIVE_NAME_ALTERNATIVE_NAME_VALUE,
		max(decode(ATTR_COL_NAME, 'ALTERNATIVE_NAME_ALTERNATIVE_NAME_TYPE', VW_ATTR_VAL)) as ALTERNATIVE_NAME_ALTERNATIVE_NAME_TYPE,
		max(decode(ATTR_COL_NAME, 'ALWAYS_SENSITIVE_ALWAYS_SENSITIVE', VW_ATTR_VAL)) as ALWAYS_SENSITIVE_ALWAYS_SENSITIVE,
		max(decode(ATTR_COL_NAME, 'APPLICATION_SPECIFIC_INFORMATION_APPLICATION_NAMESPACE', VW_ATTR_VAL)) as APPLICATION_SPECIFIC_INFORMATION_APPLICATION_NAMESPACE,
		max(decode(ATTR_COL_NAME, 'APPLICATION_SPECIFIC_INFORMATION_APPLICATION_DATA', VW_ATTR_VAL)) as APPLICATION_SPECIFIC_INFORMATION_APPLICATION_DATA,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_CN', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_CN,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_O', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_O,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_OU', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_OU,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_EMAIL', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_EMAIL,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_C', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_C,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_ST', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_ST,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_L', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_L,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_UID', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_UID,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_SERIAL_NUMBER', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_SERIAL_NUMBER,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_TITLE', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_TITLE,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_DC', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_DC,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_DN_QUALIFIER', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_SUBJECT_DN_QUALIFIER,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_CN', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_CN,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_O', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_O,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_OU', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_OU,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_EMAIL', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_EMAIL,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_C', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_C,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_ST', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_ST,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_L', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_L,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_UID', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_UID,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_SERIAL_NUMBER', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_SERIAL_NUMBER,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_TITLE', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_TITLE,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_DC', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_DC,
		max(decode(ATTR_COL_NAME, 'CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_DN_QUALIFIER', VW_ATTR_VAL)) as CERTIFICATE_ATTRIBUTES_CERTIFICATE_ISSUER_DN_QUALIFIER,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_DOMAIN_PARAMETERS_QLENGTH', VW_ATTR_VAL)) as CRYPTOGRAPHIC_DOMAIN_PARAMETERS_QLENGTH,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_DOMAIN_PARAMETERS_RECOMMENDED_CURVE', VW_ATTR_VAL)) as CRYPTOGRAPHIC_DOMAIN_PARAMETERS_RECOMMENDED_CURVE,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_BLOCK_CIPHER_MODE', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_BLOCK_CIPHER_MODE,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_PADDING_METHOD', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_PADDING_METHOD,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_HASHING_ALGORITHM', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_HASHING_ALGORITHM,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_KEY_ROLE_TYPE', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_KEY_ROLE_TYPE,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_DIGITAL_SIGNATURE_ALGORITHM_', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_DIGITAL_SIGNATURE_ALGORITHM_,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_CRYPTOGRAPHIC_ALGORITHM', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_CRYPTOGRAPHIC_ALGORITHM,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_RANDOM_IV', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_RANDOM_IV,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_IV_LENGTH', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_IV_LENGTH,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_TAG_LENGTH', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_TAG_LENGTH,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_FIXED_FIELD_LENGTH', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_FIXED_FIELD_LENGTH,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_INVOCATION_FIELD_LENGTH', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_INVOCATION_FIELD_LENGTH,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_COUNTER_LENGTH', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_COUNTER_LENGTH,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_INITIAL_COUNTER_VALUE', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_INITIAL_COUNTER_VALUE,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_SALT_LENGTH', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_SALT_LENGTH,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_MASK_GENERATOR', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_MASK_GENERATOR,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_MASK_GENERATOR_HASHING_ALGORITHM', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_MASK_GENERATOR_HASHING_ALGORITHM,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_P_SOURCE', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_P_SOURCE,
		max(decode(ATTR_COL_NAME, 'CRYPTOGRAPHIC_PARAMETERS_TRAILER_FIELD', VW_ATTR_VAL)) as CRYPTOGRAPHIC_PARAMETERS_TRAILER_FIELD,
		max(decode(ATTR_COL_NAME, 'DIGEST_HASHING_ALGORITHM', VW_ATTR_VAL)) as DIGEST_HASHING_ALGORITHM,
		max(decode(ATTR_COL_NAME, 'DIGEST_DIGEST_VALUE', VW_ATTR_VAL)) as DIGEST_DIGEST_VALUE,
		max(decode(ATTR_COL_NAME, 'DIGEST_KEY_FORMAT_TYPE', VW_ATTR_VAL)) as DIGEST_KEY_FORMAT_TYPE,
		max(decode(ATTR_COL_NAME, 'EXTRACTABLE_EXTRACTABLE', VW_ATTR_VAL)) as EXTRACTABLE_EXTRACTABLE,
		max(decode(ATTR_COL_NAME, 'FRESH_FRESH', VW_ATTR_VAL)) as FRESH_FRESH,
		max(decode(ATTR_COL_NAME, 'KEY_FORMAT_TYPE_KEY_FORMAT_TYPE', VW_ATTR_VAL)) as KEY_FORMAT_TYPE_KEY_FORMAT_TYPE,
		max(decode(ATTR_COL_NAME, 'KEY_VALUE_LOCATION_KEY_VALUE_LOCATION_VALUE', VW_ATTR_VAL)) as KEY_VALUE_LOCATION_KEY_VALUE_LOCATION_VALUE,
		max(decode(ATTR_COL_NAME, 'KEY_VALUE_LOCATION_KEY_VALUE_LOCATION_TYPE', VW_ATTR_VAL)) as KEY_VALUE_LOCATION_KEY_VALUE_LOCATION_TYPE,
		max(decode(ATTR_COL_NAME, 'KEY_VALUE_PRESENT_KEY_VALUE_PRESENT', VW_ATTR_VAL)) as KEY_VALUE_PRESENT_KEY_VALUE_PRESENT,
		max(decode(ATTR_COL_NAME, 'LINK_LINK_TYPE', VW_ATTR_VAL)) as LINK_LINK_TYPE,
		max(decode(ATTR_COL_NAME, 'LINK_LINKED_OBJECT_IDENTIFIER', VW_ATTR_VAL)) as LINK_LINKED_OBJECT_IDENTIFIER,
		max(decode(ATTR_COL_NAME, 'NAME_NAME_VALUE', VW_ATTR_VAL)) as NAME_NAME_VALUE,
		max(decode(ATTR_COL_NAME, 'NAME_NAME_TYPE', VW_ATTR_VAL)) as NAME_NAME_TYPE,
		max(decode(ATTR_COL_NAME, 'NEVER_EXTRACTABLE_NEVER_EXTRACTABLE', VW_ATTR_VAL)) as NEVER_EXTRACTABLE_NEVER_EXTRACTABLE,
		max(decode(ATTR_COL_NAME, 'NIST_KEY_TYPE_NIST_KEY_TYPE', VW_ATTR_VAL)) as NIST_KEY_TYPE_NIST_KEY_TYPE,
		max(decode(ATTR_COL_NAME, 'OBJECT_GROUP_OBJECT_GROUP', VW_ATTR_VAL)) as OBJECT_GROUP_OBJECT_GROUP,
		max(decode(ATTR_COL_NAME, 'PKCS_12_FRIENDLY_NAME_PKCS_12_FRIENDLY_NAME', VW_ATTR_VAL)) as PKCS_12_FRIENDLY_NAME_PKCS_12_FRIENDLY_NAME,
		max(decode(ATTR_COL_NAME, 'PROTECTION_LEVEL_PROTECTION_LEVEL', VW_ATTR_VAL)) as PROTECTION_LEVEL_PROTECTION_LEVEL,
		max(decode(ATTR_COL_NAME, 'PROTECTION_PERIOD_PROTECTION_PERIOD', VW_ATTR_VAL)) as PROTECTION_PERIOD_PROTECTION_PERIOD,
		max(decode(ATTR_COL_NAME, 'PROTECTION_STORAGE_MASK_PROTECTION_STORAGE_MASK', VW_ATTR_VAL)) as PROTECTION_STORAGE_MASK_PROTECTION_STORAGE_MASK,
		max(decode(ATTR_COL_NAME, 'QUANTUM_SAFE_QUANTUM_SAFE', VW_ATTR_VAL)) as QUANTUM_SAFE_QUANTUM_SAFE,
		max(decode(ATTR_COL_NAME, 'RANDOM_NUMBER_GENERATOR_RANDOM_NUMBER_GENERATOR', VW_ATTR_VAL)) as RANDOM_NUMBER_GENERATOR_RANDOM_NUMBER_GENERATOR,
		max(decode(ATTR_COL_NAME, 'ROTATE_DATE_ROTATE_DATE', VW_ATTR_VAL)) as ROTATE_DATE_ROTATE_DATE,
		max(decode(ATTR_COL_NAME, 'ROTATE_GENERATION_ROTATE_GENERATION', VW_ATTR_VAL)) as ROTATE_GENERATION_ROTATE_GENERATION,
		max(decode(ATTR_COL_NAME, 'ROTATE_INTERVAL_ROTATE_INTERVAL', VW_ATTR_VAL)) as ROTATE_INTERVAL_ROTATE_INTERVAL,
		max(decode(ATTR_COL_NAME, 'ROTATE_LATEST_ROTATE_LATEST', VW_ATTR_VAL)) as ROTATE_LATEST_ROTATE_LATEST,
		max(decode(ATTR_COL_NAME, 'ROTATE_NAME_ROTATE_NAME_VALUE', VW_ATTR_VAL)) as ROTATE_NAME_ROTATE_NAME_VALUE,
		max(decode(ATTR_COL_NAME, 'ROTATE_NAME_ROTATE_NAME_TYPE', VW_ATTR_VAL)) as ROTATE_NAME_ROTATE_NAME_TYPE,
		max(decode(ATTR_COL_NAME, 'ROTATE_OFFSET_ROTATE_OFFSET', VW_ATTR_VAL)) as ROTATE_OFFSET_ROTATE_OFFSET,
		max(decode(ATTR_COL_NAME, 'SENSITIVE_SENSITIVE', VW_ATTR_VAL)) as SENSITIVE_SENSITIVE,
		max(decode(ATTR_COL_NAME, 'SHORT_UNIQUE_IDENTIFIER_SHORT_UNIQUE_IDENTIFIER', VW_ATTR_VAL)) as SHORT_UNIQUE_IDENTIFIER_SHORT_UNIQUE_IDENTIFIER,
		max(decode(ATTR_COL_NAME, 'UNIQUE_IDENTIFIER_UNIQUE_IDENTIFIER', VW_ATTR_VAL)) as UNIQUE_IDENTIFIER_UNIQUE_IDENTIFIER,
		max(decode(ATTR_COL_NAME, 'USAGE_LIMITS_USAGE_LIMITS_TOTAL', VW_ATTR_VAL)) as USAGE_LIMITS_USAGE_LIMITS_TOTAL,
		max(decode(ATTR_COL_NAME, 'USAGE_LIMITS_USAGE_LIMITS_COUNT', VW_ATTR_VAL)) as USAGE_LIMITS_USAGE_LIMITS_COUNT,
		max(decode(ATTR_COL_NAME, 'USAGE_LIMITS_USAGE_LIMITS_UNIT', VW_ATTR_VAL)) as USAGE_LIMITS_USAGE_LIMITS_UNIT,
		max(decode(ATTR_COL_NAME, 'VENDOR_ATTRIBUTE_VENDOR_IDENTIFICATION', VW_ATTR_VAL)) as VENDOR_ATTRIBUTE_VENDOR_IDENTIFICATION,
		max(decode(ATTR_COL_NAME, 'VENDOR_ATTRIBUTE_ATTRIBUTE_NAME', VW_ATTR_VAL)) as VENDOR_ATTRIBUTE_ATTRIBUTE_NAME,
		max(decode(ATTR_COL_NAME, 'VENDOR_ATTRIBUTE_ATTRIBUTE_VALUE', VW_ATTR_VAL)) as VENDOR_ATTRIBUTE_ATTRIBUTE_VALUE,
		max(decode(ATTR_COL_NAME, 'X_509_CERTIFICATE_IDENTIFIER_ISSUER_DISTINGUISHED_NAME', VW_ATTR_VAL)) as X_509_CERTIFICATE_IDENTIFIER_ISSUER_DISTINGUISHED_NAME,
		max(decode(ATTR_COL_NAME, 'X_509_CERTIFICATE_IDENTIFIER_CERTIFICATE_SERIAL_NUMBER', VW_ATTR_VAL)) as X_509_CERTIFICATE_IDENTIFIER_CERTIFICATE_SERIAL_NUMBER,
		max(decode(ATTR_COL_NAME, 'X_509_CERTIFICATE_ISSUER_ISSUER_DISTINGUISHED_NAME', VW_ATTR_VAL)) as X_509_CERTIFICATE_ISSUER_ISSUER_DISTINGUISHED_NAME,
		max(decode(ATTR_COL_NAME, 'X_509_CERTIFICATE_ISSUER_ISSUER_ALTERNATIVE_NAME', VW_ATTR_VAL)) as X_509_CERTIFICATE_ISSUER_ISSUER_ALTERNATIVE_NAME,
		max(decode(ATTR_COL_NAME, 'X_509_CERTIFICATE_SUBJECT_SUBJECT_DISTINGUISHED_NAME', VW_ATTR_VAL)) as X_509_CERTIFICATE_SUBJECT_SUBJECT_DISTINGUISHED_NAME,
		max(decode(ATTR_COL_NAME, 'X_509_CERTIFICATE_SUBJECT_SUBJECT_ALTERNATIVE_NAME', VW_ATTR_VAL)) as X_509_CERTIFICATE_SUBJECT_SUBJECT_ALTERNATIVE_NAME
	from VW_KMIP_ATTRS_DATA group by OBJ_UUID;
	
		--1) All "." in attribute names will be replaced as "_".
		--2) All "<space>" in attribute names will be replaced as "_".
		--3) All "#" in attribute names will be replaced as "_".
	
	
CREATE VIEW VW_KMIP_CRYPTO_OBJ_WITH_ALL_ATTRS
As
	Select a.* , b.* 
	from VW_KMIP_CRYPTO_OBJECTS a LEFT OUTER JOIN VW_KMIP_OBJ_WITH_ADDITIONAL_ATTRS b 
	ON a.UUID = b.OBJ_UUID;		

	 
 ------ END - KMIP DB Restructure related changes ----------	
 
 -- commits the changes to DB2		 

commit;