#!/bin/sh
#*************** Begin Standard Header - Do not add comments here ***************
#
#
#File Name: sklmLDAPConfigure.sh
#
#
#Licensed Materials - Property of IBM
#
#(C) Copyright IBM Corp. 2016  All Rights Reserved
#
#US Government Users Restricted Rights - Use, duplication, or
#disclosure restricted by GSA ADP Schedule Contract with IBM Corp. 
#
#**************************** End Standard Header *******************************

printusage() {
echo "*************************************************************
Usage:
     ./sklmLDAPConfigure.sh WAS_HOME SKLM_INSTALL_HOME WAS_ADMIN WAS_PASS SKLM_ADMIN SKLM_ADMIN_PASS DB_INSTALL_DIR
where,
WAS_HOME is the directory where WebSphere Application Server(WAS) for SKLM is installed.
SKLM_INSTALL_HOME is the directory where SKLM is installed.
WAS_ADMIN is Username of WebSphere Application Server(WAS) for SKLM.
WAS_PASS is WAS_PASS of WebSphere Application Server(WAS) for SKLM.
SKLM_ADMIN is the Administrator of SKLM.
SKLM_ADMIN_PASS is the password for SKLM Administrator.
DB_INSTALL_DIR is the directory where DB2 for SKLM is installed.


Example : ./sklmLDAPConfigure.sh /opt/IBM/WebSphere/AppServer /opt/IBM/SKLMV41 wasadmin password sklmadmin password /opt/IBM/DB2SKLMV41

Note: -On Linux systems, slmLDAPConfigure.sh must have executable permission.
*************************************************************"
exit 1
}

if [ $# -ne 7 ]; then
        printusage
else
   export WAS_HOME="$1"
   export SKLM_HOME="$2"	
   export WAS_USER="$3"
   export WAS_PASS="$4"
   export SKLM_ADMIN="$5"
   export SKLM_ADMIN_PASS="$6"	
   export DB_HOME="$7"
fi

mylog=sklmldapconf.log

if [ "$WAS_HOME" = "" ]; then
   printusage
fi
if [ "$WAS_USER" =  "" ]; then
   printusage
fi
if [ "$WAS_PASS" =  "" ]; then
   printusage
fi

if [ "$SKLM_ADMIN_PASS" =  "" ]; then
   printusage
fi

if [ ! -d $WAS_HOME ]; then
echo  "Check if $WAS_HOME exists!"
exit 1
fi

if [ ! -f  $WAS_HOME/bin/stopServer.sh ]; then
echo "Check if the input provided $WAS_HOME is a valid WAS_HOME directory."
exit 1
fi

if [ ! -d $SKLM_HOME ]; then
echo "Check if $SKLM_HOME exists!"
exit 1
fi

if [ -f  sklmldapconf.log ]; then
rm -rf sklmldapconf.log
fi

if [ -f  ldaplog.out ]; then
rm -rf ldaplog.out
fi

########## BACKUP WAS SKLM PROFILE (KLMProfile) ###########

echo "Stopping WAS"
date > $mylog 2>&1
cp -f $DB_HOME/java/db2jcc4.jar $WAS_HOME/lib/
cp -f $DB_HOME/java/db2jcc_license_cu.jar $WAS_HOME/lib/

chmod 777 $WAS_HOME/lib/db2jcc4.jar
chmod 777 $WAS_HOME/lib/db2jcc_license_cu.jar

cp -f $SKLM_HOME/bin/LDAPIntegration/config.py $WAS_HOME/bin 

echo "Stopping WAS" >> $mylog 2>&1
$WAS_HOME/profiles/KLMProfile/bin/stopServer.sh server1 -username $WAS_USER -password $WAS_PASS >> $mylog 2>&1

echo "Backup KLMProfile.."
echo "Backup KLMProfile.." >> $mylog 2>&1

if [ -f  $WAS_HOME/products/sklm/data/WASProfile_Backup ]; then
	rm -rf $WAS_HOME/products/sklm/data/WASProfile_Backup
fi
$WAS_HOME/bin/manageprofiles.sh -backupProfile -profileName KLMProfile -backupFile $WAS_HOME/products/sklm/data/WASProfile_Backup >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "ProfileBackup = PASS" > ldaplog.out
else
	echo "Aborting...Backup Profile failed."
	echo "ProfileBackup = FAIL" > ldaplog.out
	exit 1
fi
############################################################

echo "Starting WAS"
echo "Starting WAS" >> $mylog 2>&1
$WAS_HOME/profiles/KLMProfile/bin/startServer.sh server1 >> $mylog 2>&1

###### TAKE SKLM DATA BACKUP ##############

echo "SKLM Backup started"
echo "SKLM Backup started" >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $SKLM_ADMIN -password $SKLM_ADMIN_PASS -lang jython -f "$SKLM_HOME/bin/LDAPIntegration/takeBackup.py" "$WAS_HOME/products/sklm/data" >> $mylog 2>&1

count=$(grep 'Backup operation fails' $mylog | wc -l)

if [ $count -gt 0 ]
then
        echo "Aborting...SKLM backup failed."
        echo "SKLMBackup = FAIL" >> ldaplog.out
        exit 1
else
        echo "SKLMBackup = PASS" >> ldaplog.out
fi

echo "SKLM Backup Finished"

###### Configure LDAP Server ###############

echo "LDAP Configuration Started.."
echo "LDAP Configuration Started.." >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/configureLDAPServer.py >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "SKLMConfLDAP = PASS" >> ldaplog.out
else
	echo "Aborting...SKLM LDAP server configuration failed."
	echo "SKLMConfLDAP = FAIL" >> ldaplog.out
	exit 1
fi

echo "LDAP Configuration Ends.."
####################################


##### RESTART WAS #######

echo "Restarting WAS..."
echo "Restarting WAS..." >> $mylog 2>&1
$WAS_HOME/profiles/KLMProfile/bin/stopServer.sh server1 -username $WAS_USER -password $WAS_PASS >> $mylog 2>&1
$WAS_HOME/profiles/KLMProfile/bin/startServer.sh server1 >> $mylog 2>&1
#############################

####### REMOVE GROUPS FROM FILE BASED REPOSITORY ###########

echo "Removing Groups from File Based Repository.."
echo "Removing Groups from File Based Repository.." >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS  -lang jython -f $SKLM_HOME/bin/LDAPIntegration/removeGroupsFromDefRepos.py >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "RemGrpFileRep = PASS" >> ldaplog.out
else
	echo "Aborting...Removing groups from file based repository failed."
        echo "RemGrpFileRep = FAIL" >> ldaplog.out
        exit 1
fi

echo "Groups removed from file based repository.."
#############################################################


############# Modify Security Role to User/group mapping to remove the administrator role mapping to klmGUICLIAccessGroup #####################

echo "Modify Security Role to User/group mapping to remove the administrator role mapping to klmGUICLIAccessGroup.."
echo "Modify Security Role to User/group mapping to remove the administrator role mapping to klmGUICLIAccessGroup.." >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/removeSecurityRoleMapping.py >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "RemAdminRoleMapping = PASS"  >> ldaplog.out
else
	echo "Aborting...Modify Security Role to User/group mapping to remove the administrator role mapping to klmGUICLIAccessGroup failed."
        echo "RemAdminRoleMapping = FAIL" >> ldaplog.out
        exit 1
fi

###############################################################################################################################################

######### RESTART WAS #################

echo "Restarting WAS..."
echo "Restarting WAS..." >> $mylog 2>&1
$WAS_HOME/profiles/KLMProfile/bin/stopServer.sh server1 -username $WAS_USER -password $WAS_PASS >> $mylog 2>&1
$WAS_HOME/profiles/KLMProfile/bin/startServer.sh server1 >> $mylog 2>&1
#######################################

############# Add the SKLM Application groups to database based repository ###############

echo "Add the SKLM Application groups to database based repository.."
echo "Add the SKLM Application groups to database based repository.." >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/addGroupsToDBRepos.py >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "AddGrpDBRepos = PASS"  >> ldaplog.out
else
	echo "Aborting...Add SKLM Application groups to DB repository failed."
        echo "AddGrpDBRepos = FAIL" >> ldaplog.out
        exit 1
fi

##########################################################################################

########### update the WAS federated repository with LDAP repository ###################

echo "update the WAS federated repository with LDAP repository.."
echo "update the WAS federated repository with LDAP repository" >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/updateLDAPReposConfig.py myldap >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "UpdLDAPReposConf = PASS"  >> ldaplog.out
else
	echo "Aborting...updating WAS repository with LDAP respository failed."
        echo "UpdLDAPReposConf = FAIL" >> ldaplog.out
        exit 1
fi

########################################################################################

#########  Add Security Role to User/group mapping and map administrator role to klmGUICLIAccessGroup ##########

echo "Add Security Role to User/group mapping and map administrator role to klmGUICLIAccessGroup .."
echo "Add Security Role to User/group mapping and map administrator role to klmGUICLIAccessGroup .." >> $mylog 2>&1
$WAS_HOME/bin/wsadmin.sh -username $WAS_USER -password $WAS_PASS -lang jython -f $SKLM_HOME/bin/LDAPIntegration/assignSecurityRoleMapping.py >> $mylog 2>&1

if [ $? -eq 0 ]
then
        echo "AssSecRoleMapping = PASS"  >> ldaplog.out
else
	echo "Aborting...Add Security Role to User/group mapping and map administrator role to klmGUICLIAccessGroup failed."
        echo "AssSecRoleMapping = FAIL" >> ldaplog.out
        exit 1
fi

################################################################################################################

############ RESTART WAS ############

echo "Restarting WAS..."
echo "Restarting WAS..." >> $mylog 2>&1
$WAS_HOME/profiles/KLMProfile/bin/stopServer.sh server1 -username $WAS_USER -password $WAS_PASS >> $mylog 2>&1
$WAS_HOME/profiles/KLMProfile/bin/startServer.sh server1  >> $mylog 2>&1
####################################

################################################################### END ###################################################################
