#!/bin/sh
SCRIPTDIR=`dirname $0`
CURDIR=`pwd`
USRID=`id -u`
GID=`id -g`
cd $SCRIPTDIR

#echo $USRID


WAS_HOME=$1
WAS_USER=$2
WAS_PASSWORD=$3
DB_NAME=$4
DB_USERNAME=$5
DB_PASSWORD=$6
DB_PORT=$7
SKLM_HOME=$8
SKLM_PASSWORD=$9

printUsage() {
	echo "Usage: addDBUserRepo.sh [WAS_HOME] [WAS_USER] [WAS_PASSWORD] [DB_NAME] [DB_USERNAME] [DB_PASSWORD] [DB_PORT] [SKLM_HOME] [SKLM_PASSWORD]"
	echo Example : addDBUserRepo.sh "/opt/IBM/WebSphere/AppServer" wasadmin  WAS@admin123 USERDB41 sklmdb41 SKLM@db2 50060 "/opt/IBM/SKLMV41" SKLM@admin123
	echo  WAS_HOME = /opt/IBM/WebSphere/AppServer
	echo  WAS_USER = wasadmin
	echo  WAS_PASSWORD = WAS@admin123
	echo  DB_NAME = USERDB40
	echo  DB_USERNAME = sklmdb41
	echo  DB_PASSWORD = SKLM@db2
	echo  DB_PORT = 50060
	echo  SKLM_HOME =/opt/IBM/SKLMV41
	echo SKLM_PASSWORD = SKLM@admin123
}

if [ "$#" -lt "8" ]; then
	echo Invalid number of arguments.
	printUsage
	exit 1
fi

if [ "${WAS_HOME}" == "" ]; then
	echo WAS_HOME value is invalid.
	printUsage
	exit 1
fi

if [ "${WAS_USER}" == "" ]; then
	echo WAS_USER value is invalid.
	printUsage
	exit 1
fi

if [ "${WAS_PASSWORD}" == "" ]; then
	echo WAS_PASSWORD value is invalid.
	printUsage
	exit 1
fi

if [ "${DB_NAME}" == "" ]; then
	echo DB_NAME value is invalid.
	printUsage
	exit 1
fi

if [ "${DB_USERNAME}" == "" ]; then
	echo DB_USERNAME value is invalid.
	printUsage
	exit 1
fi

if [ "${DB_PASSWORD}" == "" ]; then
	echo DB_PASSWORD value is invalid.
	printUsage
	exit 1
fi

if [ "${DB_PORT}" == "" ]; then
	echo DB_PORT value is invalid.
	printUsage
	exit 1
fi

if [ "${SKLM_HOME}" == "" ]; then
	echo SKLM_HOME value is invalid.
	printUsage
	exit 1
fi

if [ "${SKLM_PASSWORD}" == "" ]; then
	echo SKLM_PASSWORD value is invalid.
	printUsage
	exit 1
fi


#--MAIN--

echo Update realm settings
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.updateIdMgrRealm('[-name defaultWIMFileBasedRealm -allowOperationIfReposDown true]')"

echo Removing groups from file repository.
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -f "${SKLM_HOME}/bin/LDAPIntegration/removeGroupsFromDefRepos.py"

echo Configuring system for DB repo
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -f "${SKLM_HOME}/bin/LDAPIntegration/addDBUserRepo.py"  ${WAS_HOME}  ${DB_NAME} ${DB_USERNAME} ${DB_PASSWORD} ${DB_PORT}

echo Stopping server
${WAS_HOME}/bin/stopServer.sh server1 -username ${WAS_USER} -password ${WAS_PASSWORD}

echo Starting server
${WAS_HOME}/bin/startServer.sh server1

${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminApp.edit ('sklm_kms', '[ -MapRolesToUsers [[ administrator AppDeploymentOption.No AppDeploymentOption.No \"\" \"\" AppDeploymentOption.No \"\" \"\" ]]]' )"

${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython  -c "AdminConfig.save()"

#echo Adding groups to database repository.
#rem ${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -f "${SKLM_HOME}/bin/LDAPIntegration/addGroupsToDBRepos.py"

echo updating default settings
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.updateIdMgrSupportedEntityType('[-name PersonAccount -defaultParent \"o=sklmrepdb.ibm\" -rdnProperties uid]')"
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.updateIdMgrSupportedEntityType('[-name Group -defaultParent \"o=sklmrepdb.ibm\" -rdnProperties cn]')"

echo Saving settings..
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminConfig.save()"


echo Remove SKLMAdmin user from realm admin role
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.removeUsersFromAdminRole('[-userids [SKLMAdmin ] -roleName klmSecurityOfficer]')"
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.removeUsersFromAdminRole('[-userids [SKLMAdmin ] -roleName suppressmonitor]')"

echo Remove SKLMAdmin user from users repo - File repo
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.deleteUser ('[ -uniqueName \"uid=SKLMAdmin,o=defaultWIMFileBasedRealm\" ]')"

#echo Add SKLMAdmin user 
#${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c  "AdminTask.createUser ('[-uid SKLMAdmin -password SKLM@admin123 -confirmPassword SKLM@admin123 -cn key_lifecycle_manager_default_admin -sn key_lifecycle_manager_default_admin -parent \"o=sklmrepdb.ibm\"]')"

echo change SKLMAdmin users password
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c  "AdminTask.updateUser ('[ -uniqueName uid=SKLMAdmin,o=sklmrepdb.ibm -password ${SKLM_PASSWORD} -confirmPassword ${SKLM_PASSWORD} ]')"

#echo Adding user to group
#${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.addMemberToGroup ('[ -memberUniqueName \"uid=SKLMAdmin,o=sklmrepdb.ibm\"  -groupUniqueName  \"cn=klmSecurityOfficerGroup,o=sklmrepdb.ibm\"]')"
#${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.addMemberToGroup ('[ -memberUniqueName \"uid=SKLMAdmin,o=sklmrepdb.ibm\"  -groupUniqueName  \"cn=klmGUICLIAccessGroup,o=sklmrepdb.ibm\"]')"

echo Map SKLMAdmin user with admin role
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.mapUsersToAdminRole ('[-accessids [user:defaultWIMFileBasedRealm/uid=SKLMAdmin,o=sklmrepdb.ibm ] -userids [SKLMAdmin ] -roleName klmSecurityOfficer]')"
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminTask.mapUsersToAdminRole ('[-accessids [user:defaultWIMFileBasedRealm/uid=SKLMAdmin,o=sklmrepdb.ibm ] -userids [SKLMAdmin ] -roleName suppressmonitor]')"

echo Updating application settings
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminApp.edit('sklm_kms', '[ -MapRolesToUsers [[ administrator AppDeploymentOption.No AppDeploymentOption.No \"\" klmGUICLIAccessGroup AppDeploymentOption.No \"\" group:defaultWIMFileBasedRealm/cn=klmGUICLIAccessGroup,o=sklmrepdb.ibm ]]]' )" 

echo Saving settings..
${WAS_HOME}/bin/wsadmin.sh -username ${WAS_USER} -password ${WAS_PASSWORD} -lang jython -c "AdminConfig.save()"

echo Stopping server
${WAS_HOME}/bin/stopServer.sh server1 -username ${WAS_USER} -password ${WAS_PASSWORD}

echo Starting server
${WAS_HOME}/bin/startServer.sh server1
