@echo OFF

rem #############################################################################
rem #
rem #
rem # File Name: db2ConfigureKerberos.bat
rem # ===========================================================================
rem # Licensed Materials - Property of IBM
rem #
rem # 5724-T60 5608-A91
rem # (C) Copyright IBM Corp. 2021 All Rights Reserved
rem #
rem # US Government Users Restricted Rights - Use, duplication, or
rem # disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem #  ===========================================================================
rem # This script will configure Db2 to use Kerberos Authentication
rem # 
rem #############################################################################

:: Keep variables local
SETLOCAL ENABLEDELAYEDEXPANSION
SET CUR_DIR=%~dp0
SET KDC_SERVER=
SET REALM_NAME=
SET KRB5_CONF_PATH=
SET UPPER=
SET LOWER=
SET rc=0


if [%1]==[] goto usage
if [%2]==[] goto usage
if [%3]==[] goto usage

SET KRB5_CONF_PATH=%~1
SET KDC_SERVER=%~2
SET REALM_NAME=%~3

call :configureKrbFile
call :configureDb2
if NOT %rc%==0 (
    echo  Db2 configure Kerberos Authentication failed.
)
if %rc%==0 (
    echo DB2 configure Kerberos Authentication completed.
)
goto end


:configureDb2

    db2 update dbm cfg using CLNT_KRB_PLUGIN IBMkrb5 
    db2 update dbm cfg using SRVCON_GSSPLUGIN_LIST IBMkrb5 
    db2 update dbm cfg using AUTHENTICATION KERBEROS
    goto :EOF
    
:configureKrbFile

    if not exist %KRB5_CONF_PATH% (
        echo.
        echo Conf file does not exist at the specified location.
        goto end
    )
	
	call :toLower REALM_NAME
	set LOWER=!REALM_NAME!
	echo %LOWER%
	call :toUpper REALM_NAME
	set UPPER=!REALM_NAME!
	echo %UPPER%
    
    call :modifyFile kerberos.example.com %KDC_SERVER%
    call :modifyFile EXAMPLE.COM %UPPER%
    call :modifyFile example.com %LOWER%
    goto :EOF    
    
:toUpper
    for %%L IN (A B C D E F G H I J K L M N O P Q R S T U V W X Y Z) DO SET %1=!%1:%%L=%%L!
    goto :EOF

:toLower
    for %%L IN (a b c d e f g h i j k l m n o p q r s t u v w x y z) DO SET %1=!%1:%%L=%%L!
    goto :EOF

:modifyFile
    set "search=%1"
    set "replace=%2"
	
	for /f "delims=" %%s in ('type "%KRB5_CONF_PATH%" ^& break ^> "%KRB5_CONF_PATH%" ') do (
		set "line=%%s"
        setlocal enabledelayedexpansion
		set result=!line:%search%=%replace%!
        >>"%KRB5_CONF_PATH%" echo(!result!)
		endlocal
	)
	goto :EOF

:usage
    echo *************************************************************
    echo Usage:     
    echo db2ConfigureKerberos.bat path_of_krb.conf kdc_server realm_name
    echo where
    echo path_of_krb.conf is the path of krb5.conf file default is <SKLM_INSTALL_HOME>/kerberos
    echo kdc_server is the hostname of the kdc server or AD server
    echo *************************************************************
    goto end

:end
exit /B 0