#!/bin/bash

#
# File Name: db2RemoveKerberos.sh
#
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2021  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#

##############################################################################
# This script will remove kerberos settings from db2
##############################################################################

GID=`id -g`
CURDIR=`pwd`
KINIT_PATH=""
export TMPDIR=$CURDIR
OS=`uname`

printusage() {
echo "*************************************************************************
     Usage:  ./db2RemoveKerberos.sh db2ServiceName path_of_sqllib
     where 
          db2ServiceName is the name of db2 service registered with the kdc server
          and path_of_sqllib is the path of the sqllib folder default is /home/sklmdb41/sqllib
        
        eg: ./db2RemoveKerberos.sh sklmdb41/test.ibm.com@IBM.COM /home/sklmdb41/sqllib
     

Note:    Please ensure to use this script for Linux and AIX OS only                               
                            
********************************************************************************"
exit 1
}

if [ ! $2 ]; then
        printusage
fi

if [ $GID -eq 0  ]; then
        echo "Cannot run this operation as a root user. Only the process owner user can run this operation."
        exit 1        
fi


configureDb2Linux() {
    KINIT_PATH=$(which kinit)
    "$KINIT_PATH" -k -t $1 $2
    sed -i "/^export KRB5_KTNAME=/d" ~/.bash_profile
    sed -i "/^export KRB5_CONFIG=/d" ~/.bash_profile
    db2set DB2ENVLIST=
    db2 update dbm cfg using AUTHENTICATION SERVER
    db2 update dbm cfg using CLNT_KRB_PLUGIN NULL 
    db2 update dbm cfg using SRVCON_GSSPLUGIN_LIST NULL     
}

configureDb2AIX() {
    KINIT_PATH=$(which kinit)
    "$KINIT_PATH" -k -t $1 $2
    db2set DB2ENVLIST=
    db2 update dbm cfg using AUTHENTICATION SERVER
    db2 update dbm cfg using CLNT_KRB_PLUGIN NULL 
    db2 update dbm cfg using SRVCON_GSSPLUGIN_LIST NULL     
}

restartDb2() {
    db2stop force
    db2start
}

removeKinitToDb2Service() {
    kinit_command="-k -t"
    if [ "${OS}" == "Linux" ] 
    then 
       sed -i '/'"${kinit_command}"'/d' $1/db2start.sh
       sed -i '/'"${kinit_command}"'/d' $1/db2stop.sh
    else 
       sed '/'"${kinit_command}"'/d' /$1/db2start.sh > temp
       mv temp /$1/db2start.sh
       sed '/'"${kinit_command}"'/d' /$1/db2stop.sh > temp
       mv temp /$1/db2stop.sh
    fi        
}


#Executing Main
if [ "${OS}" == "Linux" ] || [ "${OS}" == "AIX" ]
then
    if [ "${OS}" == "Linux" ] 
    then 
        configureDb2Linux $KRB5_KTNAME $1
    else 
        configureDb2AIX $KRB5_KTNAME $1
    fi
    if [ $? -ne 0 ]
    then
        echo -e "Error setting the db2 with kerberos configuration."
        exit 1
    fi
    restartDb2
    if [ $? -ne 0 ]
    then
        echo -e "Error while restarting the db2."
        exit 1
    fi
    removeKinitToDb2Service $2 $1
    if [ $? -ne 0 ]
    then
        echo -e "Error while adding kinit in the db2 service file."
        exit 1
    fi
    echo -e "Db2 kerberos Configuration removed."
    exit 0
    
else
    printusage
fi
    
