#!/bin/bash

CURR_DIR=`pwd`
CURR_DIR=${CURR_DIR}/
echo "CURR_DIR=${CURR_DIR}"

export PATH=${PATH}:.

if [ ! -f restore.properties ]
then
echo "Cannot find restore.properties. The parameter values cannot be determined. Run this script again by specifying the following parameters in restore.properties"
echo WAS_HOME
echo DB_PASSWORD
echo BACKUP_PASSWORD
echo RESTORE_FILE
echo WAS_USER_PWD
echo RESTORE_USER_ROLES
exit 1
fi

. restore.properties

if [ -z ${WAS_HOME} ]
then 
echo "WAS_HOME Property is empty"
exit 1
fi
if [ ! -d ${WAS_HOME} ]
then 
echo "WAS_HOME Property is not directory"
exit 1
fi
if [ -z ${RESTORE_FILE} ]
then 
echo "RESTORE_FILE Property is empty"
exit 1
fi
if [ -z ${DB_PASSWORD} ]
then 
echo "DB_PASSWORD Property is empty"
exit 1
fi
if [ -z ${BACKUP_PASSWORD} ]
then 
echo "BACKUP_PASSWORD Property is empty"
exit 1
fi
if [ -z ${JAVA_HOME} ]
then
echo "JAVA_HOME Property is not set"
exit 1
fi
if [ ! -f ${JAVA_HOME}/bin/java ]
then
echo "Invalid JAVA_HOME directory set."
exit 1
fi


USRID=`id -u`
GID=`id -g`

if [ ! -d $HOME/sklm41properties ]; then
	if [ -f ${WAS_HOME}/properties/sklm.properties  ]; then
		. ${WAS_HOME}/properties/sklm.properties
	fi

	if [ $GID -eq 0  ]; then
		if [ "$TKLM_DB_HOME" =  "" ]; then
   			echo "Unable to locate 'sklm41properties' properties under $HOME, Please make sure $HOME/sklm41properties exist and try again."
   			exit 1
   		else
   			ln -s $TKLM_DB_HOME/sklm41properties/ $HOME/sklm41properties
		fi 
	fi
fi

BACKUP_CP=${CURR_DIR}com.ibm.sklm.server.migrate.sklmv30.jar:${WAS_HOME}/universalDriver/lib/db2jcc4.jar:${WAS_HOME}/universalDriver/lib/db2jcc_license_cu.jar:${WAS_HOME}/lib/j2ee.jar:${WAS_HOME}/plugins/com.ibm.icu.jar:${WAS_HOME}/plugins/com.ibm.tklm.commands.jar:${WAS_HOME}/java/jre/lib/ext/ibmkeycert.jar:${WAS_HOME}/java/jre/lib/ext/ibmpkcs11impl.jar:${WAS_HOME}/java/jre/lib/ext/ibmjcefips.jar:${WAS_HOME}/plugins/com.ibm.ws.runtime.jar:${WAS_HOME}/plugins/com.ibm.ws.prereq.xlxp.jar:${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/com.ibm.tklm.keyserver.jar:${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/com.ibm.tklm.kmip.adapter.jar:${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/com.ibm.tklm.kmip.jar:${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/com.ibm.tklm.ksinterface.jar:${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/com.ibm.tklm.log4j.jar:${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/com.ibm.tklm.server.api.jar:${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/com.ibm.tklm.server.db.ejb.jar:${WAS_HOME}/plugins/com.ibm.ws.runtime.wim.base.jar:${WAS_HOME}/plugins/com.ibm.ws.runtime.wim.core.jar:${WAS_HOME}/plugins/com.ibm.ws.admin.core.jar:${WAS_HOME}/plugins/org.eclipse.emf.commonj.sdo.jar:${WAS_HOME}/plugins/org.eclipse.emf.ecore.sdo.jar:${WAS_HOME}/plugins/org.eclipse.emf.ecore.xmi.jar:${WAS_HOME}/plugins/org.eclipse.emf.ecore.change.jar:${WAS_HOME}/plugins/com.ibm.sec.authz.ibmsecauthz_7.3.1.jar:${WAS_HOME}/lib/ext/com.ibm.tklm.passwordpolicy.jar:${WAS_HOME}/lib/ext/com.ibm.tklm.obfuscation.jar:${WAS_HOME}/plugins/org.eclipse.emf.ecore.jar:${WAS_HOME}/plugins/org.eclipse.emf.common.jar:${WAS_HOME}/lib/bootstrap.jar:${WAS_HOME}/plugins/com.ibm.ws.emf.jar:${WAS_HOME}/plugins/com.ibm.ws.emf.jar:${WAS_HOME}/plugins/com.ibm.ffdc.jar
for f in ${WAS_HOME}/profiles/KLMProfile/installedApps/SKLMCell/sklm_kms.ear/lib/*.jar
do
    BACKUP_CP=${BACKUP_CP}:$f
done

#echo "****** BACKUP_CP ${BACKUP_CP}*******"

export WAS_HOME=${WAS_HOME}
#echo "***** WAS_HOME ${WAS_HOME}********"

if [ -f $WAS_HOME/properties/sklm.properties  ]; then
	#echo TKLM_DB_ADMIN = $TKLM_DB_ADMIN	
	#echo loading $WAS_HOME/properties/sklm.properties
	. $WAS_HOME/properties/sklm.properties
fi

if [ $GID -eq 0  ]; then
	if [ "$TKLM_DB_ADMIN" =  "" ]; then
   		echo "Cannot run this operation as a root user. Only the process owner user can run this operation."
   		exit 1
   	else
   		COMMAND="${JAVA_HOME}/bin/java -cp ${BACKUP_CP} com.ibm.sklm.server.migrate.v2v.backup.RestoreHandlerV2V ${WAS_HOME}  > restore_console.log 2>&1"
   		su - $TKLM_DB_ADMIN -c "cd $CURR_DIR && export WAS_HOME=${WAS_HOME} && $COMMAND"
	fi	
else 
	${JAVA_HOME}/bin/java -cp ${BACKUP_CP} com.ibm.sklm.server.migrate.v2v.backup.RestoreHandlerV2V ${WAS_HOME}  > restore_console.log 2>&1
fi

rc=$?
if [ $rc -ne 0 ]; then
   	echo "Restore completed with errors, please refer to restore.log for more details."
else
	if [ ${RESTORE_USER_ROLES} = 'y' ]; then
		echo "Credentials for same user accounts that exist on both source and target servers are not migrated."
	fi
	echo "Restore completed, please refer to restore.log for more details."
	echo "For the changes to take effect, restart the IBM Security Guardium Key Lifecycle Manager server."
	rm -rf ${WAS_HOME}/products/sklm/data/*backup.jar_restore
fi

exit 0
