#!/bin/bash

#############################################################################
#
#
# 
# ===========================================================================
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2015.  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#  ===========================================================================
# 
#############################################################################

export SKLM_STATUS_FILE=$HOME/SKLMFPInstallStatus.properties
export INSTALL_MODE=UPDATE
printusage() {
echo "*************************************************************
Usage: 
     ./silent_updateSKLM.sh IM_INSTALL_LOCATION WAS_INSTALL_LOCATION WAS_ADMIN WAS_PASSWORD
      where
      IM_INSTALL_LOCATION is the directory where Installation manager for SKLM is installed.
      WAS_INSTALL_LOCATION is the directory where WebSphere Application Server(WAS) for SKLM is installed.
      WAS_ADMIN is Username of WebSphere Application Server(WAS) for SKLM.
      WAS_PASSWORD is Password of WebSphere Application Server(WAS) for SKLM.
Example : ./silent_updateSKLM.sh 	/opt/IBM/InstallationManager 
									/opt/IBM/WebSphere/AppServer 
									wasadmin 
									wasadminpwd	  
Note: 	-Please ensure that the username/passwords in SKLM_Silent_Update_Linux_Resp.xml is correct
		-before applying fixpack, Please ensure wsadmin console is not running.
*************************************************************"
echo STATUS=1 > $SKLM_STATUS_FILE
exit 1
}

SCRIPTHOME=${PWD}

if [ $# -ne 4 ]; then
	printusage
else
   export IM_INSTALL_LOCATION="$1"
   export WAS_INSTALL_LOCATION="$2"   
   export WAS_USER="$3"
   export WAS_PASS="$4"
fi

if [ "$TMPDIR" = "" ] 
then
	if [ ! -d /tmp ]
	then
		echo "Set Environment variable TMPDIR to a valid directory"
		exit 1 
	else
		export TMPDIR=/tmp
	fi
else
	if [ ! -d $TMPDIR ]
	then
		if [ ! -d /tmp ]
		then
			echo "Set Environment variable TMPDIR to a valid directory"
			exit 1 
		else
			export TMPDIR=/tmp
		fi
	fi
fi



if [ "$WAS_INSTALL_LOCATION" = "" ]; then
   printusage
fi
if [ "$IM_INSTALL_LOCATION" = "" ]; then
   printusage
fi
if [ "$WAS_USER" =  "" ]; then
   printusage
fi
if [ "$WAS_PASS" =  "" ]; then
   printusage
fi



if [ ! -d $WAS_INSTALL_LOCATION ]
then
echo "Check if the parameter WAS_INSTALL_LOCATION is set to the valid WAS directory."
echo STATUS=1 > $SKLM_STATUS_FILE
exit 1
fi

if [ ! -f  $WAS_INSTALL_LOCATION/bin/stopServer.sh ]
then
echo "Check if the parameter WAS_INSTALL_LOCATION is set to the valid WAS directory."
echo STATUS=1 > $SKLM_STATUS_FILE
exit 1
fi


if [ ! -d $IM_INSTALL_LOCATION ]
then
echo "Check if the parameter IM_INSTALL_LOCATION is set to the valid IM directory."
echo STATUS=1 > $SKLM_STATUS_FILE
exit 1
fi

if [ ! -f  $IM_INSTALL_LOCATION/eclipse/tools/imcl ]
then
echo "Check if the parameter IM_INSTALL_LOCATION is set to the valid IM directory."
echo STATUS=1 > $SKLM_STATUS_FILE
exit 1
fi

if [ ! -f  $IM_INSTALL_LOCATION/eclipse/IBMIM ]
then
echo "Check if the parameter IM_INSTALL_LOCATION is set to the valid IM directory."
echo STATUS=1 > $SKLM_STATUS_FILE
exit 1
fi


USRID=`id -u`
GID=`id -g`
if [ -f $WAS_INSTALL_LOCATION/properties/sklm.properties  ]; then
	. $WAS_INSTALL_LOCATION/properties/sklm.properties
fi

if [ $GID -eq 0  ]; then
	if [ "$TKLM_DB_HOME" =  "" ]; then
   		echo "Unable to locate 'sklm41properties' properties under $HOME, Please make sure $HOME/sklm41properties exist and try again."
   		exit 1
   	else
   		if [[ ! -L "$HOME/sklm41properties" && ! -d "$HOME/sklm41properties" ]]
        then
        	ln -s $TKLM_DB_HOME/sklm41properties/ $HOME/sklm41properties
        fi
	fi 
fi

echo STATUS=2 > $SKLM_STATUS_FILE
echo About to install FixPack...

echo Stopping SKLM Server...
echo $WAS_INSTALL_LOCATION/bin/stopServer.sh server1 -profileName KLMProfile -username $WAS_USER -password @@@@
$WAS_INSTALL_LOCATION/bin/stopServer.sh server1 -profileName KLMProfile -username $WAS_USER -password $WAS_PASS

echo Launching InstallManager...
echo $IM_INSTALL_LOCATION/eclipse/tools/imcl -input $SCRIPTHOME/sklm/SKLM_Silent_Update_AIX_Resp.xml -silent -acceptLicense
$IM_INSTALL_LOCATION/eclipse/tools/imcl -input $SCRIPTHOME/sklm/SKLM_Silent_Update_AIX_Resp.xml -silent -acceptLicense

if [ "$?" -eq "0" ]; then
        echo "Installation of fix pack is complete. See the Installation Manager log files for more information."
        echo STATUS=0 > $SKLM_STATUS_FILE
else
        echo "Installation of the fix pack is failed. See the Installation Manager log files for more information."
        echo STATUS=1 > $SKLM_STATUS_FILE
fi

rm -rf ${IM_INSTALL_LOCATION}/eclipse/jre*/jre/lib/ext/log4j-core-2.13.3.jar
rm -rf ${IM_INSTALL_LOCATION}/eclipse/jre*/jre/lib/ext/log4j-api-2.13.3.jar

rm -rf ${IM_INSTALL_LOCATION}/eclipse/jre*/jre/lib/ext/com.ibm.tklm.obfuscation.jar
cp ${WAS_INSTALL_LOCATION}/lib/ext/com.ibm.tklm.obfuscation.jar ${IM_INSTALL_LOCATION}/eclipse/jre*/jre/lib/ext/

exit 0