#! /bin/bash
logfilepath=/tmp/sklmInstaller.log
servicedirpath=/etc/systemd/system
db2servicename=$1
db2home=$2
db2username=$3
db2instancename=$4
washome=$5
sklmPropertiesDir=$6
sklmLocation=$7

GID=`id -g`

db2servicefullpath=${servicedirpath}/${db2servicename}

echo db2servicename=$db2servicename >> $logfilepath
echo db2home=$db2home >> $logfilepath
echo db2servicefullpath=$db2servicefullpath >> $logfilepath


if [ -d ${servicedirpath} ]; then
	if [ -f ${servicedirpath}/db2fmcd.service ]; then
		systemctl stop db2fmcd  >> $logfilepath
		systemctl disable db2fmcd  >> $logfilepath
	fi
	
	#Remove DB2 service if already exist
	if [ -f ${db2servicefullpath} ]; then
		systemctl disable ${db2servicename}
		rm -f ${db2servicefullpath}
		systemctl daemon-reload
		systemctl reset-failed
	fi

	#Creating DB2 service file.
	echo creating DB2 service file ${db2servicefullpath} >> $logfilepath
	echo [Unit] > ${db2servicefullpath}
	echo Description=DB2SKLMV41[Service] >> ${db2servicefullpath}
	echo DefaultDependencies=no >> ${db2servicefullpath}
	echo After=network.target >> ${db2servicefullpath}
	echo  >> ${db2servicefullpath}
	echo [Service] >> ${db2servicefullpath}
	echo Type=forking  >> ${db2servicefullpath}
	echo User=${db2username} >> ${db2servicefullpath}
	#echo #Group=${db2username} >> ${db2servicefullpath}
	
	db2StartCommand=${db2home}/sqllib/adm/db2start
    db2StopCommand="${db2home}/sqllib/adm/db2stop force"
    OS=`uname`
    if [ "${OS}" == "Linux" ] 
    then 
       sed -i '/#start db2/a '${db2StartCommand}'' ${db2home}/sqllib/db2start.sh 
       sed -i '/#stop db2/a '"${db2StopCommand}"'' ${db2home}/sqllib/db2stop.sh
    else  
       sed '/#start db2/a '${db2StartCommand}'' /${db2home}/sqllib/db2start.sh > temp
       mv temp /${db2home}/sqllib/db2start.sh
       sed '/#stop db2/a '"${db2StopCommand}"'' /${db2home}/sqllib/db2stop.sh > temp
       mv temp /${db2home}/sqllib/db2start.sh
    fi

    echo ExecStart=/bin/bash ${db2home}/sqllib/db2start.sh >> ${db2servicefullpath}
    echo ExecStop=/bin/bash ${db2home}/sqllib/db2stop.sh >> ${db2servicefullpath}
	
	echo Environment="DB2INSTANCE=${db2instancename}" >> ${db2servicefullpath}
	#echo ExecStart=${db2home}/sqllib/bin/db2fmd >> ${db2servicefullpath}
	echo Restart=on-abort >> ${db2servicefullpath}
	echo  >> ${db2servicefullpath}
	echo [Install] >> ${db2servicefullpath}
	echo WantedBy=default.target >> ${db2servicefullpath}
	
	echo enabling DB2 service "systemctl enable ${db2servicename}" >> $logfilepath
	chmod +x  ${db2servicefullpath}
	systemctl daemon-reload
	systemctl enable ${db2servicename}
	retcode=$?
	echo Enable ${db2servicename} return code : $retcode >> $logfilepath
	#Service validation
	su - ${db2username} -c "db2stop force"
	systemctl start ${db2servicename}
	retcode=$?
	echo Start ${db2servicename} return code : $retcode >> $logfilepath
	
	

fi 

chown -R ${db2username} ${washome}
chmod -R 750 ${washome}/bin
chown -R ${db2username} ${sklmLocation}

if [ $GID -eq 0  ]; then
	nruserhome=$(cat /etc/passwd | grep ${db2username} | cut -d ":" -f6)
	if [ -d ${HOME}/${sklmPropertiesDir} ]; then
		echo Directory "${HOME}/${sklmPropertiesDir}" exist, moving it to  "${nruserhome}" >> $logfilepath
		mv ${HOME}/${sklmPropertiesDir}  ${nruserhome}
		chown -R ${db2username} ${nruserhome}/${sklmPropertiesDir}
	fi
fi	
#su - ${db2username} -c "${washome}/bin/startServer.sh server1"

exit 0
